@@ -20,6 +20,7 @@ import static com.google.common.base.Preconditions.checkNotNull;
 import static com.google.common.base.Throwables.throwIfUnchecked;
 
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.CharMatcher;
 import com.google.common.base.Charsets;
 import com.google.common.base.Equivalence;
@@ -118,7 +119,7 @@ import java.util.TreeSet;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.regex.Pattern;
-import javax.annotation.CheckForNull;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Generates fresh instances of types that are different from each other (if possible).
@@ -126,6 +127,7 @@ import javax.annotation.CheckForNull;
  * @author Ben Yu
  */
 @GwtIncompatible
+@J2ktIncompatible
 class FreshValueGenerator {
 
   private static final ImmutableMap<Class<?>, Method> GENERATORS;
@@ -175,8 +177,7 @@ class FreshValueGenerator {
    *   <li>null if no value can be generated.
    * </ul>
    */
-  @CheckForNull
-  final Object generateFresh(TypeToken<?> type) {
+  final @Nullable Object generateFresh(TypeToken<?> type) {
     Object generated = generate(type);
     if (generated != null) {
       freshness.incrementAndGet();
@@ -184,8 +185,7 @@ class FreshValueGenerator {
     return generated;
   }
 
-  @CheckForNull
-  final <T> T generateFresh(Class<T> type) {
+  final <T> @Nullable T generateFresh(Class<T> type) {
     return Primitives.wrap(type).cast(generateFresh(TypeToken.of(type)));
   }
 
@@ -199,7 +199,7 @@ class FreshValueGenerator {
    * Generates an instance for {@code type} using the current {@link #freshness}. The generated
    * instance may or may not be unique across different calls.
    */
-  private Object generate(TypeToken<?> type) {
+  private @Nullable Object generate(TypeToken<?> type) {
     Class<?> rawType = type.getRawType();
     List<Object> samples = sampleInstances.get(rawType);
     Object sample = pickInstance(samples, null);
@@ -210,7 +210,7 @@ class FreshValueGenerator {
       return pickInstance(rawType.getEnumConstants(), null);
     }
     if (type.isArray()) {
-      TypeToken<?> componentType = type.getComponentType();
+      TypeToken<?> componentType = checkNotNull(type.getComponentType());
       Object array = Array.newInstance(componentType.getRawType(), 1);
       Array.set(array, 0, generate(componentType));
       return array;
@@ -256,7 +256,7 @@ class FreshValueGenerator {
     return defaultGenerate(rawType);
   }
 
-  private <T> T defaultGenerate(Class<T> rawType) {
+  private <T> @Nullable T defaultGenerate(Class<T> rawType) {
     if (rawType.isInterface()) {
       // always create a new proxy
       return newProxy(rawType);
@@ -289,7 +289,7 @@ class FreshValueGenerator {
     }
 
     @Override
-    protected Object handleInvocation(Object proxy, Method method, Object[] args) {
+    protected Object handleInvocation(Object proxy, Method method, @Nullable Object[] args) {
       return interfaceMethodCalled(interfaceType, method);
     }
 
@@ -299,7 +299,7 @@ class FreshValueGenerator {
     }
 
     @Override
-    public boolean equals(@CheckForNull Object obj) {
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof FreshInvocationHandler) {
         FreshInvocationHandler that = (FreshInvocationHandler) obj;
         return identity == that.identity;
@@ -620,7 +620,7 @@ class FreshValueGenerator {
   }
 
   @Generates
-  <T> Ordering<T> generateOrdering() {
+  <T extends @Nullable Object> Ordering<T> generateOrdering() {
     return new Ordering<T>() {
       @Override
       public int compare(T left, T right) {
@@ -647,29 +647,29 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <E> Iterable<E> generateIterable(@CheckForNull E freshElement) {
+  static <E> Iterable<E> generateIterable(@Nullable E freshElement) {
     return generateList(freshElement);
   }
 
   @Generates
-  static <E> Collection<E> generateCollection(@CheckForNull E freshElement) {
+  static <E> Collection<E> generateCollection(@Nullable E freshElement) {
     return generateList(freshElement);
   }
 
   @Generates
-  static <E> List<E> generateList(@CheckForNull E freshElement) {
+  static <E> List<E> generateList(@Nullable E freshElement) {
     return generateArrayList(freshElement);
   }
 
   @Generates
-  static <E> ArrayList<E> generateArrayList(@CheckForNull E freshElement) {
+  static <E> ArrayList<E> generateArrayList(@Nullable E freshElement) {
     ArrayList<E> list = Lists.newArrayList();
     list.add(freshElement);
     return list;
   }
 
   @Generates
-  static <E> LinkedList<E> generateLinkedList(@CheckForNull E freshElement) {
+  static <E> LinkedList<E> generateLinkedList(@Nullable E freshElement) {
     LinkedList<E> list = Lists.newLinkedList();
     list.add(freshElement);
     return list;
@@ -686,17 +686,17 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <E> Set<E> generateSet(@CheckForNull E freshElement) {
+  static <E> Set<E> generateSet(@Nullable E freshElement) {
     return generateHashSet(freshElement);
   }
 
   @Generates
-  static <E> HashSet<E> generateHashSet(@CheckForNull E freshElement) {
+  static <E> HashSet<E> generateHashSet(@Nullable E freshElement) {
     return generateLinkedHashSet(freshElement);
   }
 
   @Generates
-  static <E> LinkedHashSet<E> generateLinkedHashSet(@CheckForNull E freshElement) {
+  static <E> LinkedHashSet<E> generateLinkedHashSet(@Nullable E freshElement) {
     LinkedHashSet<E> set = Sets.newLinkedHashSet();
     set.add(freshElement);
     return set;
@@ -731,19 +731,19 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <E> Multiset<E> generateMultiset(@CheckForNull E freshElement) {
+  static <E> Multiset<E> generateMultiset(@Nullable E freshElement) {
     return generateHashMultiset(freshElement);
   }
 
   @Generates
-  static <E> HashMultiset<E> generateHashMultiset(@CheckForNull E freshElement) {
+  static <E> HashMultiset<E> generateHashMultiset(@Nullable E freshElement) {
     HashMultiset<E> multiset = HashMultiset.create();
     multiset.add(freshElement);
     return multiset;
   }
 
   @Generates
-  static <E> LinkedHashMultiset<E> generateLinkedHashMultiset(@CheckForNull E freshElement) {
+  static <E> LinkedHashMultiset<E> generateLinkedHashMultiset(@Nullable E freshElement) {
     LinkedHashMultiset<E> multiset = LinkedHashMultiset.create();
     multiset.add(freshElement);
     return multiset;
@@ -773,18 +773,17 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <K, V> Map<K, V> generateMap(@CheckForNull K key, @CheckForNull V value) {
+  static <K, V> Map<K, V> generateMap(@Nullable K key, @Nullable V value) {
     return generateHashdMap(key, value);
   }
 
   @Generates
-  static <K, V> HashMap<K, V> generateHashdMap(@CheckForNull K key, @CheckForNull V value) {
+  static <K, V> HashMap<K, V> generateHashdMap(@Nullable K key, @Nullable V value) {
     return generateLinkedHashMap(key, value);
   }
 
   @Generates
-  static <K, V> LinkedHashMap<K, V> generateLinkedHashMap(
-      @CheckForNull K key, @CheckForNull V value) {
+  static <K, V> LinkedHashMap<K, V> generateLinkedHashMap(@Nullable K key, @Nullable V value) {
     LinkedHashMap<K, V> map = Maps.newLinkedHashMap();
     map.put(key, value);
     return map;
@@ -809,19 +808,19 @@ class FreshValueGenerator {
 
   @Generates
   static <K extends Comparable<? super K>, V> SortedMap<K, V> generateSortedMap(
-      K key, @CheckForNull V value) {
+      K key, @Nullable V value) {
     return generateNavigableMap(key, value);
   }
 
   @Generates
   static <K extends Comparable<? super K>, V> NavigableMap<K, V> generateNavigableMap(
-      K key, @CheckForNull V value) {
+      K key, @Nullable V value) {
     return generateTreeMap(key, value);
   }
 
   @Generates
   static <K extends Comparable<? super K>, V> TreeMap<K, V> generateTreeMap(
-      K key, @CheckForNull V value) {
+      K key, @Nullable V value) {
     TreeMap<K, V> map = Maps.newTreeMap();
     map.put(key, value);
     return map;
@@ -834,7 +833,7 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <K, V> Multimap<K, V> generateMultimap(@CheckForNull K key, @CheckForNull V value) {
+  static <K, V> Multimap<K, V> generateMultimap(@Nullable K key, @Nullable V value) {
     return generateListMultimap(key, value);
   }
 
@@ -844,14 +843,13 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <K, V> ListMultimap<K, V> generateListMultimap(
-      @CheckForNull K key, @CheckForNull V value) {
+  static <K, V> ListMultimap<K, V> generateListMultimap(@Nullable K key, @Nullable V value) {
     return generateArrayListMultimap(key, value);
   }
 
   @Generates
   static <K, V> ArrayListMultimap<K, V> generateArrayListMultimap(
-      @CheckForNull K key, @CheckForNull V value) {
+      @Nullable K key, @Nullable V value) {
     ArrayListMultimap<K, V> multimap = ArrayListMultimap.create();
     multimap.put(key, value);
     return multimap;
@@ -863,13 +861,12 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <K, V> SetMultimap<K, V> generateSetMultimap(@CheckForNull K key, @CheckForNull V value) {
+  static <K, V> SetMultimap<K, V> generateSetMultimap(@Nullable K key, @Nullable V value) {
     return generateLinkedHashMultimap(key, value);
   }
 
   @Generates
-  static <K, V> HashMultimap<K, V> generateHashMultimap(
-      @CheckForNull K key, @CheckForNull V value) {
+  static <K, V> HashMultimap<K, V> generateHashMultimap(@Nullable K key, @Nullable V value) {
     HashMultimap<K, V> multimap = HashMultimap.create();
     multimap.put(key, value);
     return multimap;
@@ -877,7 +874,7 @@ class FreshValueGenerator {
 
   @Generates
   static <K, V> LinkedHashMultimap<K, V> generateLinkedHashMultimap(
-      @CheckForNull K key, @CheckForNull V value) {
+      @Nullable K key, @Nullable V value) {
     LinkedHashMultimap<K, V> multimap = LinkedHashMultimap.create();
     multimap.put(key, value);
     return multimap;
@@ -889,12 +886,12 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <K, V> BiMap<K, V> generateBimap(@CheckForNull K key, @CheckForNull V value) {
+  static <K, V> BiMap<K, V> generateBimap(@Nullable K key, @Nullable V value) {
     return generateHashBiMap(key, value);
   }
 
   @Generates
-  static <K, V> HashBiMap<K, V> generateHashBiMap(@CheckForNull K key, @CheckForNull V value) {
+  static <K, V> HashBiMap<K, V> generateHashBiMap(@Nullable K key, @Nullable V value) {
     HashBiMap<K, V> bimap = HashBiMap.create();
     bimap.put(key, value);
     return bimap;
@@ -906,14 +903,12 @@ class FreshValueGenerator {
   }
 
   @Generates
-  static <R, C, V> Table<R, C, V> generateTable(
-      @CheckForNull R row, @CheckForNull C column, @CheckForNull V value) {
+  static <R, C, V> Table<R, C, V> generateTable(R row, C column, V value) {
     return generateHashBasedTable(row, column, value);
   }
 
   @Generates
-  static <R, C, V> HashBasedTable<R, C, V> generateHashBasedTable(
-      @CheckForNull R row, @CheckForNull C column, @CheckForNull V value) {
+  static <R, C, V> HashBasedTable<R, C, V> generateHashBasedTable(R row, C column, V value) {
     HashBasedTable<R, C, V> table = HashBasedTable.create();
     table.put(row, column, value);
     return table;
