@@ -20,6 +20,7 @@ import static com.google.common.base.Preconditions.checkArgument;
 import static com.google.common.base.Preconditions.checkNotNull;
 
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.Converter;
 import com.google.common.base.Objects;
 import com.google.common.collect.ClassToInstanceMap;
@@ -32,8 +33,9 @@ import com.google.common.reflect.Invokable;
 import com.google.common.reflect.Parameter;
 import com.google.common.reflect.Reflection;
 import com.google.common.reflect.TypeToken;
+import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.lang.annotation.Annotation;
-import java.lang.reflect.AnnotatedElement;
+import java.lang.reflect.AnnotatedType;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Member;
@@ -41,18 +43,19 @@ import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
 import java.lang.reflect.ParameterizedType;
 import java.lang.reflect.Type;
+import java.lang.reflect.TypeVariable;
 import java.util.Arrays;
 import java.util.List;
 import java.util.concurrent.ConcurrentMap;
-import javax.annotation.CheckForNull;
 import junit.framework.Assert;
 import junit.framework.AssertionFailedError;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * A test utility that verifies that your methods and constructors throw {@link
  * NullPointerException} or {@link UnsupportedOperationException} whenever null is passed to a
- * parameter that isn't annotated with an annotation with the simple name {@code Nullable}, {@code
- * CheckForNull}, {@link NullableType}, or {@link NullableDecl}.
+ * parameter whose declaration or type isn't annotated with an annotation with the simple name
+ * {@code Nullable}, {@code CheckForNull}, {@code NullableType}, or {@code NullableDecl}.
  *
  * <p>The tested methods and constructors are invoked -- each time with one parameter being null and
  * the rest not null -- and the test fails if no expected exception is thrown. {@code
@@ -66,6 +69,8 @@ import junit.framework.AssertionFailedError;
  * @since 10.0
  */
 @GwtIncompatible
+@J2ktIncompatible
+@ElementTypesAreNonnullByDefault
 public final class NullPointerTester {
 
   private final ClassToInstanceMap<Object> defaults = MutableClassToInstanceMap.create();
@@ -73,10 +78,27 @@ public final class NullPointerTester {
 
   private ExceptionTypePolicy policy = ExceptionTypePolicy.NPE_OR_UOE;
 
+  public NullPointerTester() {
+    try {
+      /*
+       * Converter.apply has a non-nullable parameter type but doesn't throw for null arguments. For
+       * more information, see the comments in that class.
+       *
+       * We already know that that's how it behaves, and subclasses of Converter can't change that
+       * behavior. So there's no sense in making all subclass authors exclude the method from any
+       * NullPointerTester tests that they have.
+       */
+      ignoredMembers.add(Converter.class.getMethod("apply", Object.class));
+    } catch (NoSuchMethodException shouldBeImpossible) {
+      // OK, fine: If it doesn't exist, then there's chance that we're going to be asked to test it.
+    }
+  }
+
   /**
    * Sets a default value that can be used for any parameter of type {@code type}. Returns this
    * object.
    */
+  @CanIgnoreReturnValue
   public <T> NullPointerTester setDefault(Class<T> type, T value) {
     defaults.putInstance(type, checkNotNull(value));
     return this;
@@ -87,6 +109,7 @@ public final class NullPointerTester {
    *
    * @since 13.0
    */
+  @CanIgnoreReturnValue
   public NullPointerTester ignore(Method method) {
     ignoredMembers.add(checkNotNull(method));
     return this;
@@ -97,6 +120,7 @@ public final class NullPointerTester {
    *
    * @since 22.0
    */
+  @CanIgnoreReturnValue
   public NullPointerTester ignore(Constructor<?> constructor) {
     ignoredMembers.add(checkNotNull(constructor));
     return this;
@@ -174,7 +198,7 @@ public final class NullPointerTester {
    *
    * @param instance the instance to invoke {@code method} on, or null if {@code method} is static
    */
-  public void testMethod(@CheckForNull Object instance, Method method) {
+  public void testMethod(@Nullable Object instance, Method method) {
     Class<?>[] types = method.getParameterTypes();
     for (int nullIndex = 0; nullIndex < types.length; nullIndex++) {
       testMethodParameter(instance, method, nullIndex);
@@ -205,8 +229,7 @@ public final class NullPointerTester {
    *
    * @param instance the instance to invoke {@code method} on, or null if {@code method} is static
    */
-  public void testMethodParameter(
-      @CheckForNull final Object instance, final Method method, int paramIndex) {
+  public void testMethodParameter(@Nullable Object instance, Method method, int paramIndex) {
     method.setAccessible(true);
     testParameter(instance, invokable(instance, method), paramIndex, method.getDeclaringClass());
   }
@@ -304,7 +327,7 @@ public final class NullPointerTester {
     }
 
     @Override
-    public boolean equals(Object obj) {
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof Signature) {
         Signature that = (Signature) obj;
         return name.equals(that.name) && parameterTypes.equals(that.parameterTypes);
@@ -327,11 +350,18 @@ public final class NullPointerTester {
    *     static
    */
   private void testParameter(
-      Object instance, Invokable<?, ?> invokable, int paramIndex, Class<?> testedClass) {
+      @Nullable Object instance, Invokable<?, ?> invokable, int paramIndex, Class<?> testedClass) {
+    /*
+     * com.google.common is starting to rely on type-use annotations, which aren't visible under
+     * Android VMs. So we skip testing there.
+     */
+    if (isAndroid() && Reflection.getPackageName(testedClass).startsWith("com.google.common")) {
+      return;
+    }
     if (isPrimitiveOrNullable(invokable.getParameters().get(paramIndex))) {
       return; // there's nothing to test
     }
-    Object[] params = buildParamList(invokable, paramIndex);
+    @Nullable Object[] params = buildParamList(invokable, paramIndex);
     try {
       @SuppressWarnings("unchecked") // We'll get a runtime exception if the type is wrong.
       Invokable<Object, ?> unsafe = (Invokable<Object, ?>) invokable;
@@ -367,9 +397,10 @@ public final class NullPointerTester {
     }
   }
 
-  private Object[] buildParamList(Invokable<?, ?> invokable, int indexOfParamToSetToNull) {
+  private @Nullable Object[] buildParamList(
+      Invokable<?, ?> invokable, int indexOfParamToSetToNull) {
     ImmutableList<Parameter> params = invokable.getParameters();
-    Object[] args = new Object[params.size()];
+    @Nullable Object[] args = new Object[params.size()];
 
     for (int i = 0; i < args.length; i++) {
       Parameter param = params.get(i);
@@ -385,7 +416,7 @@ public final class NullPointerTester {
     return args;
   }
 
-  private <T> T getDefaultValue(TypeToken<T> type) {
+  private <T> @Nullable T getDefaultValue(TypeToken<T> type) {
     // We assume that all defaults are generics-safe, even if they aren't,
     // we take the risk.
     @SuppressWarnings("unchecked")
@@ -453,13 +484,13 @@ public final class NullPointerTester {
   private <T> T newDefaultReturningProxy(final TypeToken<T> type) {
     return new DummyProxy() {
       @Override
-      <R> R dummyReturnValue(TypeToken<R> returnType) {
+      <R> @Nullable R dummyReturnValue(TypeToken<R> returnType) {
         return getDefaultValue(returnType);
       }
     }.newProxy(type);
   }
 
-  private static Invokable<?, ?> invokable(@CheckForNull Object instance, Method method) {
+  private static Invokable<?, ?> invokable(@Nullable Object instance, Method method) {
     if (instance == null) {
       return Invokable.from(method);
     } else {
@@ -472,11 +503,18 @@ public final class NullPointerTester {
   }
 
   private static final ImmutableSet<String> NULLABLE_ANNOTATION_SIMPLE_NAMES =
-      ImmutableSet.of(
-          "CheckForNull", "Nullable", "NullableDecl", "NullableType", "ParametricNullness");
+      ImmutableSet.of("CheckForNull", "Nullable", "NullableDecl", "NullableType");
 
-  static boolean isNullable(AnnotatedElement e) {
-    for (Annotation annotation : e.getAnnotations()) {
+  static boolean isNullable(Invokable<?, ?> invokable) {
+    return NULLNESS_ANNOTATION_READER.isNullable(invokable);
+  }
+
+  static boolean isNullable(Parameter param) {
+    return NULLNESS_ANNOTATION_READER.isNullable(param);
+  }
+
+  private static boolean containsNullable(Annotation[] annotations) {
+    for (Annotation annotation : annotations) {
       if (NULLABLE_ANNOTATION_SIMPLE_NAMES.contains(annotation.annotationType().getSimpleName())) {
         return true;
       }
@@ -547,4 +585,87 @@ public final class NullPointerTester {
 
     public abstract boolean isExpectedType(Throwable cause);
   }
+
+  private static boolean annotatedTypeExists() {
+    try {
+      Class.forName("java.lang.reflect.AnnotatedType");
+    } catch (ClassNotFoundException e) {
+      return false;
+    }
+    return true;
+  }
+
+  private static final NullnessAnnotationReader NULLNESS_ANNOTATION_READER =
+      annotatedTypeExists()
+          ? NullnessAnnotationReader.FROM_DECLARATION_AND_TYPE_USE_ANNOTATIONS
+          : NullnessAnnotationReader.FROM_DECLARATION_ANNOTATIONS_ONLY;
+
+  /**
+   * Looks for declaration nullness annotations and, if supported, type-use nullness annotations.
+   *
+   * <p>Under Android VMs, the methods for retrieving type-use annotations don't exist. This means
+   * that {@link NullPointerException} may misbehave under Android when used on classes that rely on
+   * type-use annotations.
+   *
+   * <p>Under j2objc, the necessary APIs exist, but some (perhaps all) return stub values, like
+   * empty arrays. Presumably {@link NullPointerException} could likewise misbehave under j2objc,
+   * but I don't know that anyone uses it there, anyway.
+   */
+  private enum NullnessAnnotationReader {
+    // Usages (which are unsafe only for Android) are guarded by the annotatedTypeExists() check.
+    @SuppressWarnings({"Java7ApiChecker", "AndroidApiChecker", "DoNotCall", "deprecation"})
+    FROM_DECLARATION_AND_TYPE_USE_ANNOTATIONS {
+      @Override
+      @IgnoreJRERequirement
+      boolean isNullable(Invokable<?, ?> invokable) {
+        return FROM_DECLARATION_ANNOTATIONS_ONLY.isNullable(invokable)
+            || containsNullable(invokable.getAnnotatedReturnType().getAnnotations());
+        // TODO(cpovirk): Should we also check isNullableTypeVariable?
+      }
+
+      @Override
+      @IgnoreJRERequirement
+      boolean isNullable(Parameter param) {
+        return FROM_DECLARATION_ANNOTATIONS_ONLY.isNullable(param)
+            || containsNullable(param.getAnnotatedType().getAnnotations())
+            || isNullableTypeVariable(param.getAnnotatedType().getType());
+      }
+
+      @IgnoreJRERequirement
+      boolean isNullableTypeVariable(Type type) {
+        if (!(type instanceof TypeVariable)) {
+          return false;
+        }
+        TypeVariable<?> typeVar = (TypeVariable<?>) type;
+        for (AnnotatedType bound : typeVar.getAnnotatedBounds()) {
+          // Until Java 15, the isNullableTypeVariable case here won't help:
+          // https://bugs.openjdk.java.net/browse/JDK-8202469
+          if (containsNullable(bound.getAnnotations()) || isNullableTypeVariable(bound.getType())) {
+            return true;
+          }
+        }
+        return false;
+      }
+    },
+    FROM_DECLARATION_ANNOTATIONS_ONLY {
+      @Override
+      boolean isNullable(Invokable<?, ?> invokable) {
+        return containsNullable(invokable.getAnnotations());
+      }
+
+      @Override
+      boolean isNullable(Parameter param) {
+        return containsNullable(param.getAnnotations());
+      }
+    };
+
+    abstract boolean isNullable(Invokable<?, ?> invokable);
+
+    abstract boolean isNullable(Parameter param);
+  }
+
+  private static boolean isAndroid() {
+    // Arguably it would make more sense to test "can we see type-use annotations" directly....
+    return checkNotNull(System.getProperty("java.runtime.name", "")).contains("Android");
+  }
 }
