@@ -16,9 +16,8 @@
 
 package com.google.common.testing;
 
-import com.google.common.annotations.Beta;
-import com.google.errorprone.annotations.DoNotMock;
 import com.google.common.annotations.GwtCompatible;
+import com.google.errorprone.annotations.DoNotMock;
 
 /**
  * Any object which can accept registrations of {@link TearDown} instances.
@@ -26,9 +25,9 @@ import com.google.common.annotations.GwtCompatible;
  * @author Kevin Bourrillion
  * @since 10.0
  */
-@Beta
 @DoNotMock("Implement with a lambda")
 @GwtCompatible
+@ElementTypesAreNonnullByDefault
 public interface TearDownAccepter {
   /**
    * Registers a TearDown implementor which will be run after the test proper.
