@@ -31,7 +31,6 @@ import com.google.common.base.Equivalence;
 import com.google.common.base.Function;
 import com.google.common.base.Functions;
 import com.google.common.base.Predicate;
-import com.google.common.base.Predicates;
 import com.google.common.collect.Maps.EntryTransformer;
 import com.google.common.collect.Maps.ValueDifferenceImpl;
 import com.google.common.collect.SetsTest.Derived;
@@ -63,6 +62,7 @@ import java.util.SortedSet;
 import java.util.TreeMap;
 import java.util.concurrent.ConcurrentMap;
 import junit.framework.TestCase;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Unit test for {@code Maps}.
@@ -126,7 +126,10 @@ public class MapsTest extends TestCase {
 
     for (int size = 1; size < 200; size++) {
       assertWontGrow(
-          size, Maps.newHashMapWithExpectedSize(size), Maps.newHashMapWithExpectedSize(size));
+          size,
+          new HashMap<>(),
+          Maps.newHashMapWithExpectedSize(size),
+          Maps.newHashMapWithExpectedSize(size));
     }
   }
 
@@ -139,6 +142,7 @@ public class MapsTest extends TestCase {
     for (int size = 1; size < 200; size++) {
       assertWontGrow(
           size,
+          new LinkedHashMap<>(),
           Maps.newLinkedHashMapWithExpectedSize(size),
           Maps.newLinkedHashMapWithExpectedSize(size));
     }
@@ -146,7 +150,11 @@ public class MapsTest extends TestCase {
 
   @GwtIncompatible // reflection
   private static void assertWontGrow(
-      int size, HashMap<Object, Object> map1, HashMap<Object, Object> map2) throws Exception {
+      int size,
+      HashMap<Object, Object> referenceMap,
+      HashMap<Object, Object> map1,
+      HashMap<Object, Object> map2)
+      throws Exception {
     // Only start measuring table size after the first element inserted, to
     // deal with empty-map optimization.
     map1.put(0, null);
@@ -168,6 +176,16 @@ public class MapsTest extends TestCase {
     assertWithMessage("table size after adding " + size + " elements")
         .that(bucketsOf(map1))
         .isEqualTo(initialBuckets);
+
+    // Ensure that referenceMap, which doesn't use WithExpectedSize, ends up with the same table
+    // size as the other two maps. If it ended up with a smaller size that would imply that we
+    // computed the wrong initial capacity.
+    for (int i = 0; i < size; i++) {
+      referenceMap.put(i, null);
+    }
+    assertWithMessage("table size after adding " + size + " elements")
+        .that(initialBuckets)
+        .isAtMost(bucketsOf(referenceMap));
   }
 
   @GwtIncompatible // reflection
@@ -1308,23 +1326,23 @@ public class MapsTest extends TestCase {
     assertEquals(ImmutableSet.of(1, 2, 3), sync.inverse().keySet());
   }
 
-  private static final Predicate<String> NOT_LENGTH_3 =
-      new Predicate<String>() {
+  static final Predicate<@Nullable String> NOT_LENGTH_3 =
+      new Predicate<@Nullable String>() {
         @Override
-        public boolean apply(String input) {
+        public boolean apply(@Nullable String input) {
           return input == null || input.length() != 3;
         }
       };
 
-  private static final Predicate<Integer> EVEN =
-      new Predicate<Integer>() {
+  static final Predicate<@Nullable Integer> EVEN =
+      new Predicate<@Nullable Integer>() {
         @Override
-        public boolean apply(Integer input) {
+        public boolean apply(@Nullable Integer input) {
           return input == null || input % 2 == 0;
         }
       };
 
-  private static final Predicate<Entry<String, Integer>> CORRECT_LENGTH =
+  static final Predicate<Entry<String, Integer>> CORRECT_LENGTH =
       new Predicate<Entry<String, Integer>>() {
         @Override
         public boolean apply(Entry<String, Integer> input) {
@@ -1332,7 +1350,7 @@ public class MapsTest extends TestCase {
         }
       };
 
-  private static final Function<Integer, Double> SQRT_FUNCTION =
+  static final Function<Integer, Double> SQRT_FUNCTION =
       new Function<Integer, Double>() {
         @Override
         public Double apply(Integer in) {
@@ -1340,233 +1358,6 @@ public class MapsTest extends TestCase {
         }
       };
 
-  public static class FilteredMapTest extends TestCase {
-    Map<String, Integer> createUnfiltered() {
-      return Maps.newHashMap();
-    }
-
-    public void testFilteredKeysIllegalPut() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      Map<String, Integer> filtered = Maps.filterKeys(unfiltered, NOT_LENGTH_3);
-      filtered.put("a", 1);
-      filtered.put("b", 2);
-      assertEquals(ImmutableMap.of("a", 1, "b", 2), filtered);
-
-      try {
-        filtered.put("yyy", 3);
-        fail();
-      } catch (IllegalArgumentException expected) {
-      }
-    }
-
-    public void testFilteredKeysIllegalPutAll() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      Map<String, Integer> filtered = Maps.filterKeys(unfiltered, NOT_LENGTH_3);
-      filtered.put("a", 1);
-      filtered.put("b", 2);
-      assertEquals(ImmutableMap.of("a", 1, "b", 2), filtered);
-
-      try {
-        filtered.putAll(ImmutableMap.of("c", 3, "zzz", 4, "b", 5));
-        fail();
-      } catch (IllegalArgumentException expected) {
-      }
-
-      assertEquals(ImmutableMap.of("a", 1, "b", 2), filtered);
-    }
-
-    public void testFilteredKeysFilteredReflectsBackingChanges() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      Map<String, Integer> filtered = Maps.filterKeys(unfiltered, NOT_LENGTH_3);
-      unfiltered.put("two", 2);
-      unfiltered.put("three", 3);
-      unfiltered.put("four", 4);
-      assertEquals(ImmutableMap.of("two", 2, "three", 3, "four", 4), unfiltered);
-      assertEquals(ImmutableMap.of("three", 3, "four", 4), filtered);
-
-      unfiltered.remove("three");
-      assertEquals(ImmutableMap.of("two", 2, "four", 4), unfiltered);
-      assertEquals(ImmutableMap.of("four", 4), filtered);
-
-      unfiltered.clear();
-      assertEquals(ImmutableMap.of(), unfiltered);
-      assertEquals(ImmutableMap.of(), filtered);
-    }
-
-    public void testFilteredValuesIllegalPut() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      Map<String, Integer> filtered = Maps.filterValues(unfiltered, EVEN);
-      filtered.put("a", 2);
-      unfiltered.put("b", 4);
-      unfiltered.put("c", 5);
-      assertEquals(ImmutableMap.of("a", 2, "b", 4), filtered);
-
-      try {
-        filtered.put("yyy", 3);
-        fail();
-      } catch (IllegalArgumentException expected) {
-      }
-      assertEquals(ImmutableMap.of("a", 2, "b", 4), filtered);
-    }
-
-    public void testFilteredValuesIllegalPutAll() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      Map<String, Integer> filtered = Maps.filterValues(unfiltered, EVEN);
-      filtered.put("a", 2);
-      unfiltered.put("b", 4);
-      unfiltered.put("c", 5);
-      assertEquals(ImmutableMap.of("a", 2, "b", 4), filtered);
-
-      try {
-        filtered.putAll(ImmutableMap.of("c", 4, "zzz", 5, "b", 6));
-        fail();
-      } catch (IllegalArgumentException expected) {
-      }
-      assertEquals(ImmutableMap.of("a", 2, "b", 4), filtered);
-    }
-
-    public void testFilteredValuesIllegalSetValue() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      Map<String, Integer> filtered = Maps.filterValues(unfiltered, EVEN);
-      filtered.put("a", 2);
-      filtered.put("b", 4);
-      assertEquals(ImmutableMap.of("a", 2, "b", 4), filtered);
-
-      Entry<String, Integer> entry = filtered.entrySet().iterator().next();
-      try {
-        entry.setValue(5);
-        fail();
-      } catch (IllegalArgumentException expected) {
-      }
-
-      assertEquals(ImmutableMap.of("a", 2, "b", 4), filtered);
-    }
-
-    public void testFilteredValuesClear() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      unfiltered.put("one", 1);
-      unfiltered.put("two", 2);
-      unfiltered.put("three", 3);
-      unfiltered.put("four", 4);
-      Map<String, Integer> filtered = Maps.filterValues(unfiltered, EVEN);
-      assertEquals(ImmutableMap.of("one", 1, "two", 2, "three", 3, "four", 4), unfiltered);
-      assertEquals(ImmutableMap.of("two", 2, "four", 4), filtered);
-
-      filtered.clear();
-      assertEquals(ImmutableMap.of("one", 1, "three", 3), unfiltered);
-      assertTrue(filtered.isEmpty());
-    }
-
-    public void testFilteredEntriesIllegalPut() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      unfiltered.put("cat", 3);
-      unfiltered.put("dog", 2);
-      unfiltered.put("horse", 5);
-      Map<String, Integer> filtered = Maps.filterEntries(unfiltered, CORRECT_LENGTH);
-      assertEquals(ImmutableMap.of("cat", 3, "horse", 5), filtered);
-
-      filtered.put("chicken", 7);
-      assertEquals(ImmutableMap.of("cat", 3, "horse", 5, "chicken", 7), filtered);
-
-      try {
-        filtered.put("cow", 7);
-        fail();
-      } catch (IllegalArgumentException expected) {
-      }
-      assertEquals(ImmutableMap.of("cat", 3, "horse", 5, "chicken", 7), filtered);
-    }
-
-    public void testFilteredEntriesIllegalPutAll() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      unfiltered.put("cat", 3);
-      unfiltered.put("dog", 2);
-      unfiltered.put("horse", 5);
-      Map<String, Integer> filtered = Maps.filterEntries(unfiltered, CORRECT_LENGTH);
-      assertEquals(ImmutableMap.of("cat", 3, "horse", 5), filtered);
-
-      filtered.put("chicken", 7);
-      assertEquals(ImmutableMap.of("cat", 3, "horse", 5, "chicken", 7), filtered);
-
-      try {
-        filtered.putAll(ImmutableMap.of("sheep", 5, "cow", 7));
-        fail();
-      } catch (IllegalArgumentException expected) {
-      }
-      assertEquals(ImmutableMap.of("cat", 3, "horse", 5, "chicken", 7), filtered);
-    }
-
-    public void testFilteredEntriesObjectPredicate() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      unfiltered.put("cat", 3);
-      unfiltered.put("dog", 2);
-      unfiltered.put("horse", 5);
-      Predicate<Object> predicate = Predicates.alwaysFalse();
-      Map<String, Integer> filtered = Maps.filterEntries(unfiltered, predicate);
-      assertTrue(filtered.isEmpty());
-    }
-
-    public void testFilteredEntriesWildCardEntryPredicate() {
-      Map<String, Integer> unfiltered = createUnfiltered();
-      unfiltered.put("cat", 3);
-      unfiltered.put("dog", 2);
-      unfiltered.put("horse", 5);
-      Predicate<Entry<?, ?>> predicate =
-          new Predicate<Entry<?, ?>>() {
-            @Override
-            public boolean apply(Entry<?, ?> input) {
-              return "cat".equals(input.getKey()) || Integer.valueOf(2) == input.getValue();
-            }
-          };
-      Map<String, Integer> filtered = Maps.filterEntries(unfiltered, predicate);
-      assertEquals(ImmutableMap.of("cat", 3, "dog", 2), filtered);
-    }
-  }
-
-  public static class FilteredSortedMapTest extends FilteredMapTest {
-    @Override
-    SortedMap<String, Integer> createUnfiltered() {
-      return Maps.newTreeMap();
-    }
-
-    public void testFirstAndLastKeyFilteredMap() {
-      SortedMap<String, Integer> unfiltered = createUnfiltered();
-      unfiltered.put("apple", 2);
-      unfiltered.put("banana", 6);
-      unfiltered.put("cat", 3);
-      unfiltered.put("dog", 5);
-
-      SortedMap<String, Integer> filtered = Maps.filterEntries(unfiltered, CORRECT_LENGTH);
-      assertEquals("banana", filtered.firstKey());
-      assertEquals("cat", filtered.lastKey());
-    }
-
-    public void testHeadSubTailMap_FilteredMap() {
-      SortedMap<String, Integer> unfiltered = createUnfiltered();
-      unfiltered.put("apple", 2);
-      unfiltered.put("banana", 6);
-      unfiltered.put("cat", 4);
-      unfiltered.put("dog", 3);
-      SortedMap<String, Integer> filtered = Maps.filterEntries(unfiltered, CORRECT_LENGTH);
-
-      assertEquals(ImmutableMap.of("banana", 6), filtered.headMap("dog"));
-      assertEquals(ImmutableMap.of(), filtered.headMap("banana"));
-      assertEquals(ImmutableMap.of("banana", 6, "dog", 3), filtered.headMap("emu"));
-
-      assertEquals(ImmutableMap.of("banana", 6), filtered.subMap("banana", "dog"));
-      assertEquals(ImmutableMap.of("dog", 3), filtered.subMap("cat", "emu"));
-
-      assertEquals(ImmutableMap.of("dog", 3), filtered.tailMap("cat"));
-      assertEquals(ImmutableMap.of("banana", 6, "dog", 3), filtered.tailMap("banana"));
-    }
-  }
-
-  public static class FilteredBiMapTest extends FilteredMapTest {
-    @Override
-    BiMap<String, Integer> createUnfiltered() {
-      return HashBiMap.create();
-    }
-  }
-
   public void testTransformValues() {
     Map<String, Integer> map = ImmutableMap.of("a", 4, "b", 9);
     Map<String, Double> transformed = transformValues(map, SQRT_FUNCTION);
