@@ -40,6 +40,7 @@ import java.io.OutputStream;
 import java.util.Arrays;
 import java.util.EnumSet;
 import junit.framework.TestSuite;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Tests for the default implementations of {@code ByteSource} methods.
@@ -151,8 +152,8 @@ public class ByteSourceTest extends IoTestCase {
   }
 
   public void testRead_withProcessor_stopsOnFalse() throws IOException {
-    ByteProcessor<Void> processor =
-        new ByteProcessor<Void>() {
+    ByteProcessor<@Nullable Void> processor =
+        new ByteProcessor<@Nullable Void>() {
           boolean firstCall = true;
 
           @Override
@@ -163,7 +164,7 @@ public class ByteSourceTest extends IoTestCase {
           }
 
           @Override
-          public Void getResult() {
+          public @Nullable Void getResult() {
             return null;
           }
         };
@@ -473,7 +474,9 @@ public class ByteSourceTest extends IoTestCase {
     }
   }
 
-  /** @return the number of exceptions that were suppressed on the expected thrown exception */
+  /**
+   * @return the number of exceptions that were suppressed on the expected thrown exception
+   */
   private static int runSuppressionFailureTest(ByteSource in, ByteSink out) {
     try {
       in.copyTo(out);
