@@ -20,7 +20,6 @@ import static com.google.common.base.Preconditions.checkArgument;
 import static com.google.common.base.Preconditions.checkNotNull;
 import static com.google.common.collect.CollectPreconditions.checkRemove;
 
-import com.google.common.annotations.Beta;
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
 import com.google.common.base.Function;
@@ -987,10 +986,13 @@ public final class Iterables {
    * Returns a view of the supplied iterable that wraps each generated {@link Iterator} through
    * {@link Iterators#consumingIterator(Iterator)}.
    *
-   * <p>Note: If {@code iterable} is a {@link Queue}, the returned iterable will get entries from
-   * {@link Queue#remove()} since {@link Queue}'s iteration order is undefined. Calling {@link
-   * Iterator#hasNext()} on a generated iterator from the returned iterable may cause an item to be
-   * immediately dequeued for return on a subsequent call to {@link Iterator#next()}.
+   * <p>Note: If {@code iterable} is a {@link Queue}, the returned iterable will instead use {@link
+   * Queue#isEmpty} and {@link Queue#remove()}, since {@link Queue}'s iteration order is undefined.
+   * Calling {@link Iterator#hasNext()} on a generated iterator from the returned iterable may cause
+   * an item to be immediately dequeued for return on a subsequent call to {@link Iterator#next()}.
+   *
+   * <p>Whether the input {@code iterable} is a {@link Queue} or not, the returned {@code Iterable}
+   * is not thread-safe.
    *
    * @param iterable the iterable to wrap
    * @return a view of the supplied iterable that wraps each generated iterator through {@link
@@ -1050,7 +1052,6 @@ public final class Iterables {
    *
    * @since 11.0
    */
-  @Beta
   public static <T extends @Nullable Object> Iterable<T> mergeSorted(
       final Iterable<? extends Iterable<? extends T>> iterables,
       final Comparator<? super T> comparator) {
@@ -1061,21 +1062,9 @@ public final class Iterables {
           @Override
           public Iterator<T> iterator() {
             return Iterators.mergeSorted(
-                Iterables.transform(iterables, Iterables.<T>toIterator()), comparator);
+                Iterables.transform(iterables, Iterable::iterator), comparator);
           }
         };
     return new UnmodifiableIterable<>(iterable);
   }
-
-  // TODO(user): Is this the best place for this? Move to fluent functions?
-  // Useful as a public method?
-  static <T extends @Nullable Object>
-      Function<Iterable<? extends T>, Iterator<? extends T>> toIterator() {
-    return new Function<Iterable<? extends T>, Iterator<? extends T>>() {
-      @Override
-      public Iterator<? extends T> apply(Iterable<? extends T> iterable) {
-        return iterable.iterator();
-      }
-    };
-  }
 }
