@@ -23,8 +23,8 @@ import static com.google.common.base.Preconditions.checkState;
 import static com.google.common.collect.CollectPreconditions.checkRemove;
 import static java.util.Objects.requireNonNull;
 
-import com.google.common.annotations.Beta;
 import com.google.common.annotations.GwtCompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.math.IntMath;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
@@ -98,7 +98,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @author Torbjorn Gannholm
  * @since 8.0
  */
-@Beta
 @GwtCompatible
 @ElementTypesAreNonnullByDefault
 public final class MinMaxPriorityQueue<E> extends AbstractQueue<E> {
@@ -108,7 +107,7 @@ public final class MinMaxPriorityQueue<E> extends AbstractQueue<E> {
    * initial contents, and an initial expected size of 11.
    */
   public static <E extends Comparable<E>> MinMaxPriorityQueue<E> create() {
-    return new Builder<Comparable>(Ordering.natural()).create();
+    return new Builder<Comparable<E>>(Ordering.natural()).create();
   }
 
   /**
@@ -162,7 +161,6 @@ public final class MinMaxPriorityQueue<E> extends AbstractQueue<E> {
    *     Queue<Integer>} but not a {@code Queue<Object>}).
    * @since 8.0
    */
-  @Beta
   public static final class Builder<B> {
     /*
      * TODO(kevinb): when the dust settles, see if we still need this or can
@@ -518,14 +516,17 @@ public final class MinMaxPriorityQueue<E> extends AbstractQueue<E> {
   }
 
   /**
-   * Each instance of MinMaxPriortyQueue encapsulates two instances of Heap: a min-heap and a
+   * Each instance of MinMaxPriorityQueue encapsulates two instances of Heap: a min-heap and a
    * max-heap. Conceptually, these might each have their own array for storage, but for efficiency's
    * sake they are stored interleaved on alternate heap levels in the same array (MMPQ.queue).
    */
   @WeakOuter
   private class Heap {
     final Ordering<E> ordering;
-    @Weak Heap otherHeap; // always initialized immediately after construction
+
+    @SuppressWarnings("nullness:initialization.field.uninitialized")
+    @Weak
+    Heap otherHeap; // always initialized immediately after construction
 
     Heap(Ordering<E> ordering) {
       this.ordering = ordering;
@@ -644,17 +645,18 @@ public final class MinMaxPriorityQueue<E> extends AbstractQueue<E> {
       int parentIndex = getParentIndex(index);
       E parentElement = elementData(parentIndex);
       if (parentIndex != 0) {
-        // This is a guard for the case of the childless uncle.
-        // Since the end of the array is actually the middle of the heap,
-        // a smaller childless uncle can become a child of x when we
-        // bubble up alternate levels, violating the invariant.
+        /*
+         * This is a guard for the case of the childless aunt node. Since the end of the array is
+         * actually the middle of the heap, a smaller childless aunt node can become a child of x
+         * when we bubble up alternate levels, violating the invariant.
+         */
         int grandparentIndex = getParentIndex(parentIndex);
-        int uncleIndex = getRightChildIndex(grandparentIndex);
-        if (uncleIndex != parentIndex && getLeftChildIndex(uncleIndex) >= size) {
-          E uncleElement = elementData(uncleIndex);
-          if (ordering.compare(uncleElement, parentElement) < 0) {
-            parentIndex = uncleIndex;
-            parentElement = uncleElement;
+        int auntIndex = getRightChildIndex(grandparentIndex);
+        if (auntIndex != parentIndex && getLeftChildIndex(auntIndex) >= size) {
+          E auntElement = elementData(auntIndex);
+          if (ordering.compare(auntElement, parentElement) < 0) {
+            parentIndex = auntIndex;
+            parentElement = auntElement;
           }
         }
       }
@@ -667,26 +669,30 @@ public final class MinMaxPriorityQueue<E> extends AbstractQueue<E> {
       return index;
     }
 
+    // About the term "aunt node": it's better to leave gender out of it, but for this the English
+    // language has nothing for us. Except for the whimsical neologism "pibling" (!) which we
+    // obviously could not expect to increase anyone's understanding of the code.
+
     /**
      * Swap {@code actualLastElement} with the conceptually correct last element of the heap.
      * Returns the index that {@code actualLastElement} now resides in.
      *
      * <p>Since the last element of the array is actually in the middle of the sorted structure, a
-     * childless uncle node could be smaller, which would corrupt the invariant if this element
-     * becomes the new parent of the uncle. In that case, we first switch the last element with its
-     * uncle, before returning.
+     * childless aunt node could be smaller, which would corrupt the invariant if this element
+     * becomes the new parent of the aunt node. In that case, we first switch the last element with
+     * its aunt node, before returning.
      */
     int swapWithConceptuallyLastElement(E actualLastElement) {
       int parentIndex = getParentIndex(size);
       if (parentIndex != 0) {
         int grandparentIndex = getParentIndex(parentIndex);
-        int uncleIndex = getRightChildIndex(grandparentIndex);
-        if (uncleIndex != parentIndex && getLeftChildIndex(uncleIndex) >= size) {
-          E uncleElement = elementData(uncleIndex);
-          if (ordering.compare(uncleElement, actualLastElement) < 0) {
-            queue[uncleIndex] = actualLastElement;
-            queue[size] = uncleElement;
-            return uncleIndex;
+        int auntIndex = getRightChildIndex(grandparentIndex);
+        if (auntIndex != parentIndex && getLeftChildIndex(auntIndex) >= size) {
+          E auntElement = elementData(auntIndex);
+          if (ordering.compare(auntElement, actualLastElement) < 0) {
+            queue[auntIndex] = actualLastElement;
+            queue[size] = auntElement;
+            return auntIndex;
           }
         }
       }
@@ -911,6 +917,7 @@ public final class MinMaxPriorityQueue<E> extends AbstractQueue<E> {
   }
 
   @Override
+  @J2ktIncompatible // Incompatible return type change. Use inherited (unoptimized) implementation
   public Object[] toArray() {
     Object[] copyTo = new Object[size];
     System.arraycopy(queue, 0, copyTo, 0, size);
