@@ -20,6 +20,7 @@ import static com.google.common.base.Preconditions.checkNotNull;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.j2objc.annotations.RetainedWith;
 import java.io.IOException;
@@ -96,6 +97,7 @@ final class Synchronized {
     // following writeObject() handles the SynchronizedObject members.
 
     @GwtIncompatible // java.io.ObjectOutputStream
+    @J2ktIncompatible
     private void writeObject(ObjectOutputStream stream) throws IOException {
       synchronized (mutex) {
         stream.defaultWriteObject();
@@ -103,6 +105,7 @@ final class Synchronized {
     }
 
     @GwtIncompatible // not needed in emulated source
+    @J2ktIncompatible
     private static final long serialVersionUID = 0;
   }
 
@@ -459,7 +462,7 @@ final class Synchronized {
     }
 
     @Override
-    public int add(E e, int n) {
+    public int add(@ParametricNullness E e, int n) {
       synchronized (mutex) {
         return delegate().add(e, n);
       }
@@ -473,14 +476,14 @@ final class Synchronized {
     }
 
     @Override
-    public int setCount(E element, int count) {
+    public int setCount(@ParametricNullness E element, int count) {
       synchronized (mutex) {
         return delegate().setCount(element, count);
       }
     }
 
     @Override
-    public boolean setCount(E element, int oldCount, int newCount) {
+    public boolean setCount(@ParametricNullness E element, int oldCount, int newCount) {
       synchronized (mutex) {
         return delegate().setCount(element, oldCount, newCount);
       }
@@ -588,21 +591,21 @@ final class Synchronized {
     }
 
     @Override
-    public Collection<V> get(K key) {
+    public Collection<V> get(@ParametricNullness K key) {
       synchronized (mutex) {
         return typePreservingCollection(delegate().get(key), mutex);
       }
     }
 
     @Override
-    public boolean put(K key, V value) {
+    public boolean put(@ParametricNullness K key, @ParametricNullness V value) {
       synchronized (mutex) {
         return delegate().put(key, value);
       }
     }
 
     @Override
-    public boolean putAll(K key, Iterable<? extends V> values) {
+    public boolean putAll(@ParametricNullness K key, Iterable<? extends V> values) {
       synchronized (mutex) {
         return delegate().putAll(key, values);
       }
@@ -616,7 +619,7 @@ final class Synchronized {
     }
 
     @Override
-    public Collection<V> replaceValues(K key, Iterable<? extends V> values) {
+    public Collection<V> replaceValues(@ParametricNullness K key, Iterable<? extends V> values) {
       synchronized (mutex) {
         return delegate().replaceValues(key, values); // copy not synchronized
       }
@@ -922,16 +925,15 @@ final class Synchronized {
     // See Collections.CheckedMap.CheckedEntrySet for details on attacks.
 
     @Override
-    public Object[] toArray() {
+    public @Nullable Object[] toArray() {
       synchronized (mutex) {
         /*
          * toArrayImpl returns `@Nullable Object[]` rather than `Object[]` but only because it can
          * be used with collections that may contain null. This collection never contains nulls, so
-         * we can treat it as a plain `Object[]`.
+         * we could return `Object[]`. But this class is private and J2KT cannot change return types
+         * in overrides, so we declare `@Nullable Object[]` as the return type.
          */
-        @SuppressWarnings("nullness")
-        Object[] result = (Object[]) ObjectArrays.toArrayImpl(delegate());
-        return result;
+        return ObjectArrays.toArrayImpl(delegate());
       }
     }
 
@@ -1229,7 +1231,7 @@ final class Synchronized {
 
     @Override
     @CheckForNull
-    public V forcePut(K key, V value) {
+    public V forcePut(@ParametricNullness K key, @ParametricNullness V value) {
       synchronized (mutex) {
         return delegate().forcePut(key, value);
       }
@@ -1989,7 +1991,10 @@ final class Synchronized {
 
     @Override
     @CheckForNull
-    public V put(R rowKey, C columnKey, V value) {
+    public V put(
+        @ParametricNullness R rowKey,
+        @ParametricNullness C columnKey,
+        @ParametricNullness V value) {
       synchronized (mutex) {
         return delegate().put(rowKey, columnKey, value);
       }
@@ -2011,14 +2016,14 @@ final class Synchronized {
     }
 
     @Override
-    public Map<C, V> row(R rowKey) {
+    public Map<C, V> row(@ParametricNullness R rowKey) {
       synchronized (mutex) {
         return map(delegate().row(rowKey), mutex);
       }
     }
 
     @Override
-    public Map<R, V> column(C columnKey) {
+    public Map<R, V> column(@ParametricNullness C columnKey) {
       synchronized (mutex) {
         return map(delegate().column(columnKey), mutex);
       }
