@@ -24,6 +24,7 @@ import static java.util.Objects.requireNonNull;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.MoreObjects;
 import com.google.common.primitives.Ints;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
@@ -262,7 +263,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     checkArgument(range.contains(element));
     AvlNode<E> root = rootReference.get();
     if (root == null) {
-      comparator().compare(element, element);
+      int unused = comparator().compare(element, element);
       AvlNode<E> newRoot = new AvlNode<E>(element, occurrences);
       successor(header, newRoot, header);
       rootReference.checkAndSet(root, newRoot);
@@ -1061,6 +1062,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
    * @serialData the comparator, the number of distinct elements, the first element, its count, the
    *     second element, its count, and so on
    */
+  @J2ktIncompatible
   @GwtIncompatible // java.io.ObjectOutputStream
   private void writeObject(ObjectOutputStream stream) throws IOException {
     stream.defaultWriteObject();
@@ -1068,6 +1070,7 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
     Serialization.writeMultiset(this, stream);
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.io.ObjectInputStream
   private void readObject(ObjectInputStream stream) throws IOException, ClassNotFoundException {
     stream.defaultReadObject();
@@ -1086,5 +1089,6 @@ public final class TreeMultiset<E extends @Nullable Object> extends AbstractSort
   }
 
   @GwtIncompatible // not needed in emulated source
+  @J2ktIncompatible
   private static final long serialVersionUID = 1;
 }
