@@ -16,11 +16,9 @@ package com.google.common.primitives;
 
 import static com.google.common.base.Preconditions.checkArgument;
 
-import com.google.common.annotations.Beta;
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.base.Preconditions;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
-import com.google.errorprone.annotations.CheckReturnValue;
 import com.google.errorprone.annotations.Immutable;
 import java.io.Serializable;
 import java.util.AbstractList;
@@ -77,7 +75,6 @@ import javax.annotation.CheckForNull;
  *
  * @since 22.0
  */
-@Beta
 @GwtCompatible
 @Immutable
 @ElementTypesAreNonnullByDefault
@@ -192,7 +189,6 @@ public final class ImmutableIntArray implements Serializable {
    * A builder for {@link ImmutableIntArray} instances; obtained using {@link
    * ImmutableIntArray#builder}.
    */
-  @CanIgnoreReturnValue
   public static final class Builder {
     private int[] array;
     private int count = 0; // <= array.length
@@ -205,6 +201,7 @@ public final class ImmutableIntArray implements Serializable {
      * Appends {@code value} to the end of the values the built {@link ImmutableIntArray} will
      * contain.
      */
+    @CanIgnoreReturnValue
     public Builder add(int value) {
       ensureRoomFor(1);
       array[count] = value;
@@ -216,6 +213,7 @@ public final class ImmutableIntArray implements Serializable {
      * Appends {@code values}, in order, to the end of the values the built {@link
      * ImmutableIntArray} will contain.
      */
+    @CanIgnoreReturnValue
     public Builder addAll(int[] values) {
       ensureRoomFor(values.length);
       System.arraycopy(values, 0, array, count, values.length);
@@ -227,6 +225,7 @@ public final class ImmutableIntArray implements Serializable {
      * Appends {@code values}, in order, to the end of the values the built {@link
      * ImmutableIntArray} will contain.
      */
+    @CanIgnoreReturnValue
     public Builder addAll(Iterable<Integer> values) {
       if (values instanceof Collection) {
         return addAll((Collection<Integer>) values);
@@ -241,6 +240,7 @@ public final class ImmutableIntArray implements Serializable {
      * Appends {@code values}, in order, to the end of the values the built {@link
      * ImmutableIntArray} will contain.
      */
+    @CanIgnoreReturnValue
     public Builder addAll(Collection<Integer> values) {
       ensureRoomFor(values.size());
       for (Integer value : values) {
@@ -253,6 +253,7 @@ public final class ImmutableIntArray implements Serializable {
      * Appends {@code values}, in order, to the end of the values the built {@link
      * ImmutableIntArray} will contain.
      */
+    @CanIgnoreReturnValue
     public Builder addAll(ImmutableIntArray values) {
       ensureRoomFor(values.length());
       System.arraycopy(values.array, values.start, array, count, values.length());
@@ -291,7 +292,6 @@ public final class ImmutableIntArray implements Serializable {
      * no data is copied as part of this step, but this may occupy more memory than strictly
      * necessary. To copy the data to a right-sized backing array, use {@code .build().trimmed()}.
      */
-    @CheckReturnValue
     public ImmutableIntArray build() {
       return count == 0 ? EMPTY : new ImmutableIntArray(array, 0, count);
     }
