@@ -19,9 +19,11 @@ import static com.google.common.base.Preconditions.checkNotNull;
 import com.google.common.annotations.Beta;
 import com.google.common.collect.ImmutableList;
 import com.google.errorprone.annotations.CanIgnoreReturnValue;
+import com.google.errorprone.annotations.DoNotCall;
 import java.lang.annotation.Annotation;
 import java.lang.reflect.AccessibleObject;
 import java.lang.reflect.AnnotatedElement;
+import java.lang.reflect.AnnotatedType;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Member;
@@ -62,7 +64,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @since 14.0 (no longer implements {@link AccessibleObject} or {@code GenericDeclaration} since
  *     31.0)
  */
-@Beta
 @ElementTypesAreNonnullByDefault
 public abstract class Invokable<T, R> implements AnnotatedElement, Member {
   private final AccessibleObject accessibleObject;
@@ -272,12 +273,17 @@ public abstract class Invokable<T, R> implements AnnotatedElement, Member {
    * of a non-static inner class, unlike {@link Constructor#getParameterTypes}, the hidden {@code
    * this} parameter of the enclosing class is excluded from the returned parameters.
    */
+  @IgnoreJRERequirement
   public final ImmutableList<Parameter> getParameters() {
     Type[] parameterTypes = getGenericParameterTypes();
     Annotation[][] annotations = getParameterAnnotations();
+    @Nullable Object[] annotatedTypes =
+        ANNOTATED_TYPE_EXISTS ? getAnnotatedParameterTypes() : new Object[parameterTypes.length];
     ImmutableList.Builder<Parameter> builder = ImmutableList.builder();
     for (int i = 0; i < parameterTypes.length; i++) {
-      builder.add(new Parameter(this, i, TypeToken.of(parameterTypes[i]), annotations[i]));
+      builder.add(
+          new Parameter(
+              this, i, TypeToken.of(parameterTypes[i]), annotations[i], annotatedTypes[i]));
     }
     return builder.build();
   }
@@ -337,6 +343,10 @@ public abstract class Invokable<T, R> implements AnnotatedElement, Member {
 
   abstract Type[] getGenericParameterTypes();
 
+  @SuppressWarnings({"Java7ApiChecker", "AndroidJdkLibsChecker"})
+  @IgnoreJRERequirement
+  abstract AnnotatedType[] getAnnotatedParameterTypes();
+
   /** This should never return a type that's not a subtype of Throwable. */
   abstract Type[] getGenericExceptionTypes();
 
@@ -344,6 +354,22 @@ public abstract class Invokable<T, R> implements AnnotatedElement, Member {
 
   abstract Type getGenericReturnType();
 
+  /**
+   * Returns the {@link AnnotatedType} for the return type.
+   *
+   * <p>This method will fail if run under an Android VM.
+   *
+   * @since NEXT for guava-android (available since 14.0 in guava-jre)
+   * @deprecated This method does not work under Android VMs. It is safe to use from guava-jre, but
+   *     this copy in guava-android is not safe to use.
+   */
+  @SuppressWarnings({"Java7ApiChecker", "AndroidJdkLibsChecker"})
+  @DoNotCall("fails under Android VMs; do not use from guava-android")
+  @Deprecated
+  @IgnoreJRERequirement
+  @Beta
+  public abstract AnnotatedType getAnnotatedReturnType();
+
   static class MethodInvokable<T> extends Invokable<T, Object> {
 
     final Method method;
@@ -370,6 +396,21 @@ public abstract class Invokable<T, R> implements AnnotatedElement, Member {
       return method.getGenericParameterTypes();
     }
 
+    @Override
+    @SuppressWarnings({"Java7ApiChecker", "AndroidJdkLibsChecker"})
+    @IgnoreJRERequirement
+    AnnotatedType[] getAnnotatedParameterTypes() {
+      return method.getAnnotatedParameterTypes();
+    }
+
+    @Override
+    @SuppressWarnings({"Java7ApiChecker", "AndroidJdkLibsChecker", "DoNotCall"})
+    @DoNotCall
+    @IgnoreJRERequirement
+    public AnnotatedType getAnnotatedReturnType() {
+      return method.getAnnotatedReturnType();
+    }
+
     @Override
     Type[] getGenericExceptionTypes() {
       return method.getGenericExceptionTypes();
@@ -447,6 +488,21 @@ public abstract class Invokable<T, R> implements AnnotatedElement, Member {
       return types;
     }
 
+    @Override
+    @SuppressWarnings({"Java7ApiChecker", "AndroidJdkLibsChecker"})
+    @IgnoreJRERequirement
+    AnnotatedType[] getAnnotatedParameterTypes() {
+      return constructor.getAnnotatedParameterTypes();
+    }
+
+    @Override
+    @SuppressWarnings({"Java7ApiChecker", "AndroidJdkLibsChecker", "DoNotCall"})
+    @DoNotCall
+    @IgnoreJRERequirement
+    public AnnotatedType getAnnotatedReturnType() {
+      return constructor.getAnnotatedReturnType();
+    }
+
     @Override
     Type[] getGenericExceptionTypes() {
       return constructor.getGenericExceptionTypes();
@@ -510,4 +566,15 @@ public abstract class Invokable<T, R> implements AnnotatedElement, Member {
       }
     }
   }
+
+  private static final boolean ANNOTATED_TYPE_EXISTS = initAnnotatedTypeExists();
+
+  private static boolean initAnnotatedTypeExists() {
+    try {
+      Class.forName("java.lang.reflect.AnnotatedType");
+    } catch (ClassNotFoundException e) {
+      return false;
+    }
+    return true;
+  }
 }
