@@ -21,15 +21,15 @@ import java.util.Collections;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
+import jsinterop.annotations.JsMethod;
 import jsinterop.annotations.JsPackage;
 import jsinterop.annotations.JsProperty;
 import jsinterop.annotations.JsType;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Minimal GWT emulation of {@code com.google.common.collect.Platform}.
  *
- * <p><strong>This .java file should never be consumed by javac.</strong>
- *
  * @author Hayward Chan
  */
 final class Platform {
@@ -74,13 +74,8 @@ final class Platform {
   }
 
   static <T> T[] newArray(T[] reference, int length) {
-    T[] clone = Arrays.copyOf(reference, 0);
-    resizeArray(clone, length);
-    return clone;
-  }
-
-  private static void resizeArray(Object array, int newSize) {
-    ((NativeArray) array).setLength(newSize);
+    T[] empty = reference.length == 0 ? reference : Arrays.copyOf(reference, 0);
+    return Arrays.copyOf(empty, length);
   }
 
   /** Equivalent to Arrays.copyOfRange(source, from, to, arrayOfType.getClass()). */
@@ -101,6 +96,19 @@ final class Platform {
     return mapMaker;
   }
 
+  static <E extends Enum<E>> Class<E> getDeclaringClassOrObjectForJ2cl(E e) {
+    Class<E> classOrNull = getDeclaringClassOrNullForJ2cl(e);
+    @SuppressWarnings("unchecked")
+    Class<E> result = classOrNull == null ? (Class<E>) (Class<?>) Object.class : classOrNull;
+    return result;
+  }
+
+  @JsMethod
+  private static native <E extends Enum<E>> @Nullable Class<E> getDeclaringClassOrNullForJ2cl(
+      E e) /*-{
+    return e.@java.lang.Enum::getDeclaringClass()();
+  }-*/;
+
   static int reduceIterationsIfGwt(int iterations) {
     return iterations / 10;
   }
