@@ -23,6 +23,7 @@ import static com.google.common.util.concurrent.Futures.getDone;
 import static com.google.common.util.concurrent.MoreExecutors.directExecutor;
 
 import com.google.common.util.concurrent.internal.InternalFutureFailureAccess;
+import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.CancellationException;
@@ -37,7 +38,8 @@ import org.checkerframework.checker.nullness.qual.Nullable;
 
 /** Emulation for AbstractFuture in GWT. */
 @SuppressWarnings("nullness") // TODO(b/147136275): Remove once our checker understands & and |.
-public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
+@ElementTypesAreNonnullByDefault
+public abstract class AbstractFuture<V extends @Nullable Object> extends InternalFutureFailureAccess
     implements ListenableFuture<V> {
 
   static final boolean GENERATE_CANCELLATION_CAUSES = false;
@@ -47,14 +49,17 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
    * of this interface must also be an AbstractFuture and must not override or expose for overriding
    * any of the public methods of ListenableFuture.
    */
-  interface Trusted<V> extends ListenableFuture<V> {}
+  interface Trusted<V extends @Nullable Object> extends ListenableFuture<V> {}
 
-  abstract static class TrustedFuture<V> extends AbstractFuture<V> implements Trusted<V> {
+  abstract static class TrustedFuture<V extends @Nullable Object> extends AbstractFuture<V>
+      implements Trusted<V> {
+    @CanIgnoreReturnValue
     @Override
     public final V get() throws InterruptedException, ExecutionException {
       return super.get();
     }
 
+    @CanIgnoreReturnValue
     @Override
     public final V get(long timeout, TimeUnit unit)
         throws InterruptedException, ExecutionException, TimeoutException {
@@ -76,6 +81,7 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
       super.addListener(listener, executor);
     }
 
+    @CanIgnoreReturnValue
     @Override
     public final boolean cancel(boolean mayInterruptIfRunning) {
       return super.cancel(mayInterruptIfRunning);
@@ -86,8 +92,8 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
 
   private State state;
   private V value;
-  private Future<? extends V> delegate;
-  private Throwable throwable;
+  private @Nullable Future<? extends V> delegate;
+  private @Nullable Throwable throwable;
   private boolean mayInterruptIfRunning;
   private List<Listener> listeners;
 
@@ -96,6 +102,7 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
     listeners = new ArrayList<Listener>();
   }
 
+  @CanIgnoreReturnValue
   @Override
   public boolean cancel(boolean mayInterruptIfRunning) {
     if (!state.permitsPublicUserToTransitionTo(State.CANCELLED)) {
@@ -129,12 +136,14 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
   /*
    * ForwardingFluentFuture needs to override those methods, so they are not final.
    */
+  @CanIgnoreReturnValue
   @Override
   public V get() throws InterruptedException, ExecutionException {
     state.maybeThrowOnGet(throwable);
     return value;
   }
 
+  @CanIgnoreReturnValue
   @Override
   public V get(long timeout, TimeUnit unit)
       throws InterruptedException, ExecutionException, TimeoutException {
@@ -152,6 +161,7 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
     }
   }
 
+  @CanIgnoreReturnValue
   protected boolean setException(Throwable throwable) {
     checkNotNull(throwable);
     if (!state.permitsPublicUserToTransitionTo(State.FAILURE)) {
@@ -168,6 +178,7 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
     notifyAndClearListeners();
   }
 
+  @CanIgnoreReturnValue
   protected boolean set(V value) {
     if (!state.permitsPublicUserToTransitionTo(State.VALUE)) {
       return false;
@@ -183,6 +194,7 @@ public abstract class AbstractFuture<V> extends InternalFutureFailureAccess
     notifyAndClearListeners();
   }
 
+  @CanIgnoreReturnValue
   protected boolean setFuture(ListenableFuture<? extends V> future) {
     checkNotNull(future);
 
