@@ -16,12 +16,14 @@ package com.google.common.util.concurrent;
 
 import com.google.common.base.Function;
 import java.util.concurrent.Executor;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Hidden superclass of {@link Futures} that provides us a place to declare special GWT versions of
  * the {@link Futures#catching(ListenableFuture, Class, com.google.common.base.Function)
  * Futures.catching} family of methods. Those versions have slightly different signatures.
  */
+@ElementTypesAreNonnullByDefault
 abstract class GwtFuturesCatchingSpecialization {
   /*
    * In the GWT versions of the methods (below), every exceptionType parameter is required to be
@@ -29,7 +31,7 @@ abstract class GwtFuturesCatchingSpecialization {
    * your own instanceof tests.
    */
 
-  public static <V> ListenableFuture<V> catching(
+  public static <V extends @Nullable Object> ListenableFuture<V> catching(
       ListenableFuture<? extends V> input,
       Class<Throwable> exceptionType,
       Function<? super Throwable, ? extends V> fallback,
@@ -37,7 +39,7 @@ abstract class GwtFuturesCatchingSpecialization {
     return AbstractCatchingFuture.create(input, exceptionType, fallback, executor);
   }
 
-  public static <V> ListenableFuture<V> catchingAsync(
+  public static <V extends @Nullable Object> ListenableFuture<V> catchingAsync(
       ListenableFuture<? extends V> input,
       Class<Throwable> exceptionType,
       AsyncFunction<? super Throwable, ? extends V> fallback,
