@@ -17,7 +17,6 @@
 package com.google.common.collect.testing;
 
 import com.google.common.annotations.GwtCompatible;
-
 import java.util.Locale;
 
 /**
@@ -29,24 +28,13 @@ import java.util.Locale;
  */
 @GwtCompatible
 final class Platform {
-
-  /**
-   * Calls {@link Class#isInstance(Object)}.  Factored out so that it can be
-   * emulated in GWT.
-   *
-   * <p>This method always returns {@code true} in GWT.
-   */
-  static boolean checkIsInstance(Class<?> clazz, Object obj) {
-    return clazz.isInstance(obj);
-  }
-
   static <T> T[] clone(T[] array) {
     return array.clone();
   }
 
   // Class.cast is not supported in GWT.  This method is a no-op in GWT.
   static void checkCast(Class<?> clazz, Object obj) {
-    clazz.cast(obj);
+    Object unused = clazz.cast(obj);
   }
 
   static String format(String template, Object... args) {
