@@ -22,10 +22,12 @@ import static junit.framework.Assert.assertTrue;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.base.Equivalence;
-import com.google.common.collect.ImmutableList;
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Lists;
+import com.google.errorprone.annotations.CanIgnoreReturnValue;
+import java.util.ArrayList;
 import java.util.List;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Tester for equals() and hashCode() methods of a class.
@@ -74,6 +76,7 @@ import java.util.List;
  * @since 10.0
  */
 @GwtCompatible
+@ElementTypesAreNonnullByDefault
 public final class EqualsTester {
   private static final int REPETITIONS = 3;
 
@@ -93,13 +96,23 @@ public final class EqualsTester {
    * Adds {@code equalityGroup} with objects that are supposed to be equal to each other and not
    * equal to any other equality groups added to this tester.
    */
-  public EqualsTester addEqualityGroup(Object... equalityGroup) {
+  @CanIgnoreReturnValue
+  public EqualsTester addEqualityGroup(@Nullable Object @Nullable ... equalityGroup) {
     checkNotNull(equalityGroup);
-    equalityGroups.add(ImmutableList.copyOf(equalityGroup));
+    List<Object> list = new ArrayList<>(equalityGroup.length);
+    for (int i = 0; i < equalityGroup.length; i++) {
+      Object element = equalityGroup[i];
+      if (element == null) {
+        throw new NullPointerException("at index " + i);
+      }
+      list.add(element);
+    }
+    equalityGroups.add(list);
     return this;
   }
 
   /** Run tests on equals method, throwing a failure on an invalid test */
+  @CanIgnoreReturnValue
   public EqualsTester testEquals() {
     RelationshipTester<Object> delegate =
         new RelationshipTester<>(
