@@ -26,10 +26,6 @@ import com.google.common.testing.ClassSanityTester.FactoryMethodReturnsNullExcep
 import com.google.common.testing.ClassSanityTester.ParameterHasNoDistinctValueException;
 import com.google.common.testing.ClassSanityTester.ParameterNotInstantiableException;
 import com.google.common.testing.NullPointerTester.Visibility;
-
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
-
 import java.io.Serializable;
 import java.lang.reflect.InvocationTargetException;
 import java.util.AbstractList;
@@ -38,14 +34,18 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
-
-import javax.annotation.Nullable;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+import junit.framework.AssertionFailedError;
+import junit.framework.TestCase;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Unit tests for {@link ClassSanityTester}.
  *
  * @author Ben Yu
  */
+@AndroidIncompatible // NullPointerTester refuses to run for c.g.c under Android
 public class ClassSanityTesterTest extends TestCase {
 
   private final ClassSanityTester tester = new ClassSanityTester();
@@ -55,7 +55,9 @@ public class ClassSanityTesterTest extends TestCase {
   }
 
   public static class GoodEqualsFactory {
-    public static Object good(String a, int b,
+    public static Object good(
+        String a,
+        int b,
         // oneConstantOnly doesn't matter since it's not nullable and can be only 1 value.
         @SuppressWarnings("unused") OneConstantEnum oneConstantOnly,
         // noConstant doesn't matter since it can only be null
@@ -85,7 +87,8 @@ public class ClassSanityTesterTest extends TestCase {
       tester.forAllPublicStaticMethods(NoPublicStaticMethods.class).testEquals();
     } catch (AssertionFailedError expected) {
       assertThat(expected)
-          .hasMessage(
+          .hasMessageThat()
+          .isEqualTo(
               "No public static methods that return java.lang.Object or subtype are found in "
                   + NoPublicStaticMethods.class
                   + ".");
@@ -106,8 +109,7 @@ public class ClassSanityTesterTest extends TestCase {
   private static class BadEqualsFactory {
     /** oneConstantOnly matters now since it can be either null or the constant. */
     @SuppressWarnings("unused") // Called by reflection
-    public static Object bad(String a, int b,
-        @Nullable OneConstantEnum oneConstantOnly) {
+    public static Object bad(String a, int b, @Nullable OneConstantEnum oneConstantOnly) {
       return new GoodEquals(a, b);
     }
   }
@@ -125,10 +127,7 @@ public class ClassSanityTesterTest extends TestCase {
 
   public void testNullsOnReturnValues_bad() throws Exception {
     try {
-      tester
-          .forAllPublicStaticMethods(BadNullsFactory.class)
-          .thatReturn(Object.class)
-          .testNulls();
+      tester.forAllPublicStaticMethods(BadNullsFactory.class).thatReturn(Object.class).testNulls();
     } catch (AssertionFailedError expected) {
       return;
     }
@@ -143,7 +142,8 @@ public class ClassSanityTesterTest extends TestCase {
           .testNulls();
     } catch (AssertionFailedError expected) {
       assertThat(expected)
-          .hasMessage(
+          .hasMessageThat()
+          .isEqualTo(
               "No public static methods that return java.lang.Iterable or subtype are found in "
                   + BadNullsFactory.class
                   + ".");
@@ -151,13 +151,14 @@ public class ClassSanityTesterTest extends TestCase {
     }
     fail();
   }
-  
+
   public static class BadNullsFactory {
     public static Object bad(@SuppressWarnings("unused") String a) {
       return new BadNulls();
     }
   }
 
+  @AndroidIncompatible // TODO(cpovirk): ClassNotFoundException... ClassSanityTesterTest$AnInterface
   public void testSerializableOnReturnValues_good() throws Exception {
     tester.forAllPublicStaticMethods(GoodSerializableFactory.class).testSerializable();
   }
@@ -166,6 +167,7 @@ public class ClassSanityTesterTest extends TestCase {
     public static Object good(Runnable r) {
       return r;
     }
+
     public static Object good(AnInterface i) {
       return i;
     }
@@ -174,7 +176,7 @@ public class ClassSanityTesterTest extends TestCase {
   public void testSerializableOnReturnValues_bad() throws Exception {
     try {
       tester.forAllPublicStaticMethods(BadSerializableFactory.class).testSerializable();
-    } catch (AssertionError expected) {
+    } catch (AssertionFailedError expected) {
       return;
     }
     fail();
@@ -193,14 +195,13 @@ public class ClassSanityTesterTest extends TestCase {
       throws Exception {
     try {
       tester.forAllPublicStaticMethods(GoodEqualsFactory.class).testEqualsAndSerializable();
-    } catch (AssertionError expected) {
+    } catch (AssertionFailedError expected) {
       return;
     }
     fail("should have failed");
   }
 
-  public void testEqualsAndSerializableOnReturnValues_serializableButNotEquals()
-      throws Exception {
+  public void testEqualsAndSerializableOnReturnValues_serializableButNotEquals() throws Exception {
     try {
       tester.forAllPublicStaticMethods(GoodSerializableFactory.class).testEqualsAndSerializable();
     } catch (AssertionFailedError expected) {
@@ -209,13 +210,14 @@ public class ClassSanityTesterTest extends TestCase {
     fail("should have failed");
   }
 
-  public void testEqualsAndSerializableOnReturnValues_good()
-      throws Exception {
-    tester.forAllPublicStaticMethods(GoodEqualsAndSerialiableFactory.class)
+  @AndroidIncompatible // TODO(cpovirk): ClassNotFoundException... ClassSanityTesterTest$AnInterface
+  public void testEqualsAndSerializableOnReturnValues_good() throws Exception {
+    tester
+        .forAllPublicStaticMethods(GoodEqualsAndSerializableFactory.class)
         .testEqualsAndSerializable();
   }
 
-  public static class GoodEqualsAndSerialiableFactory {
+  public static class GoodEqualsAndSerializableFactory {
     public static Object good(AnInterface s) {
       return Functions.constant(s);
     }
@@ -223,8 +225,7 @@ public class ClassSanityTesterTest extends TestCase {
 
   public void testEqualsForReturnValues_factoryReturnsNullButNotAnnotated() throws Exception {
     try {
-      tester.forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class)
-          .testEquals();
+      tester.forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class).testEquals();
     } catch (AssertionFailedError expected) {
       return;
     }
@@ -233,8 +234,7 @@ public class ClassSanityTesterTest extends TestCase {
 
   public void testNullsForReturnValues_factoryReturnsNullButNotAnnotated() throws Exception {
     try {
-      tester.forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class)
-          .testNulls();
+      tester.forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class).testNulls();
     } catch (AssertionFailedError expected) {
       return;
     }
@@ -243,7 +243,8 @@ public class ClassSanityTesterTest extends TestCase {
 
   public void testSerializableForReturnValues_factoryReturnsNullButNotAnnotated() throws Exception {
     try {
-      tester.forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class)
+      tester
+          .forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class)
           .testSerializable();
     } catch (AssertionFailedError expected) {
       return;
@@ -254,7 +255,8 @@ public class ClassSanityTesterTest extends TestCase {
   public void testEqualsAndSerializableForReturnValues_factoryReturnsNullButNotAnnotated()
       throws Exception {
     try {
-      tester.forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class)
+      tester
+          .forAllPublicStaticMethods(FactoryThatReturnsNullButNotAnnotated.class)
           .testEqualsAndSerializable();
     } catch (AssertionFailedError expected) {
       return;
@@ -269,28 +271,26 @@ public class ClassSanityTesterTest extends TestCase {
   }
 
   public void testEqualsForReturnValues_factoryReturnsNullAndAnnotated() throws Exception {
-    tester.forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class)
-        .testEquals();
+    tester.forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class).testEquals();
   }
 
   public void testNullsForReturnValues_factoryReturnsNullAndAnnotated() throws Exception {
-    tester.forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class)
-        .testNulls();
+    tester.forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class).testNulls();
   }
 
   public void testSerializableForReturnValues_factoryReturnsNullAndAnnotated() throws Exception {
-    tester.forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class)
-        .testSerializable();
+    tester.forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class).testSerializable();
   }
 
   public void testEqualsAndSerializableForReturnValues_factoryReturnsNullAndAnnotated()
       throws Exception {
-    tester.forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class)
+    tester
+        .forAllPublicStaticMethods(FactoryThatReturnsNullAndAnnotated.class)
         .testEqualsAndSerializable();
   }
 
   public static class FactoryThatReturnsNullAndAnnotated {
-    @Nullable public static Object bad() {
+    public static @Nullable Object bad() {
       return null;
     }
   }
@@ -315,7 +315,7 @@ public class ClassSanityTesterTest extends TestCase {
     try {
       tester.testEquals(BadEquals.class);
     } catch (AssertionFailedError expected) {
-      assertThat(expected.getMessage()).contains("create(null)");
+      assertThat(expected).hasMessageThat().contains("create(null)");
       return;
     }
     fail("should have failed");
@@ -325,7 +325,7 @@ public class ClassSanityTesterTest extends TestCase {
     try {
       tester.testEquals(BadEqualsWithParameterizedType.class);
     } catch (AssertionFailedError expected) {
-      assertThat(expected.getMessage()).contains("create([[1]])");
+      assertThat(expected).hasMessageThat().contains("create([[1]])");
       return;
     }
     fail("should have failed");
@@ -335,7 +335,8 @@ public class ClassSanityTesterTest extends TestCase {
     try {
       tester.doTestEquals(ConstructorParameterWithOptionalNotInstantiable.class);
       fail();
-    } catch (ParameterHasNoDistinctValueException expected) {}
+    } catch (ParameterHasNoDistinctValueException expected) {
+    }
   }
 
   public void testGoodReferentialEqualityComparison() throws Exception {
@@ -344,6 +345,11 @@ public class ClassSanityTesterTest extends TestCase {
     tester.testEquals(SameListInstance.class);
   }
 
+  public void testStreamParameterSkippedForNullTesting() throws Exception {
+    tester.testNulls(WithStreamParameter.class);
+  }
+
+  @AndroidIncompatible // problem with equality of Type objects?
   public void testEqualsUsingReferentialEquality() throws Exception {
     assertBadUseOfReferentialEquality(SameIntegerInstance.class);
     assertBadUseOfReferentialEquality(SameLongInstance.class);
@@ -362,38 +368,42 @@ public class ClassSanityTesterTest extends TestCase {
     try {
       tester.testEquals(cls);
     } catch (AssertionFailedError expected) {
-      assertThat(expected.getMessage()).contains(cls.getSimpleName() + "(");
+      assertThat(expected).hasMessageThat().contains(cls.getSimpleName() + "(");
       return;
     }
-    fail("should have failed");
+    fail("should have failed for " + cls);
   }
 
   public void testParameterNotInstantiableForEqualsTest() throws Exception {
     try {
       tester.doTestEquals(ConstructorParameterNotInstantiable.class);
       fail("should have failed");
-    } catch (ParameterNotInstantiableException expected) {}
+    } catch (ParameterNotInstantiableException expected) {
+    }
   }
 
   public void testNoDistinctValueForEqualsTest() throws Exception {
     try {
       tester.doTestEquals(ConstructorParameterSingleValue.class);
       fail("should have failed");
-    } catch (ParameterHasNoDistinctValueException expected) {}
+    } catch (ParameterHasNoDistinctValueException expected) {
+    }
   }
 
   public void testConstructorThrowsForEqualsTest() throws Exception {
     try {
       tester.doTestEquals(ConstructorThrows.class);
       fail("should have failed");
-    } catch (InvocationTargetException expected) {}
+    } catch (InvocationTargetException expected) {
+    }
   }
 
   public void testFactoryMethodReturnsNullForEqualsTest() throws Exception {
     try {
       tester.doTestEquals(FactoryMethodReturnsNullAndAnnotated.class);
       fail("should have failed");
-    } catch (FactoryMethodReturnsNullException expected) {}
+    } catch (FactoryMethodReturnsNullException expected) {
+    }
   }
 
   public void testFactoryMethodReturnsNullButNotAnnotatedInEqualsTest() throws Exception {
@@ -416,15 +426,15 @@ public class ClassSanityTesterTest extends TestCase {
   }
 
   public void testNoEqualsChecksOnAnnotation() throws Exception {
-    tester.testEquals(Nullable.class);
+    tester.testEquals(MyAnnotation.class);
   }
 
   public void testGoodNulls() throws Exception {
     tester.testNulls(GoodNulls.class);
   }
 
-  public void testNoNullCheckNeededDespitNotInstantiable() throws Exception {
-    tester.doTestNulls(NoNullCheckNeededDespitNotInstantiable.class, Visibility.PACKAGE);
+  public void testNoNullCheckNeededDespiteNotInstantiable() throws Exception {
+    tester.doTestNulls(NoNullCheckNeededDespiteNotInstantiable.class, Visibility.PACKAGE);
   }
 
   public void testNulls_interface() {
@@ -459,7 +469,7 @@ public class ClassSanityTesterTest extends TestCase {
   }
 
   public void testNoNullChecksOnAnnotation() throws Exception {
-    tester.testNulls(Nullable.class);
+    tester.testNulls(MyAnnotation.class);
   }
 
   public void testBadNulls() throws Exception {
@@ -473,9 +483,10 @@ public class ClassSanityTesterTest extends TestCase {
 
   public void testInstantiate_factoryMethodReturnsNullButNotAnnotated() throws Exception {
     try {
-      tester.instantiate(FactoryMethodReturnsNullButNotAnnotated.class);
+      FactoryMethodReturnsNullButNotAnnotated unused =
+          tester.instantiate(FactoryMethodReturnsNullButNotAnnotated.class);
     } catch (AssertionFailedError expected) {
-      assertThat(expected.getMessage()).contains("@Nullable");
+      assertThat(expected).hasMessageThat().contains("@Nullable");
       return;
     }
     fail("should have failed");
@@ -485,7 +496,8 @@ public class ClassSanityTesterTest extends TestCase {
     try {
       tester.instantiate(FactoryMethodReturnsNullAndAnnotated.class);
       fail("should have failed");
-    } catch (FactoryMethodReturnsNullException expected) {}
+    } catch (FactoryMethodReturnsNullException expected) {
+    }
   }
 
   public void testInstantiate_factoryMethodAcceptsNull() throws Exception {
@@ -525,7 +537,7 @@ public class ClassSanityTesterTest extends TestCase {
   }
 
   public void testInstantiate_annotation() throws Exception {
-    assertNull(tester.instantiate(Nullable.class));
+    assertNull(tester.instantiate(MyAnnotation.class));
   }
 
   public void testInstantiate_setDefault() throws Exception {
@@ -538,7 +550,8 @@ public class ClassSanityTesterTest extends TestCase {
     try {
       tester.setDistinctValues(String.class, "", "");
       fail();
-    } catch (IllegalArgumentException expected) {}
+    } catch (IllegalArgumentException expected) {
+    }
   }
 
   public void testInstantiate_setDistinctValues() throws Exception {
@@ -549,46 +562,43 @@ public class ClassSanityTesterTest extends TestCase {
     tester.testEquals(ConstructorParameterMapOfNotInstantiable.class);
   }
 
-  public void testInstantiate_setSampleInstances_empty() throws Exception {
-    tester.setSampleInstances(NotInstantiable.class, ImmutableList.<NotInstantiable>of());
-    try {
-      tester.instantiate(ConstructorParameterNotInstantiable.class);
-      fail();
-    } catch (ParameterNotInstantiableException expected) {}
-  }
-
   public void testInstantiate_constructorThrows() throws Exception {
     try {
       tester.instantiate(ConstructorThrows.class);
       fail();
-    } catch (InvocationTargetException expected) {}
+    } catch (InvocationTargetException expected) {
+    }
   }
 
   public void testInstantiate_factoryMethodThrows() throws Exception {
     try {
       tester.instantiate(FactoryMethodThrows.class);
       fail();
-    } catch (InvocationTargetException expected) {}
+    } catch (InvocationTargetException expected) {
+    }
   }
 
   public void testInstantiate_constructorParameterNotInstantiable() throws Exception {
     try {
       tester.instantiate(ConstructorParameterNotInstantiable.class);
       fail();
-    } catch (ParameterNotInstantiableException expected) {}
+    } catch (ParameterNotInstantiableException expected) {
+    }
   }
 
   public void testInstantiate_factoryMethodParameterNotInstantiable() throws Exception {
     try {
       tester.instantiate(FactoryMethodParameterNotInstantiable.class);
       fail();
-    } catch (ParameterNotInstantiableException expected) {}
+    } catch (ParameterNotInstantiableException expected) {
+    }
   }
 
   public void testInstantiate_instantiableFactoryMethodChosen() throws Exception {
     assertEquals("good", tester.instantiate(InstantiableFactoryMethodChosen.class).name);
   }
 
+  @AndroidIncompatible // TODO(cpovirk): ClassNotFoundException... ClassSanityTesterTest$AnInterface
   public void testInterfaceProxySerializable() throws Exception {
     SerializableTester.reserializeAndAssert(tester.instantiate(HasAnInterface.class));
   }
@@ -601,7 +611,7 @@ public class ClassSanityTesterTest extends TestCase {
   private static class JdkObjectFactory {
     @SuppressWarnings("unused") // Called by reflection
     public static Object create() {
-      return new ArrayList<String>();
+      return new ArrayList<>();
     }
   }
 
@@ -612,7 +622,8 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = i;
     }
 
-    @Override public boolean equals(@Nullable Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof HasAnInterface) {
         HasAnInterface that = (HasAnInterface) obj;
         return i.equals(that.i);
@@ -621,7 +632,8 @@ public class ClassSanityTesterTest extends TestCase {
       }
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
   }
@@ -656,7 +668,8 @@ public class ClassSanityTesterTest extends TestCase {
     try {
       new ClassSanityTester().doTestEquals(SetWrapper.class);
       fail();
-    } catch (ParameterNotInstantiableException expected) {}
+    } catch (ParameterNotInstantiableException expected) {
+    }
   }
 
   private abstract static class Wrapper {
@@ -666,7 +679,8 @@ public class ClassSanityTesterTest extends TestCase {
       this.wrapped = checkNotNull(wrapped);
     }
 
-    @Override public boolean equals(@Nullable Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       // In general getClass().isInstance() is bad for equals.
       // But here we fully control the subclasses to ensure symmetry.
       if (getClass().isInstance(obj)) {
@@ -676,11 +690,13 @@ public class ClassSanityTesterTest extends TestCase {
       return false;
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return wrapped.hashCode();
     }
 
-    @Override public String toString() {
+    @Override
+    public String toString() {
       return wrapped.toString();
     }
   }
@@ -737,18 +753,19 @@ public class ClassSanityTesterTest extends TestCase {
       throw new RuntimeException();
     }
 
-    // keep trying
-    @SuppressWarnings("unused")
-    @Nullable public static GoodEquals createMayReturnNull(int a, int b) {
-      return null;
-    }
-
     // Good!
     static GoodEquals create(String a, int b) {
       return new GoodEquals(a, b);
     }
 
-    @Override public boolean equals(@Nullable Object obj) {
+    // keep trying
+    @SuppressWarnings("unused")
+    public static @Nullable GoodEquals createMayReturnNull(int a, int b) {
+      return null;
+    }
+
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof GoodEquals) {
         GoodEquals that = (GoodEquals) obj;
         return a.equals(that.a) && b == that.b;
@@ -757,7 +774,8 @@ public class ClassSanityTesterTest extends TestCase {
       }
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return 0;
     }
   }
@@ -770,11 +788,13 @@ public class ClassSanityTesterTest extends TestCase {
       return new BadEquals();
     }
 
-    @Override public boolean equals(@Nullable Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       return obj instanceof BadEquals;
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return 0;
     }
   }
@@ -786,13 +806,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
     @Override
-    @SuppressWarnings("NumericEquality")
-    public boolean equals(Object obj) {
+    @SuppressWarnings({"BoxedPrimitiveEquality", "NumericEquality"})
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameIntegerInstance) {
         SameIntegerInstance that = (SameIntegerInstance) obj;
         return i == that.i;
@@ -808,13 +829,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
     @Override
-    @SuppressWarnings("NumericEquality")
-    public boolean equals(Object obj) {
+    @SuppressWarnings({"BoxedPrimitiveEquality", "NumericEquality"})
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameLongInstance) {
         SameLongInstance that = (SameLongInstance) obj;
         return i == that.i;
@@ -830,13 +852,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
     @Override
-    @SuppressWarnings("NumericEquality")
-    public boolean equals(Object obj) {
+    @SuppressWarnings({"BoxedPrimitiveEquality", "NumericEquality"})
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameFloatInstance) {
         SameFloatInstance that = (SameFloatInstance) obj;
         return i == that.i;
@@ -852,13 +875,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
     @Override
-    @SuppressWarnings("NumericEquality")
-    public boolean equals(Object obj) {
+    @SuppressWarnings({"BoxedPrimitiveEquality", "NumericEquality"})
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameDoubleInstance) {
         SameDoubleInstance that = (SameDoubleInstance) obj;
         return i == that.i;
@@ -874,13 +898,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
     @Override
-    @SuppressWarnings("NumericEquality")
-    public boolean equals(Object obj) {
+    @SuppressWarnings({"BoxedPrimitiveEquality", "NumericEquality"})
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameShortInstance) {
         SameShortInstance that = (SameShortInstance) obj;
         return i == that.i;
@@ -896,13 +921,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
     @Override
-    @SuppressWarnings("NumericEquality")
-    public boolean equals(Object obj) {
+    @SuppressWarnings({"BoxedPrimitiveEquality", "NumericEquality"})
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameByteInstance) {
         SameByteInstance that = (SameByteInstance) obj;
         return i == that.i;
@@ -918,11 +944,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    @SuppressWarnings("BoxedPrimitiveEquality")
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameCharacterInstance) {
         SameCharacterInstance that = (SameCharacterInstance) obj;
         return i == that.i;
@@ -938,11 +967,14 @@ public class ClassSanityTesterTest extends TestCase {
       this.i = checkNotNull(i);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return i.hashCode();
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    @SuppressWarnings("BoxedPrimitiveEquality")
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameBooleanInstance) {
         SameBooleanInstance that = (SameBooleanInstance) obj;
         return i == that.i;
@@ -958,11 +990,13 @@ public class ClassSanityTesterTest extends TestCase {
       this.s = checkNotNull(s);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return s.hashCode();
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameStringInstance) {
         SameStringInstance that = (SameStringInstance) obj;
         return s == that.s;
@@ -978,11 +1012,13 @@ public class ClassSanityTesterTest extends TestCase {
       this.s = checkNotNull(s);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return s.hashCode();
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameObjectInstance) {
         SameObjectInstance that = (SameObjectInstance) obj;
         return s == that.s;
@@ -998,11 +1034,13 @@ public class ClassSanityTesterTest extends TestCase {
       this.s = checkNotNull(s);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return s.hashCode();
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameInterfaceInstance) {
         SameInterfaceInstance that = (SameInterfaceInstance) obj;
         return s == that.s;
@@ -1018,11 +1056,13 @@ public class ClassSanityTesterTest extends TestCase {
       this.s = checkNotNull(s);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return System.identityHashCode(s);
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof SameListInstance) {
         SameListInstance that = (SameListInstance) obj;
         return s == that.s;
@@ -1031,6 +1071,16 @@ public class ClassSanityTesterTest extends TestCase {
     }
   }
 
+  static class WithStreamParameter {
+    private final List<?> list;
+
+    // This should be ignored.
+    public WithStreamParameter(Stream<?> s, String str) {
+      this.list = s.collect(Collectors.toList());
+      checkNotNull(str);
+    }
+  }
+
   static class UsesReferentialEquality {
     private final ReferentialEquality s;
 
@@ -1038,11 +1088,13 @@ public class ClassSanityTesterTest extends TestCase {
       this.s = checkNotNull(s);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return s.hashCode();
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof UsesReferentialEquality) {
         UsesReferentialEquality that = (UsesReferentialEquality) obj;
         return s == that.s;
@@ -1058,11 +1110,13 @@ public class ClassSanityTesterTest extends TestCase {
       this.s = checkNotNull(s);
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return s.hashCode();
     }
 
-    @Override public boolean equals(Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof UsesEnum) {
         UsesEnum that = (UsesEnum) obj;
         return s == that.s;
@@ -1085,11 +1139,13 @@ public class ClassSanityTesterTest extends TestCase {
       return new BadEqualsWithParameterizedType();
     }
 
-    @Override public boolean equals(@Nullable Object obj) {
+    @Override
+    public boolean equals(@Nullable Object obj) {
       return obj instanceof BadEqualsWithParameterizedType;
     }
 
-    @Override public int hashCode() {
+    @Override
+    public int hashCode() {
       return 0;
     }
   }
@@ -1108,20 +1164,21 @@ public class ClassSanityTesterTest extends TestCase {
     public void failsToRejectNull(@SuppressWarnings("unused") String s) {}
   }
 
-  public static class NoNullCheckNeededDespitNotInstantiable {
+  public static class NoNullCheckNeededDespiteNotInstantiable {
 
-    public NoNullCheckNeededDespitNotInstantiable(NotInstantiable x) {
+    public NoNullCheckNeededDespiteNotInstantiable(NotInstantiable x) {
       checkNotNull(x);
     }
 
     @SuppressWarnings("unused") // reflected
     void primitiveOnly(int i) {}
 
-    @SuppressWarnings("unused") //reflected
+    @SuppressWarnings("unused") // reflected
     void nullableOnly(@Nullable String s) {}
+
     public void noParameter() {}
 
-    @SuppressWarnings("unused") //reflected
+    @SuppressWarnings("unused") // reflected
     void primitiveAndNullable(@Nullable String s, int i) {}
   }
 
@@ -1136,7 +1193,7 @@ public class ClassSanityTesterTest extends TestCase {
   static class FactoryMethodReturnsNullAndAnnotated {
     private FactoryMethodReturnsNullAndAnnotated() {}
 
-    @Nullable public static FactoryMethodReturnsNullAndAnnotated returnsNull() {
+    public static @Nullable FactoryMethodReturnsNullAndAnnotated returnsNull() {
       return null;
     }
   }
@@ -1191,19 +1248,22 @@ public class ClassSanityTesterTest extends TestCase {
 
   static class ConstructorParameterMapOfNotInstantiable {
     private final Map<NotInstantiable, NotInstantiable> m;
-    
-    public ConstructorParameterMapOfNotInstantiable(
-        Map<NotInstantiable, NotInstantiable> m) {
+
+    public ConstructorParameterMapOfNotInstantiable(Map<NotInstantiable, NotInstantiable> m) {
       this.m = checkNotNull(m);
     }
-    @Override public boolean equals(@Nullable Object obj) {
+
+    @Override
+    public boolean equals(@Nullable Object obj) {
       if (obj instanceof ConstructorParameterMapOfNotInstantiable) {
         return m.equals(((ConstructorParameterMapOfNotInstantiable) obj).m);
       } else {
         return false;
       }
     }
-    @Override public int hashCode() {
+
+    @Override
+    public int hashCode() {
       return m.hashCode();
     }
   }
@@ -1213,25 +1273,34 @@ public class ClassSanityTesterTest extends TestCase {
     public ConstructorParameterWithOptionalNotInstantiable(Optional<NotInstantiable> x) {
       checkNotNull(x);
     }
-    @Override public boolean equals(@Nullable Object obj) {
+
+    @Override
+    public boolean equals(@Nullable Object obj) {
       throw new UnsupportedOperationException();
     }
-    @Override public int hashCode() {
+
+    @Override
+    public int hashCode() {
       throw new UnsupportedOperationException();
     }
   }
 
   static class ConstructorParameterSingleValue {
     public ConstructorParameterSingleValue(@SuppressWarnings("unused") Singleton s) {}
-    @Override public boolean equals(Object obj) {
+
+    @Override
+    public boolean equals(@Nullable Object obj) {
       return obj instanceof ConstructorParameterSingleValue;
     }
-    @Override public int hashCode() {
+
+    @Override
+    public int hashCode() {
       return 1;
     }
 
     public static class Singleton {
       public static final Singleton INSTANCE = new Singleton();
+
       private Singleton() {}
     }
   }
@@ -1273,13 +1342,13 @@ public class ClassSanityTesterTest extends TestCase {
   private enum EnumFailsToCheckNull {
     A;
 
-    @SuppressWarnings("unused") 
+    @SuppressWarnings("unused")
     public void failToCheckNull(String s) {}
   }
 
   private interface AnInterface {}
 
-  private static abstract class AnAbstractClass {
+  private abstract static class AnAbstractClass {
     @SuppressWarnings("unused")
     public AnAbstractClass(String s) {}
 
@@ -1293,4 +1362,6 @@ public class ClassSanityTesterTest extends TestCase {
       return "";
     }
   }
+
+  @interface MyAnnotation {}
 }
