@@ -76,7 +76,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @author Justin T. Sampson
  * @param <E> the type of elements held in this collection
  */
-@CanIgnoreReturnValue // TODO(cpovirk): Consider being more strict.
 public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
     implements BlockingQueue<E> {
 
@@ -152,6 +151,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    *     in the priority queue according to the priority queue's ordering
    * @throws NullPointerException if the specified element is null
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean add(E e) {
     return offer(e);
@@ -166,6 +166,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    *     in the priority queue according to the priority queue's ordering
    * @throws NullPointerException if the specified element is null
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean offer(E e) {
     final Monitor monitor = this.monitor;
@@ -193,6 +194,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    *     in the priority queue according to the priority queue's ordering
    * @throws NullPointerException if the specified element is null
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean offer(E e, long timeout, TimeUnit unit) {
     checkNotNull(unit);
@@ -213,8 +215,9 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
     offer(e); // never need to block
   }
 
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
-  public E poll() {
+  public @Nullable E poll() {
     final Monitor monitor = this.monitor;
     monitor.enter();
     try {
@@ -224,8 +227,9 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
     }
   }
 
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
-  public E poll(long timeout, TimeUnit unit) throws InterruptedException {
+  public @Nullable E poll(long timeout, TimeUnit unit) throws InterruptedException {
     final Monitor monitor = this.monitor;
     if (monitor.enterWhen(notEmpty, timeout, unit)) {
       try {
@@ -238,6 +242,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
     }
   }
 
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public E take() throws InterruptedException {
     final Monitor monitor = this.monitor;
@@ -249,8 +254,9 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
     }
   }
 
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
-  public E peek() {
+  public @Nullable E peek() {
     final Monitor monitor = this.monitor;
     monitor.enter();
     try {
@@ -267,10 +273,12 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    * @return the comparator used to order the elements in this queue, or {@code null} if this queue
    *     uses the natural ordering of its elements
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   public Comparator<? super E> comparator() {
     return q.comparator();
   }
 
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public int size() {
     final Monitor monitor = this.monitor;
@@ -288,6 +296,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    *
    * @return {@code Integer.MAX_VALUE}
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public int remainingCapacity() {
     return Integer.MAX_VALUE;
@@ -302,6 +311,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    * @param o element to be removed from this queue, if present
    * @return {@code true} if this queue changed as a result of the call
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean remove(@Nullable Object o) {
     final Monitor monitor = this.monitor;
@@ -321,6 +331,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    * @param o object to be checked for containment in this queue
    * @return {@code true} if this queue contains the specified element
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public boolean contains(@Nullable Object o) {
     final Monitor monitor = this.monitor;
@@ -344,6 +355,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    *
    * @return an array containing all of the elements in this queue
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public Object[] toArray() {
     final Monitor monitor = this.monitor;
@@ -384,6 +396,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    *     the runtime type of every element in this queue
    * @throws NullPointerException if the specified array is null
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public <T> T[] toArray(T[] a) {
     final Monitor monitor = this.monitor;
@@ -395,6 +408,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
     }
   }
 
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public String toString() {
     final Monitor monitor = this.monitor;
@@ -412,6 +426,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    * @throws NullPointerException {@inheritDoc}
    * @throws IllegalArgumentException {@inheritDoc}
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public int drainTo(Collection<? super E> c) {
     if (c == null) throw new NullPointerException();
@@ -437,6 +452,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    * @throws NullPointerException {@inheritDoc}
    * @throws IllegalArgumentException {@inheritDoc}
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public int drainTo(Collection<? super E> c, int maxElements) {
     if (c == null) throw new NullPointerException();
@@ -481,6 +497,7 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
    *
    * @return an iterator over the elements in this queue
    */
+  @CanIgnoreReturnValue // pushed down from class to method
   @Override
   public Iterator<E> iterator() {
     return new Itr(toArray());
@@ -497,11 +514,13 @@ public class MonitorBasedPriorityBlockingQueue<E> extends AbstractQueue<E>
       this.array = array;
     }
 
+    @CanIgnoreReturnValue // pushed down from class to method
     @Override
     public boolean hasNext() {
       return cursor < array.length;
     }
 
+    @CanIgnoreReturnValue // pushed down from class to method
     @Override
     public E next() {
       if (cursor >= array.length) throw new NoSuchElementException();
