@@ -25,15 +25,20 @@ import java.net.URLClassLoader;
 import java.util.Arrays;
 import java.util.Collections;
 import junit.framework.TestCase;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Unit test for {@link FinalizableReferenceQueue}.
  *
  * @author Bob Lee
  */
+// - depends on details of GC and classloading
+// - .class files aren't available
+// - possibly no real concept of separate ClassLoaders?
+@AndroidIncompatible
 public class FinalizableReferenceQueueTest extends TestCase {
 
-  private FinalizableReferenceQueue frq;
+  private @Nullable FinalizableReferenceQueue frq;
 
   @Override
   protected void tearDown() throws Exception {
@@ -80,7 +85,7 @@ public class FinalizableReferenceQueueTest extends TestCase {
   }
 
   /** If we don't keep a strong reference to the reference object, it won't be enqueued. */
-  FinalizableWeakReference<Object> reference;
+  @Nullable FinalizableWeakReference<Object> reference;
 
   /** Create the FRQ in a method that goes out of scope so that we're sure it will be reclaimed. */
   private void weaklyReferenceQueue() {
@@ -102,7 +107,6 @@ public class FinalizableReferenceQueueTest extends TestCase {
         };
   }
 
-  @AndroidIncompatible // no concept of separate ClassLoaders
   public void testDecoupledLoader() {
     FinalizableReferenceQueue.DecoupledLoader decoupledLoader =
         new FinalizableReferenceQueue.DecoupledLoader() {
@@ -142,7 +146,6 @@ public class FinalizableReferenceQueueTest extends TestCase {
     }
   }
 
-  @AndroidIncompatible // TODO(cpovirk): How significant is this failure?
   public void testGetFinalizerUrl() {
     assertNotNull(getClass().getResource("internal/Finalizer.class"));
   }
