@@ -21,6 +21,7 @@ import static com.google.common.truth.Truth.assertThat;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.collect.FluentIterable;
 import com.google.common.collect.ImmutableList;
 import com.google.common.testing.EqualsTester;
@@ -29,12 +30,14 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Set;
 import junit.framework.TestCase;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Unit test for {@link Optional}.
  *
  * @author Kurt Alfred Kluever
  */
+@ElementTypesAreNonnullByDefault
 @GwtCompatible(emulated = true)
 public final class OptionalTest extends TestCase {
   public void testToJavaUtil_static() {
@@ -200,12 +203,13 @@ public final class OptionalTest extends TestCase {
       Optional<String> unused =
           Optional.of("a")
               .transform(
-                  new Function<String, String>() {
-                    @Override
-                    public String apply(String input) {
-                      return null;
-                    }
-                  });
+                  (Function<String, String>)
+                      new Function<String, @Nullable String>() {
+                        @Override
+                        public @Nullable String apply(String input) {
+                          return null;
+                        }
+                      });
       fail("Should throw if Function returns null.");
     } catch (NullPointerException expected) {
     }
@@ -216,12 +220,13 @@ public final class OptionalTest extends TestCase {
         Optional.absent(),
         Optional.absent()
             .transform(
-                new Function<Object, Object>() {
-                  @Override
-                  public Object apply(Object input) {
-                    return null;
-                  }
-                }));
+                (Function<Object, Object>)
+                    new Function<Object, @Nullable Object>() {
+                      @Override
+                      public @Nullable Object apply(Object input) {
+                        return null;
+                      }
+                    }));
   }
 
   public void testEqualsAndHashCode() {
@@ -315,6 +320,7 @@ public final class OptionalTest extends TestCase {
     Number value = first.or(0.5); // fine
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // NullPointerTester
   public void testNullPointers() {
     NullPointerTester npTester = new NullPointerTester();
