@@ -21,6 +21,7 @@ import static com.google.common.truth.Truth.assertThat;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.Splitter.MapSplitter;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.testing.NullPointerTester;
@@ -30,7 +31,10 @@ import java.util.Map;
 import java.util.regex.Pattern;
 import junit.framework.TestCase;
 
-/** @author Julien Silland */
+/**
+ * @author Julien Silland
+ */
+@ElementTypesAreNonnullByDefault
 @GwtCompatible(emulated = true)
 public class SplitterTest extends TestCase {
 
@@ -294,6 +298,7 @@ public class SplitterTest extends TestCase {
         .inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // Splitter.onPattern
   public void testPatternSimpleSplit() {
     String simple = "a,b,c";
@@ -301,6 +306,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "b", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // Splitter.onPattern
   public void testPatternSimpleSplitWithNoDelimiter() {
     String simple = "a,b,c";
@@ -308,6 +314,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a,b,c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // Splitter.onPattern
   public void testPatternSplitWithDoubleDelimiter() {
     String doubled = "a,,b,c";
@@ -315,6 +322,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "", "b", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // Splitter.onPattern
   public void testPatternSplitWithDoubleDelimiterAndSpace() {
     String doubled = "a,, b,c";
@@ -322,6 +330,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "", " b", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // Splitter.onPattern
   public void testPatternSplitWithTrailingDelimiter() {
     String trailing = "a,b,c,";
@@ -329,6 +338,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "b", "c", "").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // Splitter.onPattern
   public void testPatternSplitWithLeadingDelimiter() {
     String leading = ",a,b,c";
@@ -338,6 +348,7 @@ public class SplitterTest extends TestCase {
 
   // TODO(kevinb): the name of this method suggests it might not actually be testing what it
   // intends to be testing?
+  @J2ktIncompatible
   @GwtIncompatible // Splitter.onPattern
   public void testPatternSplitWithMultipleLetters() {
     Iterable<String> testPatterningMotto =
@@ -347,11 +358,13 @@ public class SplitterTest extends TestCase {
         .inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   private static Pattern literalDotPattern() {
     return Pattern.compile("\\.");
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitWithDoubleDelimiterOmitEmptyStrings() {
     String doubled = "a..b.c";
@@ -359,6 +372,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "b", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   @AndroidIncompatible // Bug in older versions of Android we test against, since fixed.
   public void testPatternSplitLookBehind() {
@@ -372,6 +386,7 @@ public class SplitterTest extends TestCase {
     // splits into chunks ending in :
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   @AndroidIncompatible // Bug in older versions of Android we test against, since fixed.
   public void testPatternSplitWordBoundary() {
@@ -380,6 +395,7 @@ public class SplitterTest extends TestCase {
     assertThat(words).containsExactly("foo", "<", "bar", ">", "bletch").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitWordBoundary_singleCharInput() {
     String string = "f";
@@ -388,6 +404,7 @@ public class SplitterTest extends TestCase {
   }
 
   @AndroidIncompatible // Apparently Gingerbread's regex API is buggy.
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitWordBoundary_singleWordInput() {
     String string = "foo";
@@ -395,6 +412,7 @@ public class SplitterTest extends TestCase {
     assertThat(words).containsExactly("foo").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitEmptyToken() {
     String emptyToken = "a. .c";
@@ -402,6 +420,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitEmptyTokenOmitEmptyStrings() {
     String emptyToken = "a. .c";
@@ -410,6 +429,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitOnOnlyDelimiter() {
     Iterable<String> blankblank = Splitter.on(literalDotPattern()).split(".");
@@ -417,12 +437,14 @@ public class SplitterTest extends TestCase {
     assertThat(blankblank).containsExactly("", "").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitOnOnlyDelimitersOmitEmptyStrings() {
     Iterable<String> empty = Splitter.on(literalDotPattern()).omitEmptyStrings().split("...");
     assertThat(empty).isEmpty();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitMatchingIsGreedy() {
     String longDelimiter = "a, b,   c";
@@ -430,6 +452,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "b", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitWithLongLeadingDelimiter() {
     String longDelimiter = ", a, b, c";
@@ -437,6 +460,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("", "a", "b", "c").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitWithLongTrailingDelimiter() {
     String longDelimiter = "a, b, c/ ";
@@ -444,6 +468,7 @@ public class SplitterTest extends TestCase {
     assertThat(letters).containsExactly("a", "b", "c", "").inOrder();
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitInvalidPattern() {
     try {
@@ -453,6 +478,7 @@ public class SplitterTest extends TestCase {
     }
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testPatternSplitWithTrim() {
     String jacksons =
@@ -474,6 +500,7 @@ public class SplitterTest extends TestCase {
     assertIteratorIsUnmodifiable(Splitter.on(",").split("a,b").iterator());
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   public void testSplitterIterableIsUnmodifiable_pattern() {
     assertIteratorIsUnmodifiable(Splitter.on(Pattern.compile(",")).split("a,b").iterator());
@@ -496,6 +523,7 @@ public class SplitterTest extends TestCase {
     assertSplitterIterableIsLazy(Splitter.on(","));
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // java.util.regex.Pattern
   @AndroidIncompatible // not clear that j.u.r.Matcher promises to handle mutations during use
   public void testSplitterIterableIsLazy_pattern() {
@@ -670,6 +698,7 @@ public class SplitterTest extends TestCase {
     }
   }
 
+  @J2ktIncompatible
   @GwtIncompatible // NullPointerTester
   public void testNullPointers() {
     NullPointerTester tester = new NullPointerTester();
