@@ -16,6 +16,8 @@
 
 package com.google.common.collect;
 
+import static com.google.common.collect.FluentIterableTest.Help.assertThat;
+import static com.google.common.collect.Lists.newArrayList;
 import static com.google.common.truth.Truth.assertThat;
 import static java.util.Arrays.asList;
 
@@ -29,10 +31,8 @@ import com.google.common.base.Predicates;
 import com.google.common.collect.testing.IteratorFeature;
 import com.google.common.collect.testing.IteratorTester;
 import com.google.common.testing.NullPointerTester;
-
-import junit.framework.AssertionFailedError;
-import junit.framework.TestCase;
-
+import com.google.common.truth.IterableSubject;
+import com.google.common.truth.Truth;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -40,26 +40,43 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 import java.util.SortedSet;
-
-import javax.annotation.Nullable;
+import java.util.concurrent.TimeUnit;
+import java.util.stream.Stream;
+import junit.framework.AssertionFailedError;
+import junit.framework.TestCase;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Unit test for {@link FluentIterable}.
  *
  * @author Marcin Mikosik
  */
-@SuppressWarnings("CheckReturnValue")
 @GwtCompatible(emulated = true)
 public class FluentIterableTest extends TestCase {
 
-  @GwtIncompatible("NullPointerTester")
+  @GwtIncompatible // NullPointerTester
   public void testNullPointerExceptions() {
     NullPointerTester tester = new NullPointerTester();
     tester.testAllPublicStaticMethods(FluentIterable.class);
   }
 
+  public void testFromArrayAndAppend() {
+    FluentIterable<TimeUnit> units =
+        FluentIterable.from(TimeUnit.values()).append(TimeUnit.SECONDS);
+  }
+
+  public void testFromArrayAndIteratorRemove() {
+    FluentIterable<TimeUnit> units = FluentIterable.from(TimeUnit.values());
+    try {
+      Iterables.removeIf(units, Predicates.equalTo(TimeUnit.SECONDS));
+      fail("Expected an UnsupportedOperationException to be thrown but it wasn't.");
+    } catch (UnsupportedOperationException expected) {
+    }
+  }
+
   public void testFrom() {
-    assertEquals(ImmutableList.of(1, 2, 3, 4),
+    assertEquals(
+        ImmutableList.of(1, 2, 3, 4),
         Lists.newArrayList(FluentIterable.from(ImmutableList.of(1, 2, 3, 4))));
   }
 
@@ -69,9 +86,114 @@ public class FluentIterableTest extends TestCase {
     assertSame(iterable, FluentIterable.from(iterable));
   }
 
-  public void testOfArray() {
-    assertEquals(ImmutableList.of("1", "2", "3", "4"),
-        Lists.newArrayList(FluentIterable.of(new Object[] {"1", "2", "3", "4"})));
+  public void testOf() {
+    assertEquals(ImmutableList.of(1, 2, 3, 4), Lists.newArrayList(FluentIterable.of(1, 2, 3, 4)));
+  }
+
+  public void testFromArray() {
+    assertEquals(
+        ImmutableList.of("1", "2", "3", "4"),
+        Lists.newArrayList(FluentIterable.from(new Object[] {"1", "2", "3", "4"})));
+  }
+
+  public void testOf_empty() {
+    assertEquals(ImmutableList.of(), Lists.newArrayList(FluentIterable.of()));
+  }
+
+  // Exhaustive tests are in IteratorsTest. These are copied from IterablesTest.
+  public void testConcatIterable() {
+    List<Integer> list1 = newArrayList(1);
+    List<Integer> list2 = newArrayList(4);
+
+    @SuppressWarnings("unchecked")
+    List<List<Integer>> input = newArrayList(list1, list2);
+
+    FluentIterable<Integer> result = FluentIterable.concat(input);
+    assertEquals(asList(1, 4), newArrayList(result));
+
+    // Now change the inputs and see result dynamically change as well
+
+    list1.add(2);
+    List<Integer> list3 = newArrayList(3);
+    input.add(1, list3);
+
+    assertEquals(asList(1, 2, 3, 4), newArrayList(result));
+    assertEquals("[1, 2, 3, 4]", result.toString());
+  }
+
+  public void testConcatVarargs() {
+    List<Integer> list1 = newArrayList(1);
+    List<Integer> list2 = newArrayList(4);
+    List<Integer> list3 = newArrayList(7, 8);
+    List<Integer> list4 = newArrayList(9);
+    List<Integer> list5 = newArrayList(10);
+    @SuppressWarnings("unchecked")
+    FluentIterable<Integer> result = FluentIterable.concat(list1, list2, list3, list4, list5);
+    assertEquals(asList(1, 4, 7, 8, 9, 10), newArrayList(result));
+    assertEquals("[1, 4, 7, 8, 9, 10]", result.toString());
+  }
+
+  public void testConcatNullPointerException() {
+    List<Integer> list1 = newArrayList(1);
+    List<Integer> list2 = newArrayList(4);
+
+    try {
+      FluentIterable.concat(list1, null, list2);
+      fail();
+    } catch (NullPointerException expected) {
+    }
+  }
+
+  public void testConcatPeformingFiniteCycle() {
+    Iterable<Integer> iterable = asList(1, 2, 3);
+    int n = 4;
+    FluentIterable<Integer> repeated = FluentIterable.concat(Collections.nCopies(n, iterable));
+    assertThat(repeated).containsExactly(1, 2, 3, 1, 2, 3, 1, 2, 3, 1, 2, 3).inOrder();
+  }
+
+  interface X {}
+
+  interface Y {}
+
+  static class A implements X, Y {}
+
+  static class B implements X, Y {}
+
+  /**
+   * This test passes if the {@code concat(…).filter(…).filter(…)} statement at the end compiles.
+   * That statement compiles only if {@link FluentIterable#concat concat(aIterable, bIterable)}
+   * returns a {@link FluentIterable} of elements of an anonymous type whose supertypes are the <a
+   * href="https://docs.oracle.com/javase/specs/jls/se7/html/jls-4.html#jls-4.9">intersection</a> of
+   * the supertypes of {@code A} and the supertypes of {@code B}.
+   */
+  public void testConcatIntersectionType() {
+    Iterable<A> aIterable = ImmutableList.of();
+    Iterable<B> bIterable = ImmutableList.of();
+
+    Predicate<X> xPredicate = Predicates.alwaysTrue();
+    Predicate<Y> yPredicate = Predicates.alwaysTrue();
+
+    FluentIterable<?> unused =
+        FluentIterable.concat(aIterable, bIterable).filter(xPredicate).filter(yPredicate);
+
+    /* The following fails to compile:
+     *
+     * The method append(Iterable<? extends FluentIterableTest.A>) in the type
+     * FluentIterable<FluentIterableTest.A> is not applicable for the arguments
+     * (Iterable<FluentIterableTest.B>)
+     */
+    // FluentIterable.from(aIterable).append(bIterable);
+
+    /* The following fails to compile:
+     *
+     * The method filter(Predicate<? super Object>) in the type FluentIterable<Object> is not
+     * applicable for the arguments (Predicate<FluentIterableTest.X>)
+     */
+    // FluentIterable.of().append(aIterable).append(bIterable).filter(xPredicate);
+  }
+
+  public void testSize0() {
+    assertEquals(0, FluentIterable.<String>of().size());
   }
 
   public void testSize1Collection() {
@@ -79,22 +201,25 @@ public class FluentIterableTest extends TestCase {
   }
 
   public void testSize2NonCollection() {
-    Iterable<Integer> iterable = new Iterable<Integer>() {
-      @Override
-      public Iterator<Integer> iterator() {
-        return asList(0, 1).iterator();
-      }
-    };
+    Iterable<Integer> iterable =
+        new Iterable<Integer>() {
+          @Override
+          public Iterator<Integer> iterator() {
+            return asList(0, 1).iterator();
+          }
+        };
     assertEquals(2, FluentIterable.from(iterable).size());
   }
 
   public void testSize_collectionDoesntIterate() {
     List<Integer> nums = asList(1, 2, 3, 4, 5);
-    List<Integer> collection = new ArrayList<Integer>(nums) {
-      @Override public Iterator<Integer> iterator() {
-        throw new AssertionFailedError("Don't iterate me!");
-      }
-    };
+    List<Integer> collection =
+        new ArrayList<Integer>(nums) {
+          @Override
+          public Iterator<Integer> iterator() {
+            throw new AssertionFailedError("Don't iterate me!");
+          }
+        };
     assertEquals(5, FluentIterable.from(collection).size());
   }
 
@@ -138,6 +263,18 @@ public class FluentIterableTest extends TestCase {
     assertFalse(FluentIterable.from(iterable).contains("c"));
   }
 
+  public void testOfToString() {
+    assertEquals("[yam, bam, jam, ham]", FluentIterable.of("yam", "bam", "jam", "ham").toString());
+  }
+
+  public void testToString() {
+    assertEquals("[]", FluentIterable.from(Collections.emptyList()).toString());
+    assertEquals("[]", FluentIterable.<String>of().toString());
+
+    assertEquals(
+        "[yam, bam, jam, ham]", FluentIterable.from(asList("yam", "bam", "jam", "ham")).toString());
+  }
+
   public void testCycle() {
     FluentIterable<String> cycle = FluentIterable.from(asList("a", "b")).cycle();
 
@@ -155,6 +292,11 @@ public class FluentIterableTest extends TestCase {
     assertEquals("a", cycle.iterator().next());
   }
 
+  public void testCycle_emptyIterable() {
+    FluentIterable<Integer> cycle = FluentIterable.<Integer>of().cycle();
+    assertFalse(cycle.iterator().hasNext());
+  }
+
   public void testCycle_removingAllElementsStopsCycle() {
     FluentIterable<Integer> cycle = fluent(1, 2).cycle();
     Iterator<Integer> iterator = cycle.iterator();
@@ -177,16 +319,22 @@ public class FluentIterableTest extends TestCase {
     assertEquals("[1, 2, 3, 4, 5, 6]", result.toString());
   }
 
+  public void testAppend_toEmpty() {
+    FluentIterable<Integer> result =
+        FluentIterable.<Integer>of().append(Lists.newArrayList(1, 2, 3));
+    assertEquals(asList(1, 2, 3), Lists.newArrayList(result));
+  }
+
   public void testAppend_emptyList() {
     FluentIterable<Integer> result =
         FluentIterable.<Integer>from(asList(1, 2, 3)).append(Lists.<Integer>newArrayList());
     assertEquals(asList(1, 2, 3), Lists.newArrayList(result));
   }
 
-  @SuppressWarnings("ReturnValueIgnored")
   public void testAppend_nullPointerException() {
     try {
-      FluentIterable.<Integer>from(asList(1, 2)).append((List<Integer>) null);
+      FluentIterable<Integer> unused =
+          FluentIterable.<Integer>from(asList(1, 2)).append((List<Integer>) null);
       fail("Appending null iterable should throw NPE.");
     } catch (NullPointerException expected) {
     }
@@ -212,10 +360,12 @@ public class FluentIterableTest extends TestCase {
   }
 
   private static class TypeA {}
+
   private interface TypeB {}
+
   private static class HasBoth extends TypeA implements TypeB {}
 
-  @GwtIncompatible("Iterables.filter(Iterable, Class)")
+  @GwtIncompatible // Iterables.filter(Iterable, Class)
   public void testFilterByType() throws Exception {
     HasBoth hasBoth = new HasBoth();
     FluentIterable<TypeA> alist =
@@ -265,8 +415,7 @@ public class FluentIterableTest extends TestCase {
 
   public void testTransformWith() {
     List<String> input = asList("1", "2", "3");
-    Iterable<Integer> iterable =
-        FluentIterable.from(input).transform(new IntegerValueOfFunction());
+    Iterable<Integer> iterable = FluentIterable.from(input).transform(new IntegerValueOfFunction());
 
     assertEquals(asList(1, 2, 3), Lists.newArrayList(iterable));
     assertCanIterateAgain(iterable);
@@ -275,8 +424,7 @@ public class FluentIterableTest extends TestCase {
 
   public void testTransformWith_poorlyBehavedTransform() {
     List<String> input = asList("1", null, "3");
-    Iterable<Integer> iterable =
-        FluentIterable.from(input).transform(new IntegerValueOfFunction());
+    Iterable<Integer> iterable = FluentIterable.from(input).transform(new IntegerValueOfFunction());
 
     Iterator<Integer> resultIterator = iterable.iterator();
     resultIterator.next();
@@ -329,7 +477,8 @@ public class FluentIterableTest extends TestCase {
 
   public void testTransformAndConcat_wildcardFunctionGenerics() {
     List<Integer> input = asList(1, 2, 3);
-    FluentIterable.from(input).transformAndConcat(new RepeatedStringValueOfWildcardFunction());
+    FluentIterable<String> unused =
+        FluentIterable.from(input).transformAndConcat(new RepeatedStringValueOfWildcardFunction());
   }
 
   public void testFirst_list() {
@@ -412,15 +561,15 @@ public class FluentIterableTest extends TestCase {
 
   public void testSkip_simple() {
     Collection<String> set = ImmutableSet.of("a", "b", "c", "d", "e");
-    assertEquals(Lists.newArrayList("c", "d", "e"),
-        Lists.newArrayList(FluentIterable.from(set).skip(2)));
+    assertEquals(
+        Lists.newArrayList("c", "d", "e"), Lists.newArrayList(FluentIterable.from(set).skip(2)));
     assertEquals("[c, d, e]", FluentIterable.from(set).skip(2).toString());
   }
 
   public void testSkip_simpleList() {
     Collection<String> list = Lists.newArrayList("a", "b", "c", "d", "e");
-    assertEquals(Lists.newArrayList("c", "d", "e"),
-        Lists.newArrayList(FluentIterable.from(list).skip(2)));
+    assertEquals(
+        Lists.newArrayList("c", "d", "e"), Lists.newArrayList(FluentIterable.from(list).skip(2)));
     assertEquals("[c, d, e]", FluentIterable.from(list).skip(2).toString());
   }
 
@@ -436,20 +585,24 @@ public class FluentIterableTest extends TestCase {
 
   public void testSkip_skipNone() {
     Collection<String> set = ImmutableSet.of("a", "b");
-    assertEquals(Lists.newArrayList("a", "b"),
-        Lists.newArrayList(FluentIterable.from(set).skip(0)));
+    assertEquals(
+        Lists.newArrayList("a", "b"), Lists.newArrayList(FluentIterable.from(set).skip(0)));
   }
 
   public void testSkip_skipNoneList() {
     Collection<String> list = Lists.newArrayList("a", "b");
-    assertEquals(Lists.newArrayList("a", "b"),
-        Lists.newArrayList(FluentIterable.from(list).skip(0)));
+    assertEquals(
+        Lists.newArrayList("a", "b"), Lists.newArrayList(FluentIterable.from(list).skip(0)));
   }
 
   public void testSkip_iterator() throws Exception {
-    new IteratorTester<Integer>(5, IteratorFeature.MODIFIABLE, Lists.newArrayList(2, 3),
+    new IteratorTester<Integer>(
+        5,
+        IteratorFeature.MODIFIABLE,
+        Lists.newArrayList(2, 3),
         IteratorTester.KnownOrder.KNOWN_ORDER) {
-      @Override protected Iterator<Integer> newTargetIterator() {
+      @Override
+      protected Iterator<Integer> newTargetIterator() {
         Collection<Integer> collection = Sets.newLinkedHashSet();
         Collections.addAll(collection, 1, 2, 3);
         return FluentIterable.from(collection).skip(1).iterator();
@@ -458,9 +611,13 @@ public class FluentIterableTest extends TestCase {
   }
 
   public void testSkip_iteratorList() throws Exception {
-    new IteratorTester<Integer>(5, IteratorFeature.MODIFIABLE, Lists.newArrayList(2, 3),
+    new IteratorTester<Integer>(
+        5,
+        IteratorFeature.MODIFIABLE,
+        Lists.newArrayList(2, 3),
         IteratorTester.KnownOrder.KNOWN_ORDER) {
-      @Override protected Iterator<Integer> newTargetIterator() {
+      @Override
+      protected Iterator<Integer> newTargetIterator() {
         return FluentIterable.from(Lists.newArrayList(1, 2, 3)).skip(1).iterator();
       }
     }.test();
@@ -509,7 +666,6 @@ public class FluentIterableTest extends TestCase {
     assertThat(tail).isEmpty();
   }
 
-  @SuppressWarnings("ReturnValueIgnored")
   public void testSkip_illegalArgument() {
     try {
       FluentIterable.from(asList("a", "b", "c")).skip(-1);
@@ -527,10 +683,10 @@ public class FluentIterableTest extends TestCase {
     assertEquals("[foo, bar]", limited.toString());
   }
 
-  @SuppressWarnings("ReturnValueIgnored")
   public void testLimit_illegalArgument() {
     try {
-      FluentIterable.from(Lists.newArrayList("a", "b", "c")).limit(-1);
+      FluentIterable<String> unused =
+          FluentIterable.from(Lists.newArrayList("a", "b", "c")).limit(-1);
       fail("Passing negative number to limit(...) method should throw IllegalArgumentException");
     } catch (IllegalArgumentException expected) {
     }
@@ -550,12 +706,14 @@ public class FluentIterableTest extends TestCase {
   }
 
   public void testToSortedList_withComparator() {
-    assertEquals(Lists.newArrayList(4, 3, 2, 1),
+    assertEquals(
+        Lists.newArrayList(4, 3, 2, 1),
         fluent(4, 1, 3, 2).toSortedList(Ordering.<Integer>natural().reverse()));
   }
 
   public void testToSortedList_withDuplicates() {
-    assertEquals(Lists.newArrayList(4, 3, 1, 1),
+    assertEquals(
+        Lists.newArrayList(4, 3, 1, 1),
         fluent(1, 4, 1, 3).toSortedList(Ordering.<Integer>natural().reverse()));
   }
 
@@ -573,12 +731,14 @@ public class FluentIterableTest extends TestCase {
 
   public void testToSortedSet() {
     assertThat(fluent(1, 4, 2, 3).toSortedSet(Ordering.<Integer>natural().reverse()))
-        .containsExactly(4, 3, 2, 1).inOrder();
+        .containsExactly(4, 3, 2, 1)
+        .inOrder();
   }
 
   public void testToSortedSet_removeDuplicates() {
     assertThat(fluent(1, 4, 1, 3).toSortedSet(Ordering.<Integer>natural().reverse()))
-        .containsExactly(4, 3, 1).inOrder();
+        .containsExactly(4, 3, 1)
+        .inOrder();
   }
 
   public void testToMultiset() {
@@ -592,9 +752,8 @@ public class FluentIterableTest extends TestCase {
   public void testToMap() {
     assertThat(fluent(1, 2, 3).toMap(Functions.toStringFunction()).entrySet())
         .containsExactly(
-            Maps.immutableEntry(1, "1"),
-            Maps.immutableEntry(2, "2"),
-            Maps.immutableEntry(3, "3")).inOrder();
+            Maps.immutableEntry(1, "1"), Maps.immutableEntry(2, "2"), Maps.immutableEntry(3, "3"))
+        .inOrder();
   }
 
   public void testToMap_nullKey() {
@@ -621,19 +780,21 @@ public class FluentIterableTest extends TestCase {
             .put(4, "four")
             .build();
     ImmutableListMultimap<Integer, String> index =
-        FluentIterable.from(asList("one", "two", "three", "four")).index(
-            new Function<String, Integer>() {
-              @Override
-              public Integer apply(String input) {
-                return input.length();
-              }
-            });
+        FluentIterable.from(asList("one", "two", "three", "four"))
+            .index(
+                new Function<String, Integer>() {
+                  @Override
+                  public Integer apply(String input) {
+                    return input.length();
+                  }
+                });
     assertEquals(expected, index);
   }
 
   public void testIndex_nullKey() {
     try {
-      fluent(1, 2, 3).index(Functions.constant(null));
+      ImmutableListMultimap<Object, Integer> unused =
+          fluent(1, 2, 3).index(Functions.constant(null));
       fail();
     } catch (NullPointerException expected) {
     }
@@ -641,35 +802,38 @@ public class FluentIterableTest extends TestCase {
 
   public void testIndex_nullValue() {
     try {
-      fluent(1, null, 2).index(Functions.constant("foo"));
+      ImmutableListMultimap<String, Integer> unused =
+          fluent(1, null, 2).index(Functions.constant("foo"));
       fail();
     } catch (NullPointerException expected) {
     }
   }
 
   public void testUniqueIndex() {
-    ImmutableMap<Integer, String> expected =
-        ImmutableMap.of(3, "two", 5, "three", 4, "four");
+    ImmutableMap<Integer, String> expected = ImmutableMap.of(3, "two", 5, "three", 4, "four");
     ImmutableMap<Integer, String> index =
-        FluentIterable.from(asList("two", "three", "four")).uniqueIndex(
-            new Function<String, Integer>() {
-              @Override
-              public Integer apply(String input) {
-                return input.length();
-              }
-            });
+        FluentIterable.from(asList("two", "three", "four"))
+            .uniqueIndex(
+                new Function<String, Integer>() {
+                  @Override
+                  public Integer apply(String input) {
+                    return input.length();
+                  }
+                });
     assertEquals(expected, index);
   }
 
   public void testUniqueIndex_duplicateKey() {
     try {
-      FluentIterable.from(asList("one", "two", "three", "four")).uniqueIndex(
-          new Function<String, Integer>() {
-            @Override
-            public Integer apply(String input) {
-              return input.length();
-            }
-          });
+      ImmutableMap<Integer, String> unused =
+          FluentIterable.from(asList("one", "two", "three", "four"))
+              .uniqueIndex(
+                  new Function<String, Integer>() {
+                    @Override
+                    public Integer apply(String input) {
+                      return input.length();
+                    }
+                  });
       fail();
     } catch (IllegalArgumentException expected) {
     }
@@ -685,12 +849,15 @@ public class FluentIterableTest extends TestCase {
 
   public void testUniqueIndex_nullValue() {
     try {
-      fluent(1, null, 2).uniqueIndex(new Function<Integer, Object>() {
-        @Override
-        public Object apply(@Nullable Integer input) {
-          return String.valueOf(input);
-        }
-      });
+      ImmutableMap<Object, Integer> unused =
+          fluent(1, null, 2)
+              .uniqueIndex(
+                  new Function<Integer, Object>() {
+                    @Override
+                    public Object apply(@Nullable Integer input) {
+                      return String.valueOf(input);
+                    }
+                  });
       fail();
     } catch (NullPointerException expected) {
     }
@@ -698,32 +865,33 @@ public class FluentIterableTest extends TestCase {
 
   public void testCopyInto_List() {
     assertThat(fluent(1, 3, 5).copyInto(Lists.newArrayList(1, 2)))
-        .containsExactly(1, 2, 1, 3, 5).inOrder();
+        .containsExactly(1, 2, 1, 3, 5)
+        .inOrder();
   }
 
   public void testCopyInto_Set() {
-    assertThat(fluent(1, 3, 5).copyInto(Sets.newHashSet(1, 2)))
-        .containsExactly(1, 2, 3, 5);
+    assertThat(fluent(1, 3, 5).copyInto(Sets.newHashSet(1, 2))).containsExactly(1, 2, 3, 5);
   }
 
   public void testCopyInto_SetAllDuplicates() {
-    assertThat(fluent(1, 3, 5).copyInto(Sets.newHashSet(1, 2, 3, 5)))
-        .containsExactly(1, 2, 3, 5);
+    assertThat(fluent(1, 3, 5).copyInto(Sets.newHashSet(1, 2, 3, 5))).containsExactly(1, 2, 3, 5);
   }
 
   public void testCopyInto_NonCollection() {
     final ArrayList<Integer> list = Lists.newArrayList(1, 2, 3);
 
     final ArrayList<Integer> iterList = Lists.newArrayList(9, 8, 7);
-    Iterable<Integer> iterable = new Iterable<Integer>() {
-      @Override
-      public Iterator<Integer> iterator() {
-        return iterList.iterator();
-      }
-    };
+    Iterable<Integer> iterable =
+        new Iterable<Integer>() {
+          @Override
+          public Iterator<Integer> iterator() {
+            return iterList.iterator();
+          }
+        };
 
     assertThat(FluentIterable.from(iterable).copyInto(list))
-        .containsExactly(1, 2, 3, 9, 8, 7).inOrder();
+        .containsExactly(1, 2, 3, 9, 8, 7)
+        .inOrder();
   }
 
   public void testJoin() {
@@ -735,12 +903,9 @@ public class FluentIterableTest extends TestCase {
   }
 
   public void testGet() {
-    assertEquals("a", FluentIterable
-        .from(Lists.newArrayList("a", "b", "c")).get(0));
-    assertEquals("b", FluentIterable
-        .from(Lists.newArrayList("a", "b", "c")).get(1));
-    assertEquals("c", FluentIterable
-        .from(Lists.newArrayList("a", "b", "c")).get(2));
+    assertEquals("a", FluentIterable.from(Lists.newArrayList("a", "b", "c")).get(0));
+    assertEquals("b", FluentIterable.from(Lists.newArrayList("a", "b", "c")).get(1));
+    assertEquals("c", FluentIterable.from(Lists.newArrayList("a", "b", "c")).get(2));
   }
 
   public void testGet_outOfBounds() {
@@ -757,8 +922,27 @@ public class FluentIterableTest extends TestCase {
     }
   }
 
+  /*
+   * Full and proper black-box testing of a Stream-returning method is extremely involved, and is
+   * overkill when nearly all Streams are produced using well-tested JDK calls. So, we cheat and
+   * just test that the toArray() contents are as expected.
+   */
+  public void testStream() {
+    assertThat(FluentIterable.of().stream()).isEmpty();
+    assertThat(FluentIterable.of("a").stream()).containsExactly("a");
+    assertThat(FluentIterable.of(1, 2, 3).stream().filter(n -> n > 1)).containsExactly(2, 3);
+  }
+
+  // TODO(kevinb): add assertThat(Stream) to Truth?
+  static class Help {
+    static IterableSubject assertThat(Stream<?> stream) {
+      return Truth.assertThat(stream.toArray()).asList();
+    }
+  }
+
   private static void assertCanIterateAgain(Iterable<?> iterable) {
-    for (@SuppressWarnings("unused") Object obj : iterable) {
+    for (Object unused : iterable) {
+      // do nothing
     }
   }
 
