@@ -16,6 +16,7 @@
 
 package com.google.common.collect;
 
+import static com.google.common.collect.testing.Helpers.mapEntry;
 import static com.google.common.collect.testing.features.CollectionFeature.KNOWN_ORDER;
 import static com.google.common.collect.testing.features.CollectionFeature.SERIALIZABLE;
 import static com.google.common.collect.testing.features.MapFeature.ALLOWS_ANY_NULL_QUERIES;
@@ -23,22 +24,25 @@ import static com.google.common.truth.Truth.assertThat;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.base.Equivalence;
 import com.google.common.collect.ImmutableListMultimap.Builder;
 import com.google.common.collect.testing.features.CollectionSize;
 import com.google.common.collect.testing.google.ListMultimapTestSuiteBuilder;
 import com.google.common.collect.testing.google.TestStringListMultimapGenerator;
 import com.google.common.collect.testing.google.UnmodifiableCollectionTests;
+import com.google.common.testing.CollectorTester;
 import com.google.common.testing.EqualsTester;
+import com.google.common.testing.NullPointerTester;
 import com.google.common.testing.SerializableTester;
-
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Map.Entry;
+import java.util.function.BiPredicate;
+import java.util.stream.Collector;
+import junit.framework.Test;
+import junit.framework.TestCase;
+import junit.framework.TestSuite;
 
 /**
  * Tests for {@link ImmutableListMultimap}.
@@ -57,6 +61,7 @@ public class ImmutableListMultimapTest extends TestCase {
       return builder.build();
     }
   }
+
   public static class ImmutableListMultimapCopyOfEntriesGenerator
       extends TestStringListMultimapGenerator {
     @Override
@@ -65,39 +70,31 @@ public class ImmutableListMultimapTest extends TestCase {
     }
   }
 
-  @GwtIncompatible("suite")
+  @GwtIncompatible // suite
   public static Test suite() {
     TestSuite suite = new TestSuite();
-    suite.addTest(ListMultimapTestSuiteBuilder.using(new ImmutableListMultimapGenerator())
-      .named("ImmutableListMultimap")
-      .withFeatures(
-          ALLOWS_ANY_NULL_QUERIES,
-          SERIALIZABLE,
-          KNOWN_ORDER,
-          CollectionSize.ANY)
-      .createTestSuite());
-    suite.addTest(ListMultimapTestSuiteBuilder.using(
-            new ImmutableListMultimapCopyOfEntriesGenerator())
-        .named("ImmutableListMultimap.copyOf[Iterable<Entry>]")
-        .withFeatures(
-            ALLOWS_ANY_NULL_QUERIES,
-            SERIALIZABLE,
-            KNOWN_ORDER,
-            CollectionSize.ANY)
-        .createTestSuite());
+    suite.addTest(
+        ListMultimapTestSuiteBuilder.using(new ImmutableListMultimapGenerator())
+            .named("ImmutableListMultimap")
+            .withFeatures(ALLOWS_ANY_NULL_QUERIES, SERIALIZABLE, KNOWN_ORDER, CollectionSize.ANY)
+            .createTestSuite());
+    suite.addTest(
+        ListMultimapTestSuiteBuilder.using(new ImmutableListMultimapCopyOfEntriesGenerator())
+            .named("ImmutableListMultimap.copyOf[Iterable<Entry>]")
+            .withFeatures(ALLOWS_ANY_NULL_QUERIES, SERIALIZABLE, KNOWN_ORDER, CollectionSize.ANY)
+            .createTestSuite());
     suite.addTestSuite(ImmutableListMultimapTest.class);
     return suite;
   }
 
   public void testBuilder_withImmutableEntry() {
-    ImmutableListMultimap<String, Integer> multimap = new Builder<String, Integer>()
-        .put(Maps.immutableEntry("one", 1))
-        .build();
+    ImmutableListMultimap<String, Integer> multimap =
+        new Builder<String, Integer>().put(Maps.immutableEntry("one", 1)).build();
     assertEquals(Arrays.asList(1), multimap.get("one"));
   }
 
   public void testBuilder_withImmutableEntryAndNullContents() {
-    Builder<String, Integer> builder = new Builder<String, Integer>();
+    Builder<String, Integer> builder = new Builder<>();
     try {
       builder.put(Maps.immutableEntry("one", (Integer) null));
       fail();
@@ -115,18 +112,21 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilder_withMutableEntry() {
-    ImmutableListMultimap.Builder<String, Integer> builder =
-        new Builder<String, Integer>();
+    ImmutableListMultimap.Builder<String, Integer> builder = new Builder<>();
     final StringHolder holder = new StringHolder();
     holder.string = "one";
-    Entry<String, Integer> entry = new AbstractMapEntry<String, Integer>() {
-      @Override public String getKey() {
-        return holder.string;
-      }
-      @Override public Integer getValue() {
-        return 1;
-      }
-    };
+    Entry<String, Integer> entry =
+        new AbstractMapEntry<String, Integer>() {
+          @Override
+          public String getKey() {
+            return holder.string;
+          }
+
+          @Override
+          public Integer getValue() {
+            return 1;
+          }
+        };
 
     builder.put(entry);
     holder.string = "two";
@@ -134,8 +134,7 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilderPutAllIterable() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.putAll("foo", Arrays.asList(1, 2, 3));
     builder.putAll("bar", Arrays.asList(4, 5));
     builder.putAll("foo", Arrays.asList(6, 7));
@@ -146,8 +145,7 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilderPutAllVarargs() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.putAll("foo", 1, 2, 3);
     builder.putAll("bar", 4, 5);
     builder.putAll("foo", 6, 7);
@@ -167,8 +165,7 @@ public class ImmutableListMultimapTest extends TestCase {
     moreToPut.put("foo", 6);
     moreToPut.put("bar", 5);
     moreToPut.put("foo", 7);
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.putAll(toPut);
     builder.putAll(moreToPut);
     Multimap<String, Integer> multimap = builder.build();
@@ -178,8 +175,7 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilderPutAllWithDuplicates() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.putAll("foo", 1, 2, 3);
     builder.putAll("bar", 4, 5);
     builder.putAll("foo", 1, 6, 7);
@@ -190,8 +186,7 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilderPutWithDuplicates() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.putAll("foo", 1, 2, 3);
     builder.putAll("bar", 4, 5);
     builder.put("foo", 1);
@@ -213,8 +208,7 @@ public class ImmutableListMultimapTest extends TestCase {
     moreToPut.put("bar", 4);
     moreToPut.put("foo", 7);
     moreToPut.put("foo", 2);
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.putAll(toPut);
     builder.putAll(moreToPut);
     Multimap<String, Integer> multimap = builder.build();
@@ -226,52 +220,57 @@ public class ImmutableListMultimapTest extends TestCase {
   public void testBuilderPutNullKey() {
     Multimap<String, Integer> toPut = LinkedListMultimap.create();
     toPut.put("foo", null);
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     try {
       builder.put(null, 1);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
     try {
       builder.putAll(null, Arrays.asList(1, 2, 3));
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
     try {
       builder.putAll(null, 1, 2, 3);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
     try {
       builder.putAll(toPut);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
   }
 
   public void testBuilderPutNullValue() {
     Multimap<String, Integer> toPut = LinkedListMultimap.create();
     toPut.put(null, 1);
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     try {
       builder.put("foo", null);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
     try {
       builder.putAll("foo", Arrays.asList(1, null, 3));
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
     try {
       builder.putAll("foo", 1, null, 3);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
     try {
       builder.putAll(toPut);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
   }
 
   public void testBuilderOrderKeysBy() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.put("b", 3);
     builder.put("d", 2);
     builder.put("a", 5);
@@ -287,17 +286,17 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilderOrderKeysByDuplicates() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.put("bb", 3);
     builder.put("d", 2);
     builder.put("a", 5);
-    builder.orderKeysBy(new Ordering<String>() {
-      @Override
-      public int compare(String left, String right) {
-        return left.length() - right.length();
-      }
-    });
+    builder.orderKeysBy(
+        new Ordering<String>() {
+          @Override
+          public int compare(String left, String right) {
+            return left.length() - right.length();
+          }
+        });
     builder.put("cc", 4);
     builder.put("a", 2);
     builder.put("bb", 6);
@@ -309,8 +308,7 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilderOrderValuesBy() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.put("b", 3);
     builder.put("d", 2);
     builder.put("a", 5);
@@ -326,8 +324,7 @@ public class ImmutableListMultimapTest extends TestCase {
   }
 
   public void testBuilderOrderKeysAndValuesBy() {
-    ImmutableListMultimap.Builder<String, Integer> builder
-        = ImmutableListMultimap.builder();
+    ImmutableListMultimap.Builder<String, Integer> builder = ImmutableListMultimap.builder();
     builder.put("b", 3);
     builder.put("d", 2);
     builder.put("a", 5);
@@ -382,7 +379,8 @@ public class ImmutableListMultimapTest extends TestCase {
     try {
       ImmutableListMultimap.copyOf(input);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
   }
 
   public void testCopyOfNullValue() {
@@ -391,7 +389,47 @@ public class ImmutableListMultimapTest extends TestCase {
     try {
       ImmutableListMultimap.copyOf(input);
       fail();
-    } catch (NullPointerException expected) {}
+    } catch (NullPointerException expected) {
+    }
+  }
+
+  public void testToImmutableListMultimap() {
+    Collector<Entry<String, Integer>, ?, ImmutableListMultimap<String, Integer>> collector =
+        ImmutableListMultimap.toImmutableListMultimap(Entry::getKey, Entry::getValue);
+    BiPredicate<ImmutableListMultimap<?, ?>, ImmutableListMultimap<?, ?>> equivalence =
+        Equivalence.equals()
+            .onResultOf((ImmutableListMultimap<?, ?> mm) -> mm.asMap().entrySet().asList())
+            .and(Equivalence.equals());
+    CollectorTester.of(collector, equivalence)
+        .expectCollects(ImmutableListMultimap.of())
+        .expectCollects(
+            ImmutableListMultimap.of("a", 1, "b", 2, "a", 3, "c", 4),
+            mapEntry("a", 1),
+            mapEntry("b", 2),
+            mapEntry("a", 3),
+            mapEntry("c", 4));
+  }
+
+  public void testFlatteningToImmutableListMultimap() {
+    Collector<String, ?, ImmutableListMultimap<Character, Character>> collector =
+        ImmutableListMultimap.flatteningToImmutableListMultimap(
+            str -> str.charAt(0), str -> str.substring(1).chars().mapToObj(c -> (char) c));
+    BiPredicate<Multimap<?, ?>, Multimap<?, ?>> equivalence =
+        Equivalence.equals()
+            .onResultOf((Multimap<?, ?> mm) -> ImmutableList.copyOf(mm.asMap().entrySet()))
+            .and(Equivalence.equals());
+    ImmutableListMultimap<Character, Character> empty = ImmutableListMultimap.of();
+    ImmutableListMultimap<Character, Character> filled =
+        ImmutableListMultimap.<Character, Character>builder()
+            .putAll('b', Arrays.asList('a', 'n', 'a', 'n', 'a'))
+            .putAll('a', Arrays.asList('p', 'p', 'l', 'e'))
+            .putAll('c', Arrays.asList('a', 'r', 'r', 'o', 't'))
+            .putAll('a', Arrays.asList('s', 'p', 'a', 'r', 'a', 'g', 'u', 's'))
+            .putAll('c', Arrays.asList('h', 'e', 'r', 'r', 'y'))
+            .build();
+    CollectorTester.of(collector, equivalence)
+        .expectCollects(empty)
+        .expectCollects(filled, "banana", "apple", "carrot", "asparagus", "cherry");
   }
 
   public void testEmptyMultimapReads() {
@@ -413,13 +451,15 @@ public class ImmutableListMultimapTest extends TestCase {
 
   public void testEmptyMultimapWrites() {
     Multimap<String, Integer> multimap = ImmutableListMultimap.of();
-    UnmodifiableCollectionTests.assertMultimapIsUnmodifiable(
-        multimap, "foo", 1);
+    UnmodifiableCollectionTests.assertMultimapIsUnmodifiable(multimap, "foo", 1);
   }
 
   private Multimap<String, Integer> createMultimap() {
     return ImmutableListMultimap.<String, Integer>builder()
-        .put("foo", 1).put("bar", 2).put("foo", 3).build();
+        .put("foo", 1)
+        .put("bar", 2)
+        .put("foo", 3)
+        .build();
   }
 
   public void testMultimapReads() {
@@ -439,56 +479,76 @@ public class ImmutableListMultimapTest extends TestCase {
 
   public void testMultimapWrites() {
     Multimap<String, Integer> multimap = createMultimap();
-    UnmodifiableCollectionTests.assertMultimapIsUnmodifiable(
-        multimap, "bar", 2);
+    UnmodifiableCollectionTests.assertMultimapIsUnmodifiable(multimap, "bar", 2);
   }
 
   public void testMultimapEquals() {
     Multimap<String, Integer> multimap = createMultimap();
-    Multimap<String, Integer> arrayListMultimap
-        = ArrayListMultimap.create();
+    Multimap<String, Integer> arrayListMultimap = ArrayListMultimap.create();
     arrayListMultimap.putAll("foo", Arrays.asList(1, 3));
     arrayListMultimap.put("bar", 2);
 
     new EqualsTester()
-        .addEqualityGroup(multimap, createMultimap(), arrayListMultimap,
+        .addEqualityGroup(
+            multimap,
+            createMultimap(),
+            arrayListMultimap,
             ImmutableListMultimap.<String, Integer>builder()
-                .put("bar", 2).put("foo", 1).put("foo", 3).build())
-        .addEqualityGroup(ImmutableListMultimap.<String, Integer>builder()
-            .put("bar", 2).put("foo", 3).put("foo", 1).build())
-        .addEqualityGroup(ImmutableListMultimap.<String, Integer>builder()
-            .put("foo", 2).put("foo", 3).put("foo", 1).build())
-        .addEqualityGroup(ImmutableListMultimap.<String, Integer>builder()
-            .put("bar", 2).put("foo", 3).build())
+                .put("bar", 2)
+                .put("foo", 1)
+                .put("foo", 3)
+                .build())
+        .addEqualityGroup(
+            ImmutableListMultimap.<String, Integer>builder()
+                .put("bar", 2)
+                .put("foo", 3)
+                .put("foo", 1)
+                .build())
+        .addEqualityGroup(
+            ImmutableListMultimap.<String, Integer>builder()
+                .put("foo", 2)
+                .put("foo", 3)
+                .put("foo", 1)
+                .build())
+        .addEqualityGroup(
+            ImmutableListMultimap.<String, Integer>builder().put("bar", 2).put("foo", 3).build())
         .testEquals();
   }
 
   public void testOf() {
+    assertMultimapEquals(ImmutableListMultimap.of("one", 1), "one", 1);
+    assertMultimapEquals(ImmutableListMultimap.of("one", 1, "two", 2), "one", 1, "two", 2);
     assertMultimapEquals(
-        ImmutableListMultimap.of("one", 1),
-        "one", 1);
-    assertMultimapEquals(
-        ImmutableListMultimap.of("one", 1, "two", 2),
-        "one", 1, "two", 2);
-    assertMultimapEquals(
-        ImmutableListMultimap.of("one", 1, "two", 2, "three", 3),
-        "one", 1, "two", 2, "three", 3);
+        ImmutableListMultimap.of("one", 1, "two", 2, "three", 3), "one", 1, "two", 2, "three", 3);
     assertMultimapEquals(
         ImmutableListMultimap.of("one", 1, "two", 2, "three", 3, "four", 4),
-        "one", 1, "two", 2, "three", 3, "four", 4);
+        "one",
+        1,
+        "two",
+        2,
+        "three",
+        3,
+        "four",
+        4);
     assertMultimapEquals(
-        ImmutableListMultimap.of(
-            "one", 1, "two", 2, "three", 3, "four", 4, "five", 5),
-        "one", 1, "two", 2, "three", 3, "four", 4, "five", 5);
+        ImmutableListMultimap.of("one", 1, "two", 2, "three", 3, "four", 4, "five", 5),
+        "one",
+        1,
+        "two",
+        2,
+        "three",
+        3,
+        "four",
+        4,
+        "five",
+        5);
   }
 
   public void testInverse() {
     assertEquals(
         ImmutableListMultimap.<Integer, String>of(),
         ImmutableListMultimap.<String, Integer>of().inverse());
-    assertEquals(
-        ImmutableListMultimap.of(1, "one"),
-        ImmutableListMultimap.of("one", 1).inverse());
+    assertEquals(ImmutableListMultimap.of(1, "one"), ImmutableListMultimap.of("one", 1).inverse());
     assertEquals(
         ImmutableListMultimap.of(1, "one", 2, "two"),
         ImmutableListMultimap.of("one", 1, "two", 2).inverse());
@@ -514,8 +574,8 @@ public class ImmutableListMultimapTest extends TestCase {
     assertSame(multimap, multimap.inverse().inverse());
   }
 
-  private static <K, V> void assertMultimapEquals(Multimap<K, V> multimap,
-      Object... alternatingKeysAndValues) {
+  private static <K, V> void assertMultimapEquals(
+      Multimap<K, V> multimap, Object... alternatingKeysAndValues) {
     assertEquals(multimap.size(), alternatingKeysAndValues.length / 2);
     int i = 0;
     for (Entry<K, V> entry : multimap.entries()) {
@@ -524,25 +584,31 @@ public class ImmutableListMultimapTest extends TestCase {
     }
   }
 
-  @GwtIncompatible("SerializableTester")
+  @GwtIncompatible // SerializableTester
   public void testSerialization() {
     Multimap<String, Integer> multimap = createMultimap();
     SerializableTester.reserializeAndAssert(multimap);
-    assertEquals(multimap.size(),
-        SerializableTester.reserialize(multimap).size());
+    assertEquals(multimap.size(), SerializableTester.reserialize(multimap).size());
     SerializableTester.reserializeAndAssert(multimap.get("foo"));
     LenientSerializableTester.reserializeAndAssertLenient(multimap.keySet());
     LenientSerializableTester.reserializeAndAssertLenient(multimap.keys());
     SerializableTester.reserializeAndAssert(multimap.asMap());
-    Collection<Integer> valuesCopy
-        = SerializableTester.reserialize(multimap.values());
-    assertEquals(HashMultiset.create(multimap.values()),
-        HashMultiset.create(valuesCopy));
+    Collection<Integer> valuesCopy = SerializableTester.reserialize(multimap.values());
+    assertEquals(HashMultiset.create(multimap.values()), HashMultiset.create(valuesCopy));
   }
 
-  @GwtIncompatible("SerializableTester")
+  @GwtIncompatible // SerializableTester
   public void testEmptySerialization() {
     Multimap<String, Integer> multimap = ImmutableListMultimap.of();
     assertSame(multimap, SerializableTester.reserialize(multimap));
   }
+
+  @GwtIncompatible // reflection
+  public void testNulls() throws Exception {
+    NullPointerTester tester = new NullPointerTester();
+    tester.testAllPublicStaticMethods(ImmutableListMultimap.class);
+    tester.ignore(ImmutableListMultimap.class.getMethod("get", Object.class));
+    tester.testAllPublicInstanceMethods(ImmutableListMultimap.of());
+    tester.testAllPublicInstanceMethods(ImmutableListMultimap.of("a", 1));
+  }
 }
