@@ -32,6 +32,7 @@ import java.util.SortedSet;
 import java.util.TreeSet;
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * Tests for {@link Sets#synchronizedNavigableSet(NavigableSet)}.
@@ -51,7 +52,7 @@ public class SynchronizedNavigableSetTest extends TestCase {
 
   static class TestSet<E> extends SynchronizedSetTest.TestSet<E> implements NavigableSet<E> {
 
-    TestSet(NavigableSet<E> delegate, Object mutex) {
+    TestSet(NavigableSet<E> delegate, @Nullable Object mutex) {
       super(delegate, mutex);
     }
 
@@ -61,7 +62,7 @@ public class SynchronizedNavigableSetTest extends TestCase {
     }
 
     @Override
-    public E ceiling(E e) {
+    public @Nullable E ceiling(E e) {
       assertTrue(Thread.holdsLock(mutex));
       return delegate().ceiling(e);
     }
@@ -78,7 +79,7 @@ public class SynchronizedNavigableSetTest extends TestCase {
     }
 
     @Override
-    public E floor(E e) {
+    public @Nullable E floor(E e) {
       assertTrue(Thread.holdsLock(mutex));
       return delegate().floor(e);
     }
@@ -95,24 +96,24 @@ public class SynchronizedNavigableSetTest extends TestCase {
     }
 
     @Override
-    public E higher(E e) {
+    public @Nullable E higher(E e) {
       assertTrue(Thread.holdsLock(mutex));
       return delegate().higher(e);
     }
 
     @Override
-    public E lower(E e) {
+    public @Nullable E lower(E e) {
       return delegate().lower(e);
     }
 
     @Override
-    public E pollFirst() {
+    public @Nullable E pollFirst() {
       assertTrue(Thread.holdsLock(mutex));
       return delegate().pollFirst();
     }
 
     @Override
-    public E pollLast() {
+    public @Nullable E pollLast() {
       assertTrue(Thread.holdsLock(mutex));
       return delegate().pollLast();
     }
