@@ -27,9 +27,6 @@ import com.google.common.primitives.Ints;
 import com.google.common.testing.EqualsTester;
 import com.google.common.testing.NullPointerTester;
 import com.google.common.util.concurrent.AtomicLongMap;
-
-import junit.framework.TestCase;
-
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
 import java.nio.ByteBuffer;
@@ -37,10 +34,14 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Locale;
 import java.util.Random;
+import junit.framework.TestCase;
 
 /**
  * Unit tests for {@link Hashing}.
  *
+ * <p>TODO(b/33919189): Migrate repeated testing methods to {@link #HashTestUtils} and tweak unit
+ * tests to reference them from there.
+ *
  * @author Dimitris Andreou
  * @author Kurt Alfred Kluever
  */
@@ -119,10 +120,21 @@ public class HashingTest extends TestCase {
     HashTestUtils.checkNo2BitCharacteristics(Hashing.sipHash24());
     HashTestUtils.checkNoFunnels(Hashing.sipHash24());
     HashTestUtils.assertInvariants(Hashing.sipHash24());
-    assertEquals("Hashing.sipHash24(506097522914230528, 1084818905618843912)",
+    assertEquals(
+        "Hashing.sipHash24(506097522914230528, 1084818905618843912)",
         Hashing.sipHash24().toString());
   }
 
+  public void testFingerprint2011() {
+    HashTestUtils.check2BitAvalanche(Hashing.fingerprint2011(), 100, 0.4);
+    HashTestUtils.checkAvalanche(Hashing.fingerprint2011(), 100, 0.4);
+    HashTestUtils.checkNo2BitCharacteristics(Hashing.fingerprint2011());
+    HashTestUtils.checkNoFunnels(Hashing.fingerprint2011());
+    HashTestUtils.assertInvariants(Hashing.fingerprint2011());
+    assertEquals("Hashing.fingerprint2011()", Hashing.fingerprint2011().toString());
+  }
+
+  @AndroidIncompatible // slow TODO(cpovirk): Maybe just reduce iterations under Android.
   public void testGoodFastHash() {
     for (int i = 1; i < 200; i += 17) {
       HashFunction hasher = Hashing.goodFastHash(i);
@@ -143,7 +155,7 @@ public class HashingTest extends TestCase {
   // goodFastHash(128) uses Murmur3_128. Use the same epsilon bounds.
   public void testGoodFastHash128() {
     HashTestUtils.check2BitAvalanche(Hashing.goodFastHash(128), 250, 0.20);
-    HashTestUtils.checkAvalanche(Hashing.goodFastHash(128), 250, 0.17);
+    HashTestUtils.checkAvalanche(Hashing.goodFastHash(128), 500, 0.17);
     HashTestUtils.checkNo2BitCharacteristics(Hashing.goodFastHash(128));
     HashTestUtils.checkNoFunnels(Hashing.goodFastHash(128));
     HashTestUtils.assertInvariants(Hashing.goodFastHash(128));
@@ -152,14 +164,14 @@ public class HashingTest extends TestCase {
   // goodFastHash(256) uses Murmur3_128. Use the same epsilon bounds.
   public void testGoodFastHash256() {
     HashTestUtils.check2BitAvalanche(Hashing.goodFastHash(256), 250, 0.20);
-    HashTestUtils.checkAvalanche(Hashing.goodFastHash(256), 250, 0.17);
+    HashTestUtils.checkAvalanche(Hashing.goodFastHash(256), 500, 0.17);
     HashTestUtils.checkNo2BitCharacteristics(Hashing.goodFastHash(256));
     HashTestUtils.checkNoFunnels(Hashing.goodFastHash(256));
     HashTestUtils.assertInvariants(Hashing.goodFastHash(256));
   }
 
   public void testConsistentHash_correctness() {
-    long[] interestingValues = { -1, 0, 1, 2, Long.MAX_VALUE, Long.MIN_VALUE };
+    long[] interestingValues = {-1, 0, 1, 2, Long.MAX_VALUE, Long.MIN_VALUE};
     for (long h : interestingValues) {
       checkConsistentHashCorrectness(h);
     }
@@ -206,7 +218,6 @@ public class HashingTest extends TestCase {
   private static final int ITERS = 10000;
   private static final int MAX_SHARDS = 500;
 
-  @SuppressWarnings("CheckReturnValue")
   public void testConsistentHash_outOfRange() {
     try {
       Hashing.consistentHash(5L, 0);
@@ -226,13 +237,14 @@ public class HashingTest extends TestCase {
   }
 
   /**
-   * Check a few "golden" values to see that implementations across languages
-   * are equivalent.
+   * Check a few "golden" values to see that implementations across languages are equivalent.
+   *
    */
   public void testConsistentHash_linearCongruentialGeneratorCompatibility() {
-    int[] golden100 =
-        { 0, 55, 62, 8, 45, 59, 86, 97, 82, 59,
-          73, 37, 17, 56, 86, 21, 90, 37, 38, 83 };
+    int[] golden100 = {
+      0, 55, 62, 8, 45, 59, 86, 97, 82, 59,
+      73, 37, 17, 56, 86, 21, 90, 37, 38, 83
+    };
     for (int i = 0; i < golden100.length; i++) {
       assertEquals(golden100[i], Hashing.consistentHash(i, 100));
     }
@@ -247,7 +259,6 @@ public class HashingTest extends TestCase {
   private static final double MAX_PERCENT_SPREAD = 0.5;
   private static final long RANDOM_SEED = 177L;
 
-  @SuppressWarnings("CheckReturnValue")
   public void testCombineOrdered_empty() {
     try {
       Hashing.combineOrdered(Collections.<HashCode>emptySet());
@@ -256,10 +267,10 @@ public class HashingTest extends TestCase {
     }
   }
 
-  @SuppressWarnings("CheckReturnValue")
   public void testCombineOrdered_differentBitLengths() {
     try {
-      Hashing.combineOrdered(ImmutableList.of(HashCode.fromInt(32), HashCode.fromLong(32L)));
+      HashCode unused =
+          Hashing.combineOrdered(ImmutableList.of(HashCode.fromInt(32), HashCode.fromLong(32L)));
       fail();
     } catch (IllegalArgumentException expected) {
     }
@@ -269,13 +280,15 @@ public class HashingTest extends TestCase {
     HashCode hash31 = HashCode.fromInt(31);
     HashCode hash32 = HashCode.fromInt(32);
     assertEquals(hash32, Hashing.combineOrdered(ImmutableList.of(hash32)));
-    assertEquals(HashCode.fromBytes(new byte[] { (byte) 0x80, 0, 0, 0 }),
+    assertEquals(
+        HashCode.fromBytes(new byte[] {(byte) 0x80, 0, 0, 0}),
         Hashing.combineOrdered(ImmutableList.of(hash32, hash32)));
-    assertEquals(HashCode.fromBytes(new byte[] { (byte) 0xa0, 0, 0, 0 }),
+    assertEquals(
+        HashCode.fromBytes(new byte[] {(byte) 0xa0, 0, 0, 0}),
         Hashing.combineOrdered(ImmutableList.of(hash32, hash32, hash32)));
     assertFalse(
-        Hashing.combineOrdered(ImmutableList.of(hash31, hash32)).equals(
-        Hashing.combineOrdered(ImmutableList.of(hash32, hash31))));
+        Hashing.combineOrdered(ImmutableList.of(hash31, hash32))
+            .equals(Hashing.combineOrdered(ImmutableList.of(hash32, hash31))));
   }
 
   public void testCombineOrdered_randomHashCodes() {
@@ -291,7 +304,6 @@ public class HashingTest extends TestCase {
     assertFalse(hashCode1.equals(hashCode2));
   }
 
-  @SuppressWarnings("CheckReturnValue")
   public void testCombineUnordered_empty() {
     try {
       Hashing.combineUnordered(Collections.<HashCode>emptySet());
@@ -300,10 +312,10 @@ public class HashingTest extends TestCase {
     }
   }
 
-  @SuppressWarnings("CheckReturnValue")
   public void testCombineUnordered_differentBitLengths() {
     try {
-      Hashing.combineUnordered(ImmutableList.of(HashCode.fromInt(32), HashCode.fromLong(32L)));
+      HashCode unused =
+          Hashing.combineUnordered(ImmutableList.of(HashCode.fromInt(32), HashCode.fromLong(32L)));
       fail();
     } catch (IllegalArgumentException expected) {
     }
@@ -314,8 +326,8 @@ public class HashingTest extends TestCase {
     HashCode hash32 = HashCode.fromInt(32);
     assertEquals(hash32, Hashing.combineUnordered(ImmutableList.of(hash32)));
     assertEquals(HashCode.fromInt(64), Hashing.combineUnordered(ImmutableList.of(hash32, hash32)));
-    assertEquals(HashCode.fromInt(96),
-        Hashing.combineUnordered(ImmutableList.of(hash32, hash32, hash32)));
+    assertEquals(
+        HashCode.fromInt(96), Hashing.combineUnordered(ImmutableList.of(hash32, hash32, hash32)));
     assertEquals(
         Hashing.combineUnordered(ImmutableList.of(hash31, hash32)),
         Hashing.combineUnordered(ImmutableList.of(hash32, hash31)));
@@ -360,8 +372,8 @@ public class HashingTest extends TestCase {
         Hashing.concatenating(asList(Hashing.md5(), Hashing.murmur3_32())).bits());
     assertEquals(
         Hashing.md5().bits() + Hashing.murmur3_32().bits() + Hashing.murmur3_128().bits(),
-        Hashing.concatenating(
-            asList(Hashing.md5(), Hashing.murmur3_32(), Hashing.murmur3_128())).bits());
+        Hashing.concatenating(asList(Hashing.md5(), Hashing.murmur3_32(), Hashing.murmur3_128()))
+            .bits());
   }
 
   public void testConcatenatingVarArgs_bits() {
@@ -385,10 +397,10 @@ public class HashingTest extends TestCase {
     buffer.put(murmur3Hash);
     HashCode expected = HashCode.fromBytes(combined);
 
-    assertEquals(expected,
-        Hashing.concatenating(Hashing.md5(), Hashing.murmur3_32()).hashLong(42L));
-    assertEquals(expected,
-        Hashing.concatenating(asList(Hashing.md5(), Hashing.murmur3_32())).hashLong(42L));
+    assertEquals(
+        expected, Hashing.concatenating(Hashing.md5(), Hashing.murmur3_32()).hashLong(42L));
+    assertEquals(
+        expected, Hashing.concatenating(asList(Hashing.md5(), Hashing.murmur3_32())).hashLong(42L));
   }
 
   public void testHashIntReverseBytesVsHashBytesIntsToByteArray() {
@@ -429,33 +441,54 @@ public class HashingTest extends TestCase {
           .put(Hashing.murmur3_32(), EMPTY_STRING, "00000000")
           .put(Hashing.murmur3_32(), TQBFJOTLD, "23f74f2e")
           .put(Hashing.murmur3_32(), TQBFJOTLDP, "fc8bc4d5")
+          .put(Hashing.murmur3_32_fixed(), EMPTY_STRING, "00000000")
+          .put(Hashing.murmur3_32_fixed(), TQBFJOTLD, "23f74f2e")
+          .put(Hashing.murmur3_32_fixed(), TQBFJOTLDP, "fc8bc4d5")
           .put(Hashing.sha1(), EMPTY_STRING, "da39a3ee5e6b4b0d3255bfef95601890afd80709")
           .put(Hashing.sha1(), TQBFJOTLD, "2fd4e1c67a2d28fced849ee1bb76e7391b93eb12")
           .put(Hashing.sha1(), TQBFJOTLDP, "408d94384216f890ff7a0c3528e8bed1e0b01621")
-          .put(Hashing.sha256(), EMPTY_STRING,
-               "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855")
-          .put(Hashing.sha256(), TQBFJOTLD,
-               "d7a8fbb307d7809469ca9abcb0082e4f8d5651e46d3cdb762d02d0bf37c9e592")
-          .put(Hashing.sha256(), TQBFJOTLDP,
-               "ef537f25c895bfa782526529a9b63d97aa631564d5d789c2b765448c8635fb6c")
-          .put(Hashing.sha384(), EMPTY_STRING,
-               "38b060a751ac96384cd9327eb1b1e36a21fdb71114be07434c0cc7bf63f6e1da2"
-               + "74edebfe76f65fbd51ad2f14898b95b")
-          .put(Hashing.sha384(), TQBFJOTLD,
-               "ca737f1014a48f4c0b6dd43cb177b0afd9e5169367544c494011e3317dbf9a509"
-               + "cb1e5dc1e85a941bbee3d7f2afbc9b1")
-          .put(Hashing.sha384(), TQBFJOTLDP,
-               "ed892481d8272ca6df370bf706e4d7bc1b5739fa2177aae6c50e946678718fc67"
-               + "a7af2819a021c2fc34e91bdb63409d7")
-          .put(Hashing.sha512(), EMPTY_STRING,
-               "cf83e1357eefb8bdf1542850d66d8007d620e4050b5715dc83f4a921d36ce9ce"
-               + "47d0d13c5d85f2b0ff8318d2877eec2f63b931bd47417a81a538327af927da3e")
-          .put(Hashing.sha512(), TQBFJOTLD,
-               "07e547d9586f6a73f73fbac0435ed76951218fb7d0c8d788a309d785436bbb64"
-               + "2e93a252a954f23912547d1e8a3b5ed6e1bfd7097821233fa0538f3db854fee6")
-          .put(Hashing.sha512(), TQBFJOTLDP,
-               "91ea1245f20d46ae9a037a989f54f1f790f0a47607eeb8a14d12890cea77a1bb"
-               + "c6c7ed9cf205e67b7f2b8fd4c7dfd3a7a8617e45f3c463d481c7e586c39ac1ed")
+          .put(
+              Hashing.sha256(),
+              EMPTY_STRING,
+              "e3b0c44298fc1c149afbf4c8996fb92427ae41e4649b934ca495991b7852b855")
+          .put(
+              Hashing.sha256(),
+              TQBFJOTLD,
+              "d7a8fbb307d7809469ca9abcb0082e4f8d5651e46d3cdb762d02d0bf37c9e592")
+          .put(
+              Hashing.sha256(),
+              TQBFJOTLDP,
+              "ef537f25c895bfa782526529a9b63d97aa631564d5d789c2b765448c8635fb6c")
+          .put(
+              Hashing.sha384(),
+              EMPTY_STRING,
+              "38b060a751ac96384cd9327eb1b1e36a21fdb71114be07434c0cc7bf63f6e1da2"
+                  + "74edebfe76f65fbd51ad2f14898b95b")
+          .put(
+              Hashing.sha384(),
+              TQBFJOTLD,
+              "ca737f1014a48f4c0b6dd43cb177b0afd9e5169367544c494011e3317dbf9a509"
+                  + "cb1e5dc1e85a941bbee3d7f2afbc9b1")
+          .put(
+              Hashing.sha384(),
+              TQBFJOTLDP,
+              "ed892481d8272ca6df370bf706e4d7bc1b5739fa2177aae6c50e946678718fc67"
+                  + "a7af2819a021c2fc34e91bdb63409d7")
+          .put(
+              Hashing.sha512(),
+              EMPTY_STRING,
+              "cf83e1357eefb8bdf1542850d66d8007d620e4050b5715dc83f4a921d36ce9ce"
+                  + "47d0d13c5d85f2b0ff8318d2877eec2f63b931bd47417a81a538327af927da3e")
+          .put(
+              Hashing.sha512(),
+              TQBFJOTLD,
+              "07e547d9586f6a73f73fbac0435ed76951218fb7d0c8d788a309d785436bbb64"
+                  + "2e93a252a954f23912547d1e8a3b5ed6e1bfd7097821233fa0538f3db854fee6")
+          .put(
+              Hashing.sha512(),
+              TQBFJOTLDP,
+              "91ea1245f20d46ae9a037a989f54f1f790f0a47607eeb8a14d12890cea77a1bb"
+                  + "c6c7ed9cf205e67b7f2b8fd4c7dfd3a7a8617e45f3c463d481c7e586c39ac1ed")
           .put(Hashing.crc32(), EMPTY_STRING, "00000000")
           .put(Hashing.crc32(), TQBFJOTLD, "39a34f41")
           .put(Hashing.crc32(), TQBFJOTLDP, "e9259051")
@@ -465,15 +498,25 @@ public class HashingTest extends TestCase {
           .put(Hashing.crc32c(), EMPTY_STRING, "00000000")
           .put(Hashing.crc32c(), TQBFJOTLD, "04046222")
           .put(Hashing.crc32c(), TQBFJOTLDP, "b3970019")
+          .put(Hashing.farmHashFingerprint64(), EMPTY_STRING, "4f40902f3b6ae19a")
+          .put(Hashing.farmHashFingerprint64(), TQBFJOTLD, "34511b3bf383beab")
+          .put(Hashing.farmHashFingerprint64(), TQBFJOTLDP, "737d7e5f8660653e")
+          .put(Hashing.fingerprint2011(), EMPTY_STRING, "e365a64a907cad23")
+          .put(Hashing.fingerprint2011(), TQBFJOTLD, "c9688c84e813b089")
+          .put(Hashing.fingerprint2011(), TQBFJOTLDP, "a714d70f1d569cd0")
           .build();
 
   public void testAllHashFunctionsHaveKnownHashes() throws Exception {
+    // The following legacy hashing function methods have been covered by unit testing already.
+    List<String> legacyHashingMethodNames = ImmutableList.of("murmur2_64", "fprint96");
     for (Method method : Hashing.class.getDeclaredMethods()) {
       if (method.getReturnType().equals(HashFunction.class) // must return HashFunction
           && Modifier.isPublic(method.getModifiers()) // only the public methods
-          && method.getParameterTypes().length == 0) { // only the seed-less grapes^W hash functions
+          && method.getParameterTypes().length == 0 // only the seed-less grapes^W hash functions
+          && !legacyHashingMethodNames.contains(method.getName())) {
         HashFunction hashFunction = (HashFunction) method.invoke(Hashing.class);
-        assertTrue("There should be at least 3 entries in KNOWN_HASHES for " + hashFunction,
+        assertTrue(
+            "There should be at least 3 entries in KNOWN_HASHES for " + hashFunction,
             KNOWN_HASHES.row(hashFunction).size() >= 3);
       }
     }
@@ -492,9 +535,10 @@ public class HashingTest extends TestCase {
   }
 
   public void testNullPointers() {
-    NullPointerTester tester = new NullPointerTester()
-        .setDefault(byte[].class, "secret key".getBytes(UTF_8))
-        .setDefault(HashCode.class, HashCode.fromLong(0));
+    NullPointerTester tester =
+        new NullPointerTester()
+            .setDefault(byte[].class, "secret key".getBytes(UTF_8))
+            .setDefault(HashCode.class, HashCode.fromLong(0));
     tester.testAllPublicStaticMethods(Hashing.class);
   }
 
@@ -544,9 +588,7 @@ public class HashingTest extends TestCase {
         HashFunction hashFunction1a = (HashFunction) method.invoke(clazz);
         HashFunction hashFunction1b = (HashFunction) method.invoke(clazz);
 
-        new EqualsTester()
-            .addEqualityGroup(hashFunction1a, hashFunction1b)
-            .testEquals();
+        new EqualsTester().addEqualityGroup(hashFunction1a, hashFunction1b).testEquals();
 
         // Make sure we're returning not only equal instances, but constants.
         assertSame(hashFunction1a, hashFunction1b);
@@ -591,4 +633,6 @@ public class HashingTest extends TestCase {
       }
     }
   }
+
+  // Parity tests taken from //util/hash/hash_unittest.cc
 }
