@@ -42,13 +42,19 @@ import junit.framework.TestSuite;
 /**
  * Unit test for {@link Files}.
  *
- * <p>Note: {@link Files#fileTraverser()} is tested in {@link FilesFileTraverserTest}.
+ * <p>Some methods are tested in separate files:
+ *
+ * <ul>
+ *   <li>{@link Files#fileTraverser()} is tested in {@link FilesFileTraverserTest}.
+ *   <li>{@link Files#createTempDir()} is tested in {@link FilesCreateTempDirTest}.
+ * </ul>
  *
  * @author Chris Nokleberg
  */
 
 public class FilesTest extends IoTestCase {
 
+  @AndroidIncompatible // suites, ByteSourceTester (b/230620681)
   public static TestSuite suite() {
     TestSuite suite = new TestSuite();
     suite.addTest(
@@ -357,14 +363,6 @@ public class FilesTest extends IoTestCase {
     }
   }
 
-  public void testCreateTempDir() {
-    File temp = Files.createTempDir();
-    assertTrue(temp.exists());
-    assertTrue(temp.isDirectory());
-    assertThat(temp.listFiles()).isEmpty();
-    assertTrue(temp.delete());
-  }
-
   public void testMove() throws IOException {
     File i18nFile = getTestFile("i18n.txt");
     File temp1 = createTempFile();
