@@ -17,6 +17,7 @@ package com.google.common.reflect;
 
 import static com.google.common.base.Charsets.US_ASCII;
 import static com.google.common.base.StandardSystemProperty.JAVA_CLASS_PATH;
+import static com.google.common.base.StandardSystemProperty.OS_NAME;
 import static com.google.common.base.StandardSystemProperty.PATH_SEPARATOR;
 import static com.google.common.io.MoreFiles.deleteRecursively;
 import static com.google.common.truth.Truth.assertThat;
@@ -184,6 +185,7 @@ public class ClassPathTest extends TestCase {
     assertThat(ClassPath.from(classloader).getTopLevelClasses()).isNotEmpty();
   }
 
+  @AndroidIncompatible // ClassPath is documented as not supporting Android
 
   public void testScan_classPathCycle() throws IOException {
     File jarFile = File.createTempFile("with_circular_class_path", ".jar");
@@ -201,6 +203,9 @@ public class ClassPathTest extends TestCase {
   @AndroidIncompatible // Path (for symlink creation)
 
   public void testScanDirectory_symlinkCycle() throws IOException {
+    if (isWindows()) {
+      return; // TODO: b/136041958 - Can we detect cycles under Windows?
+    }
     ClassLoader loader = ClassPathTest.class.getClassLoader();
     // directory with a cycle,
     // /root
@@ -233,6 +238,9 @@ public class ClassPathTest extends TestCase {
   @AndroidIncompatible // Path (for symlink creation)
 
   public void testScanDirectory_symlinkToRootCycle() throws IOException {
+    if (isWindows()) {
+      return; // TODO: b/136041958 - Can we detect cycles under Windows?
+    }
     ClassLoader loader = ClassPathTest.class.getClassLoader();
     // directory with a cycle,
     // /root
@@ -260,6 +268,7 @@ public class ClassPathTest extends TestCase {
         .isEmpty();
   }
 
+  @AndroidIncompatible // ClassPath is documented as not supporting Android
 
   public void testScanFromFile_notJarFile() throws IOException {
     ClassLoader classLoader = ClassPathTest.class.getClassLoader();
@@ -272,6 +281,9 @@ public class ClassPathTest extends TestCase {
   }
 
   public void testGetClassPathEntry() throws MalformedURLException, URISyntaxException {
+    if (isWindows()) {
+      return; // TODO: b/136041958 - We need to account for drive letters in the path.
+    }
     assertEquals(
         new File("/usr/test/dep.jar").toURI(),
         ClassPath.getClassPathEntry(new File("/home/build/outer.jar"), "file:/usr/test/dep.jar")
@@ -342,6 +354,9 @@ public class ClassPathTest extends TestCase {
   }
 
   public void testGetClassPathFromManifest_absoluteDirectory() throws IOException {
+    if (isWindows()) {
+      return; // TODO: b/136041958 - We need to account for drive letters in the path.
+    }
     File jarFile = new File("base/some.jar");
     Manifest manifest = manifestClasspath("file:/with/absolute/dir");
     assertThat(ClassPath.getClassPathFromManifest(jarFile, manifest))
@@ -349,6 +364,9 @@ public class ClassPathTest extends TestCase {
   }
 
   public void testGetClassPathFromManifest_absoluteJar() throws IOException {
+    if (isWindows()) {
+      return; // TODO: b/136041958 - We need to account for drive letters in the path.
+    }
     File jarFile = new File("base/some.jar");
     Manifest manifest = manifestClasspath("file:/with/absolute.jar");
     assertThat(ClassPath.getClassPathFromManifest(jarFile, manifest))
@@ -356,6 +374,9 @@ public class ClassPathTest extends TestCase {
   }
 
   public void testGetClassPathFromManifest_multiplePaths() throws IOException {
+    if (isWindows()) {
+      return; // TODO: b/136041958 - We need to account for drive letters in the path.
+    }
     File jarFile = new File("base/some.jar");
     Manifest manifest = manifestClasspath("file:/with/absolute.jar relative.jar  relative/dir");
     assertThat(ClassPath.getClassPathFromManifest(jarFile, manifest))
@@ -412,6 +433,9 @@ public class ClassPathTest extends TestCase {
 
 
   public void testGetClassPathUrls() throws Exception {
+    if (isWindows()) {
+      return; // TODO: b/136041958 - We need to account for drive letters in the path.
+    }
     String oldPathSeparator = PATH_SEPARATOR.value();
     String oldClassPath = JAVA_CLASS_PATH.value();
     System.setProperty(PATH_SEPARATOR.key(), ":");
@@ -458,6 +482,7 @@ public class ClassPathTest extends TestCase {
         .testAllPublicInstanceMethods(ClassPath.from(getClass().getClassLoader()));
   }
 
+  @AndroidIncompatible // ClassPath is documented as not supporting Android
 
   public void testLocationsFrom_idempotentScan() throws IOException {
     ImmutableSet<ClassPath.LocationInfo> locations =
@@ -488,6 +513,7 @@ public class ClassPathTest extends TestCase {
         .testEquals();
   }
 
+  @AndroidIncompatible // ClassPath is documented as not supporting Android
 
   public void testScanAllResources() throws IOException {
     assertThat(scanResourceNames(ClassLoader.getSystemClassLoader()))
@@ -602,6 +628,10 @@ public class ClassPathTest extends TestCase {
   }
 
   private static URL makeJarUrlWithName(String name) throws IOException {
+    /*
+     * TODO: cpovirk - Use java.nio.file.Files.createTempDirectory instead of
+     * c.g.c.io.Files.createTempDir?
+     */
     File fullPath = new File(Files.createTempDir(), name);
     File jarFile = pickAnyJarFile();
     Files.copy(jarFile, fullPath);
@@ -636,4 +666,8 @@ public class ClassPathTest extends TestCase {
     }
     return builder.build();
   }
+
+  private static boolean isWindows() {
+    return OS_NAME.value().startsWith("Windows");
+  }
 }
