@@ -49,10 +49,6 @@ import com.google.common.collect.ImmutableList;
 import com.google.common.collect.Lists;
 import com.google.common.testing.ClassSanityTester;
 import com.google.common.util.concurrent.MoreExecutors.Application;
-
-import org.mockito.InOrder;
-import org.mockito.Mockito;
-
 import java.lang.Thread.State;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -68,6 +64,7 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.concurrent.RejectedExecutionException;
+import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.ScheduledThreadPoolExecutor;
 import java.util.concurrent.ThreadFactory;
@@ -75,6 +72,9 @@ import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
+import org.checkerframework.checker.nullness.qual.Nullable;
+import org.mockito.InOrder;
+import org.mockito.Mockito;
 
 /**
  * Tests for MoreExecutors.
@@ -83,21 +83,22 @@ import java.util.concurrent.atomic.AtomicReference;
  */
 public class MoreExecutorsTest extends JSR166TestCase {
 
-  private static final Runnable EMPTY_RUNNABLE = new Runnable() {
-    @Override public void run() {}
-  };
+  private static final Runnable EMPTY_RUNNABLE =
+      new Runnable() {
+        @Override
+        public void run() {}
+      };
 
-  public void testDirectExecutorServiceServiceInThreadExecution()
-      throws Exception {
+  public void testDirectExecutorServiceServiceInThreadExecution() throws Exception {
     final ListeningExecutorService executor = newDirectExecutorService();
-    final ThreadLocal<Integer> threadLocalCount = new ThreadLocal<Integer>() {
-      @Override
-      protected Integer initialValue() {
-        return 0;
-      }
-    };
-    final AtomicReference<Throwable> throwableFromOtherThread =
-        new AtomicReference<Throwable>(null);
+    final ThreadLocal<Integer> threadLocalCount =
+        new ThreadLocal<Integer>() {
+          @Override
+          protected Integer initialValue() {
+            return 0;
+          }
+        };
+    final AtomicReference<Throwable> throwableFromOtherThread = new AtomicReference<>(null);
     final Runnable incrementTask =
         new Runnable() {
           @Override
@@ -106,19 +107,20 @@ public class MoreExecutorsTest extends JSR166TestCase {
           }
         };
 
-    Thread otherThread = new Thread(
-        new Runnable() {
-          @Override
-          public void run() {
-            try {
-              Future<?> future = executor.submit(incrementTask);
-              assertTrue(future.isDone());
-              assertEquals(1, threadLocalCount.get().intValue());
-            } catch (Throwable t) {
-              throwableFromOtherThread.set(t);
-            }
-          }
-        });
+    Thread otherThread =
+        new Thread(
+            new Runnable() {
+              @Override
+              public void run() {
+                try {
+                  Future<?> future = executor.submit(incrementTask);
+                  assertTrue(future.isDone());
+                  assertEquals(1, threadLocalCount.get().intValue());
+                } catch (Throwable t) {
+                  throwableFromOtherThread.set(t);
+                }
+              }
+            });
 
     otherThread.start();
 
@@ -129,31 +131,33 @@ public class MoreExecutorsTest extends JSR166TestCase {
     otherThread.join(1000);
     assertEquals(Thread.State.TERMINATED, otherThread.getState());
     Throwable throwable = throwableFromOtherThread.get();
-    assertNull("Throwable from other thread: "
-        + (throwable == null ? null : Throwables.getStackTraceAsString(throwable)),
+    assertNull(
+        "Throwable from other thread: "
+            + (throwable == null ? null : Throwables.getStackTraceAsString(throwable)),
         throwableFromOtherThread.get());
   }
 
   public void testDirectExecutorServiceInvokeAll() throws Exception {
     final ExecutorService executor = newDirectExecutorService();
-    final ThreadLocal<Integer> threadLocalCount = new ThreadLocal<Integer>() {
-      @Override
-      protected Integer initialValue() {
-        return 0;
-      }
-    };
+    final ThreadLocal<Integer> threadLocalCount =
+        new ThreadLocal<Integer>() {
+          @Override
+          protected Integer initialValue() {
+            return 0;
+          }
+        };
 
-    final Callable<Integer> incrementTask = new Callable<Integer>() {
-      @Override
-      public Integer call() {
-        int i = threadLocalCount.get();
-        threadLocalCount.set(i + 1);
-        return i;
-      }
-    };
+    final Callable<Integer> incrementTask =
+        new Callable<Integer>() {
+          @Override
+          public Integer call() {
+            int i = threadLocalCount.get();
+            threadLocalCount.set(i + 1);
+            return i;
+          }
+        };
 
-    List<Future<Integer>> futures =
-        executor.invokeAll(Collections.nCopies(10, incrementTask));
+    List<Future<Integer>> futures = executor.invokeAll(Collections.nCopies(10, incrementTask));
 
     for (int i = 0; i < 10; i++) {
       Future<Integer> future = futures.get(i);
@@ -164,43 +168,48 @@ public class MoreExecutorsTest extends JSR166TestCase {
     assertEquals(10, threadLocalCount.get().intValue());
   }
 
-  public void testDirectExecutorServiceServiceTermination()
-      throws Exception {
+  public void testDirectExecutorServiceServiceTermination() throws Exception {
     final ExecutorService executor = newDirectExecutorService();
     final CyclicBarrier barrier = new CyclicBarrier(2);
-    final AtomicReference<Throwable> throwableFromOtherThread =
-        new AtomicReference<Throwable>(null);
-    final Runnable doNothingRunnable = new Runnable() {
-        @Override public void run() {
-        }};
+    final AtomicReference<Throwable> throwableFromOtherThread = new AtomicReference<>(null);
+    final Runnable doNothingRunnable =
+        new Runnable() {
+          @Override
+          public void run() {}
+        };
 
-    Thread otherThread = new Thread(new Runnable() {
-      @Override
-      public void run() {
-        try {
-          Future<?> future = executor.submit(new Callable<Void>() {
-            @Override
-            public Void call() throws Exception {
-              // WAIT #1
-              barrier.await(1, TimeUnit.SECONDS);
+    Thread otherThread =
+        new Thread(
+            new Runnable() {
+              @Override
+              public void run() {
+                try {
+                  Future<?> future =
+                      executor.submit(
+                          new Callable<@Nullable Void>() {
+                            @Override
+                            public @Nullable Void call() throws Exception {
+                              // WAIT #1
+                              barrier.await(1, TimeUnit.SECONDS);
 
-              // WAIT #2
-              barrier.await(1, TimeUnit.SECONDS);
-              assertTrue(executor.isShutdown());
-              assertFalse(executor.isTerminated());
+                              // WAIT #2
+                              barrier.await(1, TimeUnit.SECONDS);
+                              assertTrue(executor.isShutdown());
+                              assertFalse(executor.isTerminated());
 
-              // WAIT #3
-              barrier.await(1, TimeUnit.SECONDS);
-              return null;
-            }
-          });
-          assertTrue(future.isDone());
-          assertTrue(executor.isShutdown());
-          assertTrue(executor.isTerminated());
-        } catch (Throwable t) {
-          throwableFromOtherThread.set(t);
-        }
-      }});
+                              // WAIT #3
+                              barrier.await(1, TimeUnit.SECONDS);
+                              return null;
+                            }
+                          });
+                  assertTrue(future.isDone());
+                  assertTrue(executor.isShutdown());
+                  assertTrue(executor.isTerminated());
+                } catch (Throwable t) {
+                  throwableFromOtherThread.set(t);
+                }
+              }
+            });
 
     otherThread.start();
 
@@ -239,27 +248,29 @@ public class MoreExecutorsTest extends JSR166TestCase {
     otherThread.join(1000);
     assertEquals(Thread.State.TERMINATED, otherThread.getState());
     Throwable throwable = throwableFromOtherThread.get();
-    assertNull("Throwable from other thread: "
-        + (throwable == null ? null : Throwables.getStackTraceAsString(throwable)),
+    assertNull(
+        "Throwable from other thread: "
+            + (throwable == null ? null : Throwables.getStackTraceAsString(throwable)),
         throwableFromOtherThread.get());
   }
 
   /**
-   * Test for a bug where threads weren't getting signaled when shutdown was called, only when
-   * tasks completed.
+   * Test for a bug where threads weren't getting signaled when shutdown was called, only when tasks
+   * completed.
    */
-
   public void testDirectExecutorService_awaitTermination_missedSignal() {
     final ExecutorService service = MoreExecutors.newDirectExecutorService();
-    Thread waiter = new Thread() {
-      @Override public void run() {
-        try {
-          service.awaitTermination(1, TimeUnit.DAYS);
-        } catch (InterruptedException e) {
-          return;
-        }
-      }
-    };
+    Thread waiter =
+        new Thread() {
+          @Override
+          public void run() {
+            try {
+              service.awaitTermination(1, TimeUnit.DAYS);
+            } catch (InterruptedException e) {
+              return;
+            }
+          }
+        };
     waiter.start();
     awaitTimedWaiting(waiter);
     service.shutdown();
@@ -301,23 +312,20 @@ public class MoreExecutorsTest extends JSR166TestCase {
     try {
       executor.execute(EMPTY_RUNNABLE);
       fail();
-    } catch (RejectedExecutionException expected) {}
+    } catch (RejectedExecutionException expected) {
+    }
   }
 
-  public <T> void testListeningExecutorServiceInvokeAllJavadocCodeCompiles()
-      throws Exception {
+  public <T> void testListeningExecutorServiceInvokeAllJavadocCodeCompiles() throws Exception {
     ListeningExecutorService executor = newDirectExecutorService();
     List<Callable<T>> tasks = ImmutableList.of();
-    @SuppressWarnings("unchecked") // guaranteed by invokeAll contract
-    List<ListenableFuture<T>> unused = (List) executor.invokeAll(tasks);
+    List<? extends Future<?>> unused = executor.invokeAll(tasks);
   }
 
   public void testListeningDecorator() throws Exception {
-    ListeningExecutorService service =
-        listeningDecorator(newDirectExecutorService());
+    ListeningExecutorService service = listeningDecorator(newDirectExecutorService());
     assertSame(service, listeningDecorator(service));
-    List<Callable<String>> callables =
-        ImmutableList.of(Callables.returning("x"));
+    List<Callable<String>> callables = ImmutableList.of(Callables.returning("x"));
     List<Future<String>> results;
 
     results = service.invokeAll(callables);
@@ -332,25 +340,28 @@ public class MoreExecutorsTest extends JSR166TestCase {
      */
   }
 
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
   public void testListeningDecorator_noWrapExecuteTask() {
     ExecutorService delegate = mock(ExecutorService.class);
     ListeningExecutorService service = listeningDecorator(delegate);
-    Runnable task = new Runnable() {
-      @Override
-      public void run() {}
-    };
+    Runnable task =
+        new Runnable() {
+          @Override
+          public void run() {}
+        };
     service.execute(task);
     verify(delegate).execute(task);
   }
 
   public void testListeningDecorator_scheduleSuccess() throws Exception {
     final CountDownLatch completed = new CountDownLatch(1);
-    ScheduledThreadPoolExecutor delegate = new ScheduledThreadPoolExecutor(1) {
-      @Override
-      protected void afterExecute(Runnable r, Throwable t) {
-        completed.countDown();
-      }
-    };
+    ScheduledThreadPoolExecutor delegate =
+        new ScheduledThreadPoolExecutor(1) {
+          @Override
+          protected void afterExecute(Runnable r, Throwable t) {
+            completed.countDown();
+          }
+        };
     ListeningScheduledExecutorService service = listeningDecorator(delegate);
     ListenableFuture<Integer> future =
         service.schedule(Callables.returning(42), 1, TimeUnit.MILLISECONDS);
@@ -404,9 +415,11 @@ public class MoreExecutorsTest extends JSR166TestCase {
     ListenableFuture<?> future;
     ScheduledFuture<?> delegateFuture;
 
-    Runnable runnable = new Runnable() {
-      @Override public void run() {}
-    };
+    Runnable runnable =
+        new Runnable() {
+          @Override
+          public void run() {}
+        };
 
     future = service.schedule(runnable, 5, TimeUnit.MINUTES);
     future.cancel(true);
@@ -455,86 +468,78 @@ public class MoreExecutorsTest extends JSR166TestCase {
       future.get();
       fail("Expected ExecutionException");
     } catch (ExecutionException e) {
-      assertSame(expectedCause, e.getCause());
+      assertThat(e).hasCauseThat().isSameInstanceAs(expectedCause);
     }
   }
 
-  /**
-   * invokeAny(null) throws NPE
-   */
+  /** invokeAny(null) throws NPE */
   public void testInvokeAnyImpl_nullTasks() throws Exception {
     ListeningExecutorService e = newDirectExecutorService();
     try {
-      invokeAnyImpl(e, null, false, 0);
-      shouldThrow();
+      invokeAnyImpl(e, null, false, 0, TimeUnit.NANOSECONDS);
+      fail();
     } catch (NullPointerException success) {
     } finally {
       joinPool(e);
     }
   }
 
-  /**
-   * invokeAny(empty collection) throws IAE
-   */
+  /** invokeAny(empty collection) throws IAE */
   public void testInvokeAnyImpl_emptyTasks() throws Exception {
     ListeningExecutorService e = newDirectExecutorService();
     try {
-      invokeAnyImpl(e, new ArrayList<Callable<String>>(), false, 0);
-      shouldThrow();
+      invokeAnyImpl(e, new ArrayList<Callable<String>>(), false, 0, TimeUnit.NANOSECONDS);
+      fail();
     } catch (IllegalArgumentException success) {
     } finally {
       joinPool(e);
     }
   }
 
-  /**
-   * invokeAny(c) throws NPE if c has null elements
-   */
+  /** invokeAny(c) throws NPE if c has null elements */
   public void testInvokeAnyImpl_nullElement() throws Exception {
     ListeningExecutorService e = newDirectExecutorService();
-    List<Callable<Integer>> l = new ArrayList<Callable<Integer>>();
-    l.add(new Callable<Integer>() {
-      @Override public Integer call() {
-          throw new ArithmeticException("/ by zero");
-      }
-    });
+    List<Callable<Integer>> l = new ArrayList<>();
+    l.add(
+        new Callable<Integer>() {
+          @Override
+          public Integer call() {
+            throw new ArithmeticException("/ by zero");
+          }
+        });
     l.add(null);
     try {
-      invokeAnyImpl(e, l, false, 0);
-      shouldThrow();
+      invokeAnyImpl(e, l, false, 0, TimeUnit.NANOSECONDS);
+      fail();
     } catch (NullPointerException success) {
     } finally {
       joinPool(e);
     }
   }
 
-  /**
-   * invokeAny(c) throws ExecutionException if no task in c completes
-   */
+  /** invokeAny(c) throws ExecutionException if no task in c completes */
   public void testInvokeAnyImpl_noTaskCompletes() throws Exception {
     ListeningExecutorService e = newDirectExecutorService();
-    List<Callable<String>> l = new ArrayList<Callable<String>>();
+    List<Callable<String>> l = new ArrayList<>();
     l.add(new NPETask());
     try {
-      invokeAnyImpl(e, l, false, 0);
-      shouldThrow();
+      invokeAnyImpl(e, l, false, 0, TimeUnit.NANOSECONDS);
+      fail();
     } catch (ExecutionException success) {
-      assertThat(success.getCause()).isInstanceOf(NullPointerException.class);
+      assertThat(success).hasCauseThat().isInstanceOf(NullPointerException.class);
     } finally {
       joinPool(e);
     }
   }
 
-  /**
-   * invokeAny(c) returns result of some task in c if at least one completes
-   */
+  /** invokeAny(c) returns result of some task in c if at least one completes */
   public void testInvokeAnyImpl() throws Exception {
     ListeningExecutorService e = newDirectExecutorService();
     try {
-      List<Callable<String>> l = new ArrayList<Callable<String>>();
+      List<Callable<String>> l = new ArrayList<>();
       l.add(new StringTask());
       l.add(new StringTask());
-      String result = invokeAnyImpl(e, l, false, 0);
+      String result = invokeAnyImpl(e, l, false, 0, TimeUnit.NANOSECONDS);
       assertSame(TEST_STRING, result);
     } finally {
       joinPool(e);
@@ -556,6 +561,7 @@ public class MoreExecutorsTest extends JSR166TestCase {
     }
   }
 
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
   public void testAddDelayedShutdownHook_success() throws InterruptedException {
     TestApplication application = new TestApplication();
     ExecutorService service = mock(ExecutorService.class);
@@ -567,6 +573,7 @@ public class MoreExecutorsTest extends JSR166TestCase {
     shutdownFirst.verify(service).awaitTermination(2, TimeUnit.SECONDS);
   }
 
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
   public void testAddDelayedShutdownHook_interrupted() throws InterruptedException {
     TestApplication application = new TestApplication();
     ExecutorService service = mock(ExecutorService.class);
@@ -576,15 +583,16 @@ public class MoreExecutorsTest extends JSR166TestCase {
     verify(service).shutdown();
   }
 
-  public void testGetExitingExcutorService_executorSetToUseDaemonThreads() {
+  public void testGetExitingExecutorService_executorSetToUseDaemonThreads() {
     TestApplication application = new TestApplication();
-    ThreadPoolExecutor executor = new ThreadPoolExecutor(
-        1, 2, 3, TimeUnit.SECONDS, new ArrayBlockingQueue<Runnable>(1));
+    ThreadPoolExecutor executor =
+        new ThreadPoolExecutor(1, 2, 3, TimeUnit.SECONDS, new ArrayBlockingQueue<Runnable>(1));
     assertNotNull(application.getExitingExecutorService(executor));
     assertTrue(executor.getThreadFactory().newThread(EMPTY_RUNNABLE).isDaemon());
   }
 
-  public void testGetExitingExcutorService_executorDelegatesToOriginal() {
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
+  public void testGetExitingExecutorService_executorDelegatesToOriginal() {
     TestApplication application = new TestApplication();
     ThreadPoolExecutor executor = mock(ThreadPoolExecutor.class);
     ThreadFactory threadFactory = mock(ThreadFactory.class);
@@ -593,24 +601,26 @@ public class MoreExecutorsTest extends JSR166TestCase {
     verify(executor).execute(EMPTY_RUNNABLE);
   }
 
-  public void testGetExitingExcutorService_shutdownHookRegistered() throws InterruptedException {
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
+  public void testGetExitingExecutorService_shutdownHookRegistered() throws InterruptedException {
     TestApplication application = new TestApplication();
     ThreadPoolExecutor executor = mock(ThreadPoolExecutor.class);
     ThreadFactory threadFactory = mock(ThreadFactory.class);
     when(executor.getThreadFactory()).thenReturn(threadFactory);
-    application.getExitingExecutorService(executor);
+    ExecutorService unused = application.getExitingExecutorService(executor);
     application.shutdown();
     verify(executor).shutdown();
   }
 
-  public void testGetExitingScheduledExcutorService_executorSetToUseDaemonThreads() {
+  public void testGetExitingScheduledExecutorService_executorSetToUseDaemonThreads() {
     TestApplication application = new TestApplication();
     ScheduledThreadPoolExecutor executor = new ScheduledThreadPoolExecutor(1);
     assertNotNull(application.getExitingScheduledExecutorService(executor));
     assertTrue(executor.getThreadFactory().newThread(EMPTY_RUNNABLE).isDaemon());
   }
 
-  public void testGetExitingScheduledExcutorService_executorDelegatesToOriginal() {
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
+  public void testGetExitingScheduledExecutorService_executorDelegatesToOriginal() {
     TestApplication application = new TestApplication();
     ScheduledThreadPoolExecutor executor = mock(ScheduledThreadPoolExecutor.class);
     ThreadFactory threadFactory = mock(ThreadFactory.class);
@@ -619,13 +629,14 @@ public class MoreExecutorsTest extends JSR166TestCase {
     verify(executor).execute(EMPTY_RUNNABLE);
   }
 
-  public void testGetScheduledExitingExcutorService_shutdownHookRegistered()
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
+  public void testGetScheduledExitingExecutorService_shutdownHookRegistered()
       throws InterruptedException {
     TestApplication application = new TestApplication();
     ScheduledThreadPoolExecutor executor = mock(ScheduledThreadPoolExecutor.class);
     ThreadFactory threadFactory = mock(ThreadFactory.class);
     when(executor.getThreadFactory()).thenReturn(threadFactory);
-    application.getExitingScheduledExecutorService(executor);
+    ScheduledExecutorService unused = application.getExitingScheduledExecutorService(executor);
     application.shutdown();
     verify(executor).shutdown();
   }
@@ -638,13 +649,16 @@ public class MoreExecutorsTest extends JSR166TestCase {
   }
 
   public void testThreadRenaming() {
-    Executor renamingExecutor = renamingDecorator(newDirectExecutorService(),
-        Suppliers.ofInstance("FooBar"));
+    Executor renamingExecutor =
+        renamingDecorator(newDirectExecutorService(), Suppliers.ofInstance("FooBar"));
     String oldName = Thread.currentThread().getName();
-    renamingExecutor.execute(new Runnable() {
-      @Override public void run() {
-        assertEquals("FooBar", Thread.currentThread().getName());
-      }});
+    renamingExecutor.execute(
+        new Runnable() {
+          @Override
+          public void run() {
+            assertEquals("FooBar", Thread.currentThread().getName());
+          }
+        });
     assertEquals(oldName, Thread.currentThread().getName());
   }
 
@@ -659,7 +673,8 @@ public class MoreExecutorsTest extends JSR166TestCase {
   private static class TestApplication extends Application {
     private final List<Thread> hooks = Lists.newArrayList();
 
-    @Override synchronized void addShutdownHook(Thread hook) {
+    @Override
+    synchronized void addShutdownHook(Thread hook) {
       hooks.add(hook);
     }
 
@@ -682,6 +697,7 @@ public class MoreExecutorsTest extends JSR166TestCase {
     assertTrue(service.isTerminated());
   }
 
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
   public void testShutdownAndAwaitTermination_immediateShutdownInternal() throws Exception {
     ExecutorService service = mock(ExecutorService.class);
     when(service.awaitTermination(HALF_SECOND_NANOS, NANOSECONDS)).thenReturn(true);
@@ -691,10 +707,12 @@ public class MoreExecutorsTest extends JSR166TestCase {
     verify(service).awaitTermination(HALF_SECOND_NANOS, NANOSECONDS);
   }
 
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
   public void testShutdownAndAwaitTermination_forcedShutDownInternal() throws Exception {
     ExecutorService service = mock(ExecutorService.class);
     when(service.awaitTermination(HALF_SECOND_NANOS, NANOSECONDS))
-        .thenReturn(false).thenReturn(true);
+        .thenReturn(false)
+        .thenReturn(true);
     when(service.isTerminated()).thenReturn(true);
     assertTrue(shutdownAndAwaitTermination(service, 1L, SECONDS));
     verify(service).shutdown();
@@ -702,16 +720,19 @@ public class MoreExecutorsTest extends JSR166TestCase {
     verify(service).shutdownNow();
   }
 
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
   public void testShutdownAndAwaitTermination_nonTerminationInternal() throws Exception {
     ExecutorService service = mock(ExecutorService.class);
     when(service.awaitTermination(HALF_SECOND_NANOS, NANOSECONDS))
-        .thenReturn(false).thenReturn(false);
+        .thenReturn(false)
+        .thenReturn(false);
     assertFalse(shutdownAndAwaitTermination(service, 1L, SECONDS));
     verify(service).shutdown();
     verify(service, times(2)).awaitTermination(HALF_SECOND_NANOS, NANOSECONDS);
     verify(service).shutdownNow();
   }
 
+  @AndroidIncompatible // Mocking ExecutorService is forbidden there. TODO(b/218700094): Don't mock.
   public void testShutdownAndAwaitTermination_interruptedInternal() throws Exception {
     final ExecutorService service = mock(ExecutorService.class);
     when(service.awaitTermination(HALF_SECOND_NANOS, NANOSECONDS))
@@ -722,13 +743,15 @@ public class MoreExecutorsTest extends JSR166TestCase {
     final AtomicBoolean interrupted = new AtomicBoolean();
     // we need to use another thread because it will be interrupted and thus using
     // the current one, owned by JUnit, would make the test fail
-    Thread thread = new Thread(new Runnable() {
-      @Override
-      public void run() {
-        terminated.set(shutdownAndAwaitTermination(service, 1L, SECONDS));
-        interrupted.set(Thread.currentThread().isInterrupted());
-      }
-    });
+    Thread thread =
+        new Thread(
+            new Runnable() {
+              @Override
+              public void run() {
+                terminated.set(shutdownAndAwaitTermination(service, 1L, SECONDS));
+                interrupted.set(Thread.currentThread().isInterrupted());
+              }
+            });
     thread.start();
     thread.join();
     verify(service).shutdown();
