@@ -33,6 +33,7 @@ import java.util.concurrent.Executors;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 import junit.framework.TestCase;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /** Test case for {@link TrustedListenableFutureTask}. */
 @GwtCompatible(emulated = true)
@@ -172,11 +173,11 @@ public class TrustedListenableFutureTaskTest extends TestCase {
   public void testToString() throws Exception {
     final CountDownLatch enterLatch = new CountDownLatch(1);
     final CountDownLatch exitLatch = new CountDownLatch(1);
-    final TrustedListenableFutureTask<Void> task =
+    final TrustedListenableFutureTask<@Nullable Void> task =
         TrustedListenableFutureTask.create(
-            new Callable<Void>() {
+            new Callable<@Nullable Void>() {
               @Override
-              public Void call() throws Exception {
+              public @Nullable Void call() throws Exception {
                 enterLatch.countDown();
                 new CountDownLatch(1).await(); // wait forever
                 return null;
@@ -205,7 +206,7 @@ public class TrustedListenableFutureTaskTest extends TestCase {
     exitLatch.await();
   }
 
-  @GwtIncompatible // used only in GwtIncomaptible tests
+  @GwtIncompatible // used only in GwtIncompatible tests
   private void awaitUnchecked(CyclicBarrier barrier) {
     try {
       barrier.await();
