@@ -1,30 +1,31 @@
 /*
  * Copyright (C) 2008 The Guava Authors
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the License at
  *
  * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
  */
 
 package com.google.common.base;
 
+import static com.google.common.base.NullnessCasts.uncheckedCastNullableTToT;
 import static com.google.common.base.Preconditions.checkNotNull;
 
-import com.google.common.annotations.Beta;
 import com.google.common.annotations.GwtCompatible;
-
+import com.google.errorprone.annotations.CheckReturnValue;
+import com.google.errorprone.annotations.ForOverride;
+import com.google.errorprone.annotations.InlineMe;
+import com.google.errorprone.annotations.concurrent.LazyInit;
+import com.google.j2objc.annotations.RetainedWith;
 import java.io.Serializable;
 import java.util.Iterator;
-
-import javax.annotation.Nullable;
+import javax.annotation.CheckForNull;
 
 /**
  * A function from {@code A} to {@code B} with an associated <i>reverse</i> function from {@code B}
@@ -34,14 +35,14 @@ import javax.annotation.Nullable;
  * <h3>Invertibility</h3>
  *
  * <p>The reverse operation <b>may</b> be a strict <i>inverse</i> (meaning that {@code
- * converter.reverse().convert(converter.convert(a)).equals(a)} is always true). However, it is
- * very common (perhaps <i>more</i> common) for round-trip conversion to be <i>lossy</i>. Consider
- * an example round-trip using {@link com.google.common.primitives.Doubles#stringConverter}:
+ * converter.reverse().convert(converter.convert(a)).equals(a)} is always true). However, it is very
+ * common (perhaps <i>more</i> common) for round-trip conversion to be <i>lossy</i>. Consider an
+ * example round-trip using {@link com.google.common.primitives.Doubles#stringConverter}:
  *
  * <ol>
- * <li>{@code stringConverter().convert("1.00")} returns the {@code Double} value {@code 1.0}
- * <li>{@code stringConverter().reverse().convert(1.0)} returns the string {@code "1.0"} --
- *     <i>not</i> the same string ({@code "1.00"}) we started with
+ *   <li>{@code stringConverter().convert("1.00")} returns the {@code Double} value {@code 1.0}
+ *   <li>{@code stringConverter().reverse().convert(1.0)} returns the string {@code "1.0"} --
+ *       <i>not</i> the same string ({@code "1.00"}) we started with
  * </ol>
  *
  * <p>Note that it should still be the case that the round-tripped and original objects are
@@ -56,77 +57,101 @@ import javax.annotation.Nullable;
  * behavior for all converters; implementations of {@link #doForward} and {@link #doBackward} are
  * guaranteed to never be passed {@code null}, and must never return {@code null}.
  *
-
  * <h3>Common ways to use</h3>
  *
  * <p>Getting a converter:
  *
  * <ul>
- * <li>Use a provided converter implementation, such as {@link Enums#stringConverter}, {@link
- *     com.google.common.primitives.Ints#stringConverter Ints.stringConverter} or the {@linkplain
- *     #reverse reverse} views of these.
- * <li>Convert between specific preset values using {@link
- *     com.google.common.collect.Maps#asConverter Maps.asConverter}. For example, use this to create
- *     a "fake" converter for a unit test. It is unnecessary (and confusing) to <i>mock</i> the
- *     {@code Converter} type using a mocking framework.
- * <li>Extend this class and implement its {@link #doForward} and {@link #doBackward} methods.
- * <li>If using Java 8, you may prefer to pass two lambda expressions or method references to {@link
- *     #from}.
+ *   <li>Use a provided converter implementation, such as {@link Enums#stringConverter}, {@link
+ *       com.google.common.primitives.Ints#stringConverter Ints.stringConverter} or the {@linkplain
+ *       #reverse reverse} views of these.
+ *   <li>Convert between specific preset values using {@link
+ *       com.google.common.collect.Maps#asConverter Maps.asConverter}. For example, use this to
+ *       create a "fake" converter for a unit test. It is unnecessary (and confusing) to <i>mock</i>
+ *       the {@code Converter} type using a mocking framework.
+ *   <li>Extend this class and implement its {@link #doForward} and {@link #doBackward} methods.
+ *   <li><b>Java 8 users:</b> you may prefer to pass two lambda expressions or method references to
+ *       the {@link #from from} factory method.
  * </ul>
  *
  * <p>Using a converter:
  *
  * <ul>
- * <li>Convert one instance in the "forward" direction using {@code converter.convert(a)}.
- * <li>Convert multiple instances "forward" using {@code converter.convertAll(as)}.
- * <li>Convert in the "backward" direction using {@code converter.reverse().convert(b)} or {@code
- *     converter.reverse().convertAll(bs)}.
- * <li>Use {@code converter} or {@code converter.reverse()} anywhere a {@link Function} is accepted
- * <li><b>Do not</b> call {@link #doForward} or {@link #doBackward} directly; these exist only to be
- *     overridden.
+ *   <li>Convert one instance in the "forward" direction using {@code converter.convert(a)}.
+ *   <li>Convert multiple instances "forward" using {@code converter.convertAll(as)}.
+ *   <li>Convert in the "backward" direction using {@code converter.reverse().convert(b)} or {@code
+ *       converter.reverse().convertAll(bs)}.
+ *   <li>Use {@code converter} or {@code converter.reverse()} anywhere a {@link
+ *       java.util.function.Function} is accepted (for example {@link java.util.stream.Stream#map
+ *       Stream.map}).
+ *   <li><b>Do not</b> call {@link #doForward} or {@link #doBackward} directly; these exist only to
+ *       be overridden.
  * </ul>
  *
  * <h3>Example</h3>
  *
- * <pre>   {@code
- *
- *   return new Converter<Integer, String>() {
- *     @Override
+ * <pre>
+ *   return new Converter&lt;Integer, String&gt;() {
  *     protected String doForward(Integer i) {
  *       return Integer.toHexString(i);
  *     }
  *
- *     @Override
  *     protected Integer doBackward(String s) {
  *       return parseUnsignedInt(s, 16);
  *     }
- *   };}</pre>
+ *   };</pre>
  *
- * <p>An alternative using Java 8: <pre>   {@code
+ * <p>An alternative using Java 8:
  *
- *   return Converter.from(Integer::toHexString, s -> parseUnsignedInt(s, 16));}</pre>
+ * <pre>{@code
+ * return Converter.from(
+ *     Integer::toHexString,
+ *     s -> parseUnsignedInt(s, 16));
+ * }</pre>
  *
  * @author Mike Ward
  * @author Kurt Alfred Kluever
  * @author Gregory Kick
  * @since 16.0
  */
-@Beta
 @GwtCompatible
+@ElementTypesAreNonnullByDefault
+/*
+ * 1. The type parameter is <T> rather than <T extends @Nullable> so that we can use T in the
+ * doForward and doBackward methods to indicate that the parameter cannot be null. (We also take
+ * advantage of that for convertAll, as discussed on that method.)
+ *
+ * 2. The supertype of this class could be `Function<@Nullable A, @Nullable B>`, since
+ * Converter.apply (like Converter.convert) is capable of accepting null inputs. However, a
+ * supertype of `Function<A, B>` turns out to be massively more useful to callers in practice: They
+ * want their output to be non-null in operations like `stream.map(myConverter)`, and we can
+ * guarantee that as long as we also require the input type to be non-null[*] (which is a
+ * requirement that existing callers already fulfill).
+ *
+ * Disclaimer: Part of the reason that callers are so well adapted to `Function<A, B>` may be that
+ * that is how the signature looked even prior to this comment! So naturally any change can break
+ * existing users, but it can't *fix* existing users because any users who needed
+ * `Function<@Nullable A, @Nullable B>` already had to find a workaround. Still, there is a *ton* of
+ * fallout from trying to switch. I would be shocked if the switch would offer benefits to anywhere
+ * near enough users to justify the costs.
+ *
+ * Fortunately, if anyone does want to use a Converter as a `Function<@Nullable A, @Nullable B>`,
+ * it's easy to get one: `converter::convert`.
+ *
+ * [*] In annotating this class, we're ignoring LegacyConverter.
+ */
 public abstract class Converter<A, B> implements Function<A, B> {
   private final boolean handleNullAutomatically;
 
   // We lazily cache the reverse view to avoid allocating on every call to reverse().
-  private transient Converter<B, A> reverse;
+  @LazyInit @RetainedWith @CheckForNull private transient Converter<B, A> reverse;
 
   /** Constructor for use by subclasses. */
   protected Converter() {
     this(true);
   }
 
-  /**
-   * Constructor used only by {@code LegacyConverter} to suspend automatic null-handling.
-   */
+  /** Constructor used only by {@code LegacyConverter} to suspend automatic null-handling. */
   Converter(boolean handleNullAutomatically) {
     this.handleNullAutomatically = handleNullAutomatically;
   }
@@ -140,6 +165,7 @@ public abstract class Converter<A, B> implements Function<A, B> {
    * @param a the instance to convert; will never be null
    * @return the converted instance; <b>must not</b> be null
    */
+  @ForOverride
   protected abstract B doForward(A a);
 
   /**
@@ -154,6 +180,7 @@ public abstract class Converter<A, B> implements Function<A, B> {
    *     then this is not logically a {@code Converter} at all, and should just implement {@link
    *     Function}.
    */
+  @ForOverride
   protected abstract A doBackward(B b);
 
   // API (consumer-side) methods
@@ -163,31 +190,67 @@ public abstract class Converter<A, B> implements Function<A, B> {
    *
    * @return the converted value; is null <i>if and only if</i> {@code a} is null
    */
-  @Nullable
-  public final B convert(@Nullable A a) {
+  @CheckForNull
+  public final B convert(@CheckForNull A a) {
     return correctedDoForward(a);
   }
 
-  @Nullable
-  B correctedDoForward(@Nullable A a) {
+  @CheckForNull
+  B correctedDoForward(@CheckForNull A a) {
     if (handleNullAutomatically) {
       // TODO(kevinb): we shouldn't be checking for a null result at runtime. Assert?
       return a == null ? null : checkNotNull(doForward(a));
     } else {
-      return doForward(a);
+      return unsafeDoForward(a);
     }
   }
 
-  @Nullable
-  A correctedDoBackward(@Nullable B b) {
+  @CheckForNull
+  A correctedDoBackward(@CheckForNull B b) {
     if (handleNullAutomatically) {
       // TODO(kevinb): we shouldn't be checking for a null result at runtime. Assert?
       return b == null ? null : checkNotNull(doBackward(b));
     } else {
-      return doBackward(b);
+      return unsafeDoBackward(b);
     }
   }
 
+  /*
+   * LegacyConverter violates the contract of Converter by allowing its doForward and doBackward
+   * methods to accept null. We could avoid having unchecked casts in Converter.java itself if we
+   * could perform a cast to LegacyConverter, but we can't because it's an internal-only class.
+   *
+   * TODO(cpovirk): So make it part of the open-source build, albeit package-private there?
+   *
+   * So we use uncheckedCastNullableTToT here. This is a weird usage of that method: The method is
+   * documented as being for use with type parameters that have parametric nullness. But Converter's
+   * type parameters do not. Still, we use it here so that we can suppress a warning at a smaller
+   * level than the whole method but without performing a runtime null check. That way, we can still
+   * pass null inputs to LegacyConverter, and it can violate the contract of Converter.
+   *
+   * TODO(cpovirk): Could this be simplified if we modified implementations of LegacyConverter to
+   * override methods (probably called "unsafeDoForward" and "unsafeDoBackward") with the same
+   * signatures as the methods below, rather than overriding the same doForward and doBackward
+   * methods as implementations of normal converters do?
+   *
+   * But no matter what we do, it's worth remembering that the resulting code is going to be unsound
+   * in the presence of LegacyConverter, at least in the case of users who view the converter as a
+   * Function<A, B> or who call convertAll (and for any checkers that apply @PolyNull-like semantics
+   * to Converter.convert). So maybe we don't want to think too hard about how to prevent our
+   * checkers from issuing errors related to LegacyConverter, since it turns out that
+   * LegacyConverter does violate the assumptions we make elsewhere.
+   */
+
+  @CheckForNull
+  private B unsafeDoForward(@CheckForNull A a) {
+    return doForward(uncheckedCastNullableTToT(a));
+  }
+
+  @CheckForNull
+  private A unsafeDoBackward(@CheckForNull B b) {
+    return doBackward(uncheckedCastNullableTToT(b));
+  }
+
   /**
    * Returns an iterable that applies {@code convert} to each element of {@code fromIterable}. The
    * conversion is done lazily.
@@ -196,7 +259,17 @@ public abstract class Converter<A, B> implements Function<A, B> {
    * a successful {@code remove()} call, {@code fromIterable} no longer contains the corresponding
    * element.
    */
-  public Iterable<B> convertAll(final Iterable<? extends A> fromIterable) {
+  /*
+   * Just as Converter could implement `Function<@Nullable A, @Nullable B>` instead of `Function<A,
+   * B>`, convertAll could accept and return iterables with nullable element types. In both cases,
+   * we've chosen to instead use a signature that benefits existing users -- and is still safe.
+   *
+   * For convertAll, I haven't looked as closely at *how* much existing users benefit, so we should
+   * keep an eye out for problems that new users encounter. Note also that convertAll could support
+   * both use cases by using @PolyNull. (By contrast, we can't use @PolyNull for our superinterface
+   * (`implements Function<@PolyNull A, @PolyNull B>`), at least as far as I know.)
+   */
+  public Iterable<B> convertAll(Iterable<? extends A> fromIterable) {
     checkNotNull(fromIterable, "fromIterable");
     return new Iterable<B>() {
       @Override
@@ -228,11 +301,13 @@ public abstract class Converter<A, B> implements Function<A, B> {
    * value roughly equivalent to {@code a}.
    *
    * <p>The returned converter is serializable if {@code this} converter is.
+   *
+   * <p><b>Note:</b> you should not override this method. It is non-final for legacy reasons.
    */
-  // TODO(kak): Make this method final
+  @CheckReturnValue
   public Converter<B, A> reverse() {
     Converter<B, A> result = reverse;
-    return (result == null) ? reverse = new ReverseConverter<A, B>(this) : result;
+    return (result == null) ? reverse = new ReverseConverter<>(this) : result;
   }
 
   private static final class ReverseConverter<A, B> extends Converter<B, A>
@@ -261,14 +336,14 @@ public abstract class Converter<A, B> implements Function<A, B> {
     }
 
     @Override
-    @Nullable
-    A correctedDoForward(@Nullable B b) {
+    @CheckForNull
+    A correctedDoForward(@CheckForNull B b) {
       return original.correctedDoBackward(b);
     }
 
     @Override
-    @Nullable
-    B correctedDoBackward(@Nullable A a) {
+    @CheckForNull
+    B correctedDoBackward(@CheckForNull A a) {
       return original.correctedDoForward(a);
     }
 
@@ -278,7 +353,7 @@ public abstract class Converter<A, B> implements Function<A, B> {
     }
 
     @Override
-    public boolean equals(@Nullable Object object) {
+    public boolean equals(@CheckForNull Object object) {
       if (object instanceof ReverseConverter) {
         ReverseConverter<?, ?> that = (ReverseConverter<?, ?>) object;
         return this.original.equals(that.original);
@@ -310,11 +385,9 @@ public abstract class Converter<A, B> implements Function<A, B> {
     return doAndThen(secondConverter);
   }
 
-  /**
-   * Package-private non-final implementation of andThen() so only we can override it.
-   */
+  /** Package-private non-final implementation of andThen() so only we can override it. */
   <C> Converter<A, C> doAndThen(Converter<B, C> secondConverter) {
-    return new ConverterComposition<A, B, C>(this, checkNotNull(secondConverter));
+    return new ConverterComposition<>(this, checkNotNull(secondConverter));
   }
 
   private static final class ConverterComposition<A, B, C> extends Converter<A, C>
@@ -345,19 +418,19 @@ public abstract class Converter<A, B> implements Function<A, B> {
     }
 
     @Override
-    @Nullable
-    C correctedDoForward(@Nullable A a) {
+    @CheckForNull
+    C correctedDoForward(@CheckForNull A a) {
       return second.correctedDoForward(first.correctedDoForward(a));
     }
 
     @Override
-    @Nullable
-    A correctedDoBackward(@Nullable C c) {
+    @CheckForNull
+    A correctedDoBackward(@CheckForNull C c) {
       return first.correctedDoBackward(second.correctedDoBackward(c));
     }
 
     @Override
-    public boolean equals(@Nullable Object object) {
+    public boolean equals(@CheckForNull Object object) {
       if (object instanceof ConverterComposition) {
         ConverterComposition<?, ?, ?> that = (ConverterComposition<?, ?, ?>) object;
         return this.first.equals(that.first) && this.second.equals(that.second);
@@ -383,8 +456,26 @@ public abstract class Converter<A, B> implements Function<A, B> {
    */
   @Deprecated
   @Override
-  @Nullable
-  public final B apply(@Nullable A a) {
+  @InlineMe(replacement = "this.convert(a)")
+  public final B apply(A a) {
+    /*
+     * Given that we declare this method as accepting and returning non-nullable values (because we
+     * implement Function<A, B>, as discussed in a class-level comment), it would make some sense to
+     * perform runtime null checks on the input and output. (That would also make NullPointerTester
+     * happy!) However, since we didn't do that for many years, we're not about to start now.
+     * (Runtime checks could be particularly bad for users of LegacyConverter.)
+     *
+     * Luckily, our nullness checker is smart enough to realize that `convert` has @PolyNull-like
+     * behavior, so it knows that `convert(a)` returns a non-nullable value, and we don't need to
+     * perform even a cast, much less a runtime check.
+     *
+     * All that said, don't forget that everyone should call converter.convert() instead of
+     * converter.apply(), anyway. If clients use only converter.convert(), then their nullness
+     * checkers are unlikely to ever look at the annotations on this declaration.
+     *
+     * Historical note: At one point, we'd declared this method as accepting and returning nullable
+     * values. For details on that, see earlier revisions of this file.
+     */
     return convert(a);
   }
 
@@ -400,17 +491,17 @@ public abstract class Converter<A, B> implements Function<A, B> {
    * interchangeable.
    */
   @Override
-  public boolean equals(@Nullable Object object) {
+  public boolean equals(@CheckForNull Object object) {
     return super.equals(object);
   }
 
   // Static converters
 
   /**
-   * Returns a converter based on <i>existing</i> forward and backward functions. Note that it is
-   * unnecessary to create <i>new</i> classes implementing {@code Function} just to pass them in
-   * here. Instead, simply subclass {@code Converter} and implement its {@link #doForward} and
-   * {@link #doBackward} methods directly.
+   * Returns a converter based on separate forward and backward functions. This is useful if the
+   * function instances already exist, or so that you can supply lambda expressions. If those
+   * circumstances don't apply, you probably don't need to use this; subclass {@code Converter} and
+   * implement its {@link #doForward} and {@link #doBackward} methods directly.
    *
    * <p>These functions will never be passed {@code null} and must not under any circumstances
    * return {@code null}. If a value cannot be converted, the function should throw an unchecked
@@ -423,7 +514,7 @@ public abstract class Converter<A, B> implements Function<A, B> {
   public static <A, B> Converter<A, B> from(
       Function<? super A, ? extends B> forwardFunction,
       Function<? super B, ? extends A> backwardFunction) {
-    return new FunctionBasedConverter<A, B>(forwardFunction, backwardFunction);
+    return new FunctionBasedConverter<>(forwardFunction, backwardFunction);
   }
 
   private static final class FunctionBasedConverter<A, B> extends Converter<A, B>
@@ -449,7 +540,7 @@ public abstract class Converter<A, B> implements Function<A, B> {
     }
 
     @Override
-    public boolean equals(@Nullable Object object) {
+    public boolean equals(@CheckForNull Object object) {
       if (object instanceof FunctionBasedConverter) {
         FunctionBasedConverter<?, ?> that = (FunctionBasedConverter<?, ?>) object;
         return this.forwardFunction.equals(that.forwardFunction)
@@ -469,9 +560,7 @@ public abstract class Converter<A, B> implements Function<A, B> {
     }
   }
 
-  /**
-   * Returns a serializable converter that always converts or reverses an object to itself.
-   */
+  /** Returns a serializable converter that always converts or reverses an object to itself. */
   @SuppressWarnings("unchecked") // implementation is "fully variant"
   public static <T> Converter<T, T> identity() {
     return (IdentityConverter<T>) IdentityConverter.INSTANCE;
@@ -482,7 +571,7 @@ public abstract class Converter<A, B> implements Function<A, B> {
    * "pass-through type".
    */
   private static final class IdentityConverter<T> extends Converter<T, T> implements Serializable {
-    static final IdentityConverter INSTANCE = new IdentityConverter();
+    static final IdentityConverter<?> INSTANCE = new IdentityConverter<>();
 
     @Override
     protected T doForward(T t) {
