@@ -1,44 +1,43 @@
 /*
  * Copyright (C) 2008 The Guava Authors
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the License at
  *
  * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
  */
 
 package com.google.common.base;
 
 import static com.google.common.base.Preconditions.checkNotNull;
+import static java.util.Objects.requireNonNull;
 
-import com.google.common.annotations.Beta;
 import com.google.common.annotations.GwtCompatible;
-
+import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.io.IOException;
 import java.util.AbstractList;
 import java.util.Arrays;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.Map.Entry;
-
-import javax.annotation.CheckReturnValue;
-import javax.annotation.Nullable;
+import javax.annotation.CheckForNull;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * An object which joins pieces of text (specified as an array, {@link Iterable}, varargs or even a
  * {@link Map}) with a separator. It either appends the results to an {@link Appendable} or returns
- * them as a {@link String}. Example: <pre>   {@code
+ * them as a {@link String}. Example:
  *
- *   Joiner joiner = Joiner.on("; ").skipNulls();
- *    . . .
- *   return joiner.join("Harry", null, "Ron", "Hermione");}</pre>
+ * <pre>{@code
+ * Joiner joiner = Joiner.on("; ").skipNulls();
+ *  . . .
+ * return joiner.join("Harry", null, "Ron", "Hermione");
+ * }</pre>
  *
  * <p>This returns the string {@code "Harry; Ron; Hermione"}. Note that all input elements are
  * converted to strings using {@link Object#toString()} before being appended.
@@ -49,33 +48,30 @@ import javax.annotation.Nullable;
  * <p><b>Warning: joiner instances are always immutable</b>; a configuration method such as {@code
  * useForNull} has no effect on the instance it is invoked on! You must store and use the new joiner
  * instance returned by the method. This makes joiners thread-safe, and safe to store as {@code
- * static final} constants. <pre>   {@code
+ * static final} constants.
  *
- *   // Bad! Do not do this!
- *   Joiner joiner = Joiner.on(',');
- *   joiner.skipNulls(); // does nothing!
- *   return joiner.join("wrong", null, "wrong");}</pre>
+ * <pre>{@code
+ * // Bad! Do not do this!
+ * Joiner joiner = Joiner.on(',');
+ * joiner.skipNulls(); // does nothing!
+ * return joiner.join("wrong", null, "wrong");
+ * }</pre>
  *
- * <p>See the Guava User Guide article on <a href=
- * "https://github.com/google/guava/wiki/StringsExplained#joiner">{@code Joiner}</a>.
+ * <p>See the Guava User Guide article on <a
+ * href="https://github.com/google/guava/wiki/StringsExplained#joiner">{@code Joiner}</a>.
  *
  * @author Kevin Bourrillion
  * @since 2.0
  */
 @GwtCompatible
+@ElementTypesAreNonnullByDefault
 public class Joiner {
-  /**
-   * Returns a joiner which automatically places {@code separator} between consecutive elements.
-   */
-  @CheckReturnValue
+  /** Returns a joiner which automatically places {@code separator} between consecutive elements. */
   public static Joiner on(String separator) {
     return new Joiner(separator);
   }
 
-  /**
-   * Returns a joiner which automatically places {@code separator} between consecutive elements.
-   */
-  @CheckReturnValue
+  /** Returns a joiner which automatically places {@code separator} between consecutive elements. */
   public static Joiner on(char separator) {
     return new Joiner(String.valueOf(separator));
   }
@@ -90,11 +86,19 @@ public class Joiner {
     this.separator = prototype.separator;
   }
 
+  /*
+   * In this file, we use <? extends @Nullable Object> instead of <?> to work around a Kotlin bug
+   * (see b/189937072 until we file a bug against Kotlin itself). (The two should be equivalent, so
+   * we normally prefer the shorter one.)
+   */
+
   /**
    * Appends the string representation of each of {@code parts}, using the previously configured
    * separator between each, to {@code appendable}.
    */
-  public <A extends Appendable> A appendTo(A appendable, Iterable<?> parts) throws IOException {
+  @CanIgnoreReturnValue
+  public <A extends Appendable> A appendTo(A appendable, Iterable<? extends @Nullable Object> parts)
+      throws IOException {
     return appendTo(appendable, parts.iterator());
   }
 
@@ -104,7 +108,9 @@ public class Joiner {
    *
    * @since 11.0
    */
-  public <A extends Appendable> A appendTo(A appendable, Iterator<?> parts) throws IOException {
+  @CanIgnoreReturnValue
+  public <A extends Appendable> A appendTo(A appendable, Iterator<? extends @Nullable Object> parts)
+      throws IOException {
     checkNotNull(appendable);
     if (parts.hasNext()) {
       appendable.append(toString(parts.next()));
@@ -120,15 +126,19 @@ public class Joiner {
    * Appends the string representation of each of {@code parts}, using the previously configured
    * separator between each, to {@code appendable}.
    */
-  public final <A extends Appendable> A appendTo(A appendable, Object[] parts) throws IOException {
+  @CanIgnoreReturnValue
+  public final <A extends Appendable> A appendTo(A appendable, @Nullable Object[] parts)
+      throws IOException {
     return appendTo(appendable, Arrays.asList(parts));
   }
 
-  /**
-   * Appends to {@code appendable} the string representation of each of the remaining arguments.
-   */
+  /** Appends to {@code appendable} the string representation of each of the remaining arguments. */
+  @CanIgnoreReturnValue
   public final <A extends Appendable> A appendTo(
-      A appendable, @Nullable Object first, @Nullable Object second, Object... rest)
+      A appendable,
+      @CheckForNull Object first,
+      @CheckForNull Object second,
+      @Nullable Object... rest)
       throws IOException {
     return appendTo(appendable, iterable(first, second, rest));
   }
@@ -138,7 +148,9 @@ public class Joiner {
    * separator between each, to {@code builder}. Identical to {@link #appendTo(Appendable,
    * Iterable)}, except that it does not throw {@link IOException}.
    */
-  public final StringBuilder appendTo(StringBuilder builder, Iterable<?> parts) {
+  @CanIgnoreReturnValue
+  public final StringBuilder appendTo(
+      StringBuilder builder, Iterable<? extends @Nullable Object> parts) {
     return appendTo(builder, parts.iterator());
   }
 
@@ -149,7 +161,9 @@ public class Joiner {
    *
    * @since 11.0
    */
-  public final StringBuilder appendTo(StringBuilder builder, Iterator<?> parts) {
+  @CanIgnoreReturnValue
+  public final StringBuilder appendTo(
+      StringBuilder builder, Iterator<? extends @Nullable Object> parts) {
     try {
       appendTo((Appendable) builder, parts);
     } catch (IOException impossible) {
@@ -163,7 +177,8 @@ public class Joiner {
    * separator between each, to {@code builder}. Identical to {@link #appendTo(Appendable,
    * Iterable)}, except that it does not throw {@link IOException}.
    */
-  public final StringBuilder appendTo(StringBuilder builder, Object[] parts) {
+  @CanIgnoreReturnValue
+  public final StringBuilder appendTo(StringBuilder builder, @Nullable Object[] parts) {
     return appendTo(builder, Arrays.asList(parts));
   }
 
@@ -172,8 +187,12 @@ public class Joiner {
    * Identical to {@link #appendTo(Appendable, Object, Object, Object...)}, except that it does not
    * throw {@link IOException}.
    */
+  @CanIgnoreReturnValue
   public final StringBuilder appendTo(
-      StringBuilder builder, @Nullable Object first, @Nullable Object second, Object... rest) {
+      StringBuilder builder,
+      @CheckForNull Object first,
+      @CheckForNull Object second,
+      @Nullable Object... rest) {
     return appendTo(builder, iterable(first, second, rest));
   }
 
@@ -181,8 +200,7 @@ public class Joiner {
    * Returns a string containing the string representation of each of {@code parts}, using the
    * previously configured separator between each.
    */
-  @CheckReturnValue
-  public final String join(Iterable<?> parts) {
+  public final String join(Iterable<? extends @Nullable Object> parts) {
     return join(parts.iterator());
   }
 
@@ -192,8 +210,7 @@ public class Joiner {
    *
    * @since 11.0
    */
-  @CheckReturnValue
-  public final String join(Iterator<?> parts) {
+  public final String join(Iterator<? extends @Nullable Object> parts) {
     return appendTo(new StringBuilder(), parts).toString();
   }
 
@@ -201,8 +218,7 @@ public class Joiner {
    * Returns a string containing the string representation of each of {@code parts}, using the
    * previously configured separator between each.
    */
-  @CheckReturnValue
-  public final String join(Object[] parts) {
+  public final String join(@Nullable Object[] parts) {
     return join(Arrays.asList(parts));
   }
 
@@ -210,8 +226,8 @@ public class Joiner {
    * Returns a string containing the string representation of each argument, using the previously
    * configured separator between each.
    */
-  @CheckReturnValue
-  public final String join(@Nullable Object first, @Nullable Object second, Object... rest) {
+  public final String join(
+      @CheckForNull Object first, @CheckForNull Object second, @Nullable Object... rest) {
     return join(iterable(first, second, rest));
   }
 
@@ -219,12 +235,11 @@ public class Joiner {
    * Returns a joiner with the same behavior as this one, except automatically substituting {@code
    * nullText} for any provided null elements.
    */
-  @CheckReturnValue
-  public Joiner useForNull(final String nullText) {
+  public Joiner useForNull(String nullText) {
     checkNotNull(nullText);
     return new Joiner(this) {
       @Override
-      CharSequence toString(@Nullable Object part) {
+      CharSequence toString(@CheckForNull Object part) {
         return (part == null) ? nullText : Joiner.this.toString(part);
       }
 
@@ -244,11 +259,11 @@ public class Joiner {
    * Returns a joiner with the same behavior as this joiner, except automatically skipping over any
    * provided null elements.
    */
-  @CheckReturnValue
   public Joiner skipNulls() {
     return new Joiner(this) {
       @Override
-      public <A extends Appendable> A appendTo(A appendable, Iterator<?> parts) throws IOException {
+      public <A extends Appendable> A appendTo(
+          A appendable, Iterator<? extends @Nullable Object> parts) throws IOException {
         checkNotNull(appendable, "appendable");
         checkNotNull(parts, "parts");
         while (parts.hasNext()) {
@@ -280,11 +295,20 @@ public class Joiner {
     };
   }
 
+  /**
+   * Returns a {@code MapJoiner} using the given key-value separator, and the same configuration as
+   * this {@code Joiner} otherwise.
+   *
+   * @since 20.0
+   */
+  public MapJoiner withKeyValueSeparator(char keyValueSeparator) {
+    return withKeyValueSeparator(String.valueOf(keyValueSeparator));
+  }
+
   /**
    * Returns a {@code MapJoiner} using the given key-value separator, and the same configuration as
    * this {@code Joiner} otherwise.
    */
-  @CheckReturnValue
   public MapJoiner withKeyValueSeparator(String keyValueSeparator) {
     return new MapJoiner(this, keyValueSeparator);
   }
@@ -297,12 +321,12 @@ public class Joiner {
    * Multimap} entries in two distinct modes:
    *
    * <ul>
-   * <li>To output a separate entry for each key-value pair, pass {@code multimap.entries()} to a
-   *     {@code MapJoiner} method that accepts entries as input, and receive output of the form
-   *     {@code key1=A&key1=B&key2=C}.
-   * <li>To output a single entry for each key, pass {@code multimap.asMap()} to a {@code MapJoiner}
-   *     method that accepts a map as input, and receive output of the form {@code
-   *     key1=[A, B]&key2=C}.
+   *   <li>To output a separate entry for each key-value pair, pass {@code multimap.entries()} to a
+   *       {@code MapJoiner} method that accepts entries as input, and receive output of the form
+   *       {@code key1=A&key1=B&key2=C}.
+   *   <li>To output a single entry for each key, pass {@code multimap.asMap()} to a {@code
+   *       MapJoiner} method that accepts a map as input, and receive output of the form {@code
+   *       key1=[A, B]&key2=C}.
    * </ul>
    *
    * @since 2.0
@@ -320,6 +344,7 @@ public class Joiner {
      * Appends the string representation of each entry of {@code map}, using the previously
      * configured separator and key-value separator, to {@code appendable}.
      */
+    @CanIgnoreReturnValue
     public <A extends Appendable> A appendTo(A appendable, Map<?, ?> map) throws IOException {
       return appendTo(appendable, map.entrySet());
     }
@@ -329,26 +354,18 @@ public class Joiner {
      * configured separator and key-value separator, to {@code builder}. Identical to {@link
      * #appendTo(Appendable, Map)}, except that it does not throw {@link IOException}.
      */
+    @CanIgnoreReturnValue
     public StringBuilder appendTo(StringBuilder builder, Map<?, ?> map) {
       return appendTo(builder, map.entrySet());
     }
 
-    /**
-     * Returns a string containing the string representation of each entry of {@code map}, using the
-     * previously configured separator and key-value separator.
-     */
-    @CheckReturnValue
-    public String join(Map<?, ?> map) {
-      return join(map.entrySet());
-    }
-
     /**
      * Appends the string representation of each entry in {@code entries}, using the previously
      * configured separator and key-value separator, to {@code appendable}.
      *
      * @since 10.0
      */
-    @Beta
+    @CanIgnoreReturnValue
     public <A extends Appendable> A appendTo(A appendable, Iterable<? extends Entry<?, ?>> entries)
         throws IOException {
       return appendTo(appendable, entries.iterator());
@@ -360,7 +377,7 @@ public class Joiner {
      *
      * @since 11.0
      */
-    @Beta
+    @CanIgnoreReturnValue
     public <A extends Appendable> A appendTo(A appendable, Iterator<? extends Entry<?, ?>> parts)
         throws IOException {
       checkNotNull(appendable);
@@ -387,7 +404,7 @@ public class Joiner {
      *
      * @since 10.0
      */
-    @Beta
+    @CanIgnoreReturnValue
     public StringBuilder appendTo(StringBuilder builder, Iterable<? extends Entry<?, ?>> entries) {
       return appendTo(builder, entries.iterator());
     }
@@ -399,7 +416,7 @@ public class Joiner {
      *
      * @since 11.0
      */
-    @Beta
+    @CanIgnoreReturnValue
     public StringBuilder appendTo(StringBuilder builder, Iterator<? extends Entry<?, ?>> entries) {
       try {
         appendTo((Appendable) builder, entries);
@@ -409,14 +426,20 @@ public class Joiner {
       return builder;
     }
 
+    /**
+     * Returns a string containing the string representation of each entry of {@code map}, using the
+     * previously configured separator and key-value separator.
+     */
+    public String join(Map<?, ?> map) {
+      return join(map.entrySet());
+    }
+
     /**
      * Returns a string containing the string representation of each entry in {@code entries}, using
      * the previously configured separator and key-value separator.
      *
      * @since 10.0
      */
-    @Beta
-    @CheckReturnValue
     public String join(Iterable<? extends Entry<?, ?>> entries) {
       return join(entries.iterator());
     }
@@ -427,8 +450,6 @@ public class Joiner {
      *
      * @since 11.0
      */
-    @Beta
-    @CheckReturnValue
     public String join(Iterator<? extends Entry<?, ?>> entries) {
       return appendTo(new StringBuilder(), entries).toString();
     }
@@ -437,27 +458,44 @@ public class Joiner {
      * Returns a map joiner with the same behavior as this one, except automatically substituting
      * {@code nullText} for any provided null keys or values.
      */
-    @CheckReturnValue
     public MapJoiner useForNull(String nullText) {
       return new MapJoiner(joiner.useForNull(nullText), keyValueSeparator);
     }
   }
 
-  CharSequence toString(Object part) {
-    checkNotNull(part); // checkNotNull for GWT (do not optimize).
+  CharSequence toString(@CheckForNull Object part) {
+    /*
+     * requireNonNull is not safe: Joiner.on(...).join(somethingThatContainsNull) will indeed throw.
+     * However, Joiner.on(...).useForNull(...).join(somethingThatContainsNull) *is* safe -- because
+     * it returns a subclass of Joiner that overrides this method to tolerate null inputs.
+     *
+     * Unfortunately, we don't distinguish between these two cases in our public API: Joiner.on(...)
+     * and Joiner.on(...).useForNull(...) both declare the same return type: plain Joiner. To ensure
+     * that users *can* pass null arguments to Joiner, we annotate it as if it always tolerates null
+     * inputs, rather than as if it never tolerates them.
+     *
+     * We rely on checkers to implement special cases to catch dangerous calls to join(), etc. based
+     * on what they know about the particular Joiner instances the calls are performed on.
+     *
+     * (In addition to useForNull, we also offer skipNulls. It, too, tolerates null inputs, but its
+     * tolerance is implemented differently: Its implementation avoids calling this toString(Object)
+     * method in the first place.)
+     */
+    requireNonNull(part);
     return (part instanceof CharSequence) ? (CharSequence) part : part.toString();
   }
 
-  private static Iterable<Object> iterable(
-      final Object first, final Object second, final Object[] rest) {
+  private static Iterable<@Nullable Object> iterable(
+      @CheckForNull Object first, @CheckForNull Object second, @Nullable Object[] rest) {
     checkNotNull(rest);
-    return new AbstractList<Object>() {
+    return new AbstractList<@Nullable Object>() {
       @Override
       public int size() {
         return rest.length + 2;
       }
 
       @Override
+      @CheckForNull
       public Object get(int index) {
         switch (index) {
           case 0:
