@@ -17,10 +17,12 @@
 package com.google.common.collect;
 
 import static com.google.common.base.Preconditions.checkNotNull;
+import static java.util.Collections.singletonMap;
 import static java.util.stream.Collectors.collectingAndThen;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.Preconditions;
 import java.util.Collection;
 import java.util.Comparator;
@@ -95,16 +97,20 @@ final class CollectCollectors {
     return (Collector) EnumSetAccumulator.TO_IMMUTABLE_ENUM_SET;
   }
 
+  private static <E extends Enum<E>>
+      Collector<E, EnumSetAccumulator<E>, ImmutableSet<E>> toImmutableEnumSetGeneric() {
+    return Collector.of(
+        EnumSetAccumulator::new,
+        EnumSetAccumulator::add,
+        EnumSetAccumulator::combine,
+        EnumSetAccumulator::toImmutableSet,
+        Collector.Characteristics.UNORDERED);
+  }
+
   private static final class EnumSetAccumulator<E extends Enum<E>> {
     @SuppressWarnings({"rawtypes", "unchecked"})
     static final Collector<Enum<?>, ?, ImmutableSet<? extends Enum<?>>> TO_IMMUTABLE_ENUM_SET =
-        (Collector)
-            Collector.<Enum, EnumSetAccumulator, ImmutableSet<?>>of(
-                EnumSetAccumulator::new,
-                EnumSetAccumulator::add,
-                EnumSetAccumulator::combine,
-                EnumSetAccumulator::toImmutableSet,
-                Collector.Characteristics.UNORDERED);
+        (Collector) toImmutableEnumSetGeneric();
 
     @CheckForNull private EnumSet<E> set;
 
@@ -128,7 +134,12 @@ final class CollectCollectors {
     }
 
     ImmutableSet<E> toImmutableSet() {
-      return (set == null) ? ImmutableSet.<E>of() : ImmutableEnumSet.asImmutable(set);
+      if (set == null) {
+        return ImmutableSet.of();
+      }
+      ImmutableSet<E> ret = ImmutableEnumSet.asImmutable(set);
+      set = null; // subsequent manual manipulation of the accumulator mustn't affect ret
+      return ret;
     }
   }
 
@@ -249,6 +260,7 @@ final class CollectCollectors {
         new Collector.Characteristics[0]);
   }
 
+  @J2ktIncompatible
   static <T extends @Nullable Object, K extends Enum<K>, V>
       Collector<T, ?, ImmutableMap<K, V>> toImmutableEnumMap(
           Function<? super T, ? extends K> keyFunction,
@@ -277,6 +289,7 @@ final class CollectCollectors {
         Collector.Characteristics.UNORDERED);
   }
 
+  @J2ktIncompatible
   static <T extends @Nullable Object, K extends Enum<K>, V>
       Collector<T, ?, ImmutableMap<K, V>> toImmutableEnumMap(
           Function<? super T, ? extends K> keyFunction,
@@ -303,6 +316,7 @@ final class CollectCollectors {
         EnumMapAccumulator::toImmutableMap);
   }
 
+  @J2ktIncompatible
   private static class EnumMapAccumulator<K extends Enum<K>, V> {
     private final BinaryOperator<V> mergeFunction;
     @CheckForNull private EnumMap<K, V> map = null;
@@ -313,9 +327,10 @@ final class CollectCollectors {
 
     void put(K key, V value) {
       if (map == null) {
-        map = new EnumMap<>(key.getDeclaringClass());
+        map = new EnumMap<>(singletonMap(key, value));
+      } else {
+        map.merge(key, value, mergeFunction);
       }
-      map.merge(key, value, mergeFunction);
     }
 
     EnumMapAccumulator<K, V> combine(EnumMapAccumulator<K, V> other) {
