@@ -20,9 +20,9 @@ import static com.google.common.base.Preconditions.checkNotNull;
 import static com.google.common.collect.CollectPreconditions.checkNonnegative;
 
 import com.google.common.annotations.GwtCompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Function;
-import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -39,6 +39,7 @@ import java.util.TreeSet;
 import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.atomic.AtomicInteger;
 import javax.annotation.CheckForNull;
+import org.checkerframework.checker.nullness.qual.NonNull;
 import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
@@ -172,6 +173,8 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * to pass it in here. Instead, simply subclass {@code Ordering} and implement its {@code compare}
    * method directly.
    *
+   * <p>The returned object is serializable if {@code comparator} is serializable.
+   *
    * <p><b>Java 8 users:</b> this class is now obsolete as explained in the class documentation, so
    * there is no need to use this method.
    *
@@ -313,14 +316,17 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * @since 2.0
    */
   // TODO(kevinb): copy to Comparators, etc.
+  @J2ktIncompatible // MapMaker
   public static Ordering<@Nullable Object> arbitrary() {
     return ArbitraryOrderingHolder.ARBITRARY_ORDERING;
   }
 
+  @J2ktIncompatible // MapMaker
   private static class ArbitraryOrderingHolder {
     static final Ordering<@Nullable Object> ARBITRARY_ORDERING = new ArbitraryOrdering();
   }
 
+  @J2ktIncompatible // MapMaker
   @VisibleForTesting
   static class ArbitraryOrdering extends Ordering<@Nullable Object> {
 
@@ -411,6 +417,8 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * Returns an ordering that treats {@code null} as less than all other values and uses {@code
    * this} to compare non-null values.
    *
+   * <p>The returned object is serializable if this object is serializable.
+   *
    * <p><b>Java 8 users:</b> Use {@code Comparator.nullsFirst(thisComparator)} instead.
    */
   // type parameter <S> lets us avoid the extra <String> in statements like:
@@ -424,6 +432,8 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * Returns an ordering that treats {@code null} as greater than all other values and uses this
    * ordering to compare non-null values.
    *
+   * <p>The returned object is serializable if this object is serializable.
+   *
    * <p><b>Java 8 users:</b> Use {@code Comparator.nullsLast(thisComparator)} instead.
    */
   // type parameter <S> lets us avoid the extra <String> in statements like:
@@ -464,6 +474,9 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * <p>An ordering produced by this method, or a chain of calls to this method, is equivalent to
    * one created using {@link Ordering#compound(Iterable)} on the same component comparators.
    *
+   * <p>The returned object is serializable if this object and {@code secondaryComparator} are both
+   * serializable.
+   *
    * <p><b>Java 8 users:</b> Use {@code thisComparator.thenComparing(secondaryComparator)} instead.
    * Depending on what {@code secondaryComparator} is, one of the other overloads of {@code
    * thenComparing} may be even more useful.
@@ -482,6 +495,8 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * <p>The returned ordering is equivalent to that produced using {@code
    * Ordering.from(comp1).compound(comp2).compound(comp3) . . .}.
    *
+   * <p>The returned object is serializable if each of the {@code comparators} is serializable.
+   *
    * <p><b>Warning:</b> Supplying an argument with undefined iteration order, such as a {@link
    * HashSet}, will produce non-deterministic results.
    *
@@ -530,7 +545,6 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
 
   // Regular instance methods
 
-  @CanIgnoreReturnValue // TODO(kak): Consider removing this
   @Override
   public abstract int compare(@ParametricNullness T left, @ParametricNullness T right);
 
@@ -567,7 +581,7 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * <p><b>Java 8 users:</b> If {@code iterable} is a {@link Collection}, use {@code
    * Collections.min(collection, thisComparator)} instead. Otherwise, use {@code
    * Streams.stream(iterable).min(thisComparator).get()} instead. Note that these alternatives do
-   * not guarantee which tied minimum element is returned)
+   * not guarantee which tied minimum element is returned.
    *
    * @param iterable the iterable whose minimum element is to be determined
    * @throws NoSuchElementException if {@code iterable} is empty
@@ -658,7 +672,7 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * <p><b>Java 8 users:</b> If {@code iterable} is a {@link Collection}, use {@code
    * Collections.max(collection, thisComparator)} instead. Otherwise, use {@code
    * Streams.stream(iterable).max(thisComparator).get()} instead. Note that these alternatives do
-   * not guarantee which tied maximum element is returned)
+   * not guarantee which tied maximum element is returned.
    *
    * @param iterable the iterable whose maximum element is to be determined
    * @throws NoSuchElementException if {@code iterable} is empty
@@ -809,7 +823,7 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
   public <E extends T> List<E> greatestOf(Iterable<E> iterable, int k) {
     // TODO(kevinb): see if delegation is hurting performance noticeably
     // TODO(kevinb): if we change this implementation, add full unit tests.
-    return reverse().leastOf(iterable, k);
+    return this.<E>reverse().leastOf(iterable, k);
   }
 
   /**
@@ -829,7 +843,7 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * @since 14.0
    */
   public <E extends T> List<E> greatestOf(Iterator<E> iterator, int k) {
-    return reverse().leastOf(iterator, k);
+    return this.<E>reverse().leastOf(iterator, k);
   }
 
   /**
@@ -871,8 +885,7 @@ public abstract class Ordering<T extends @Nullable Object> implements Comparator
    * @since 3.0
    */
   // TODO(kevinb): rerun benchmarks including new options
-  @SuppressWarnings("nullness") // unsafe, but there's not much we can do about it now
-  public <E extends T> ImmutableList<E> immutableSortedCopy(Iterable<E> elements) {
+  public <E extends @NonNull T> ImmutableList<E> immutableSortedCopy(Iterable<E> elements) {
     return ImmutableList.sortedCopyOf(this, elements);
   }
 
