@@ -16,7 +16,6 @@
 
 package com.google.common.collect;
 
-import com.google.common.annotations.Beta;
 import com.google.common.annotations.GwtIncompatible;
 import com.google.errorprone.annotations.DoNotMock;
 import java.util.Collection;
@@ -37,7 +36,6 @@ import org.checkerframework.checker.nullness.qual.Nullable;
  * @author Louis Wasserman
  * @since 14.0
  */
-@Beta
 @DoNotMock("Use ImmutableRangeMap or TreeRangeMap")
 @GwtIncompatible
 @ElementTypesAreNonnullByDefault
@@ -103,7 +101,7 @@ public interface RangeMap<K extends Comparable, V> {
   void putCoalescing(Range<K> range, V value);
 
   /** Puts all the associations from {@code rangeMap} into this range map (optional operation). */
-  void putAll(RangeMap<K, V> rangeMap);
+  void putAll(RangeMap<K, ? extends V> rangeMap);
 
   /** Removes all associations from this range map (optional operation). */
   void clear();
