@@ -17,15 +17,18 @@
 package com.google.common.collect;
 
 import static com.google.common.base.Preconditions.checkArgument;
+import static com.google.common.base.Preconditions.checkNotNull;
 import static com.google.common.base.Preconditions.checkState;
 import static com.google.common.collect.CollectPreconditions.checkNonnegative;
-import static com.google.common.collect.CollectPreconditions.checkRemove;
+import static com.google.common.collect.NullnessCasts.uncheckedCastNullableTToT;
+import static java.util.Objects.requireNonNull;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.base.MoreObjects;
 import com.google.common.primitives.Ints;
-
+import com.google.errorprone.annotations.CanIgnoreReturnValue;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
@@ -34,38 +37,40 @@ import java.util.Comparator;
 import java.util.ConcurrentModificationException;
 import java.util.Iterator;
 import java.util.NoSuchElementException;
-
-import javax.annotation.Nullable;
+import java.util.function.ObjIntConsumer;
+import javax.annotation.CheckForNull;
+import org.checkerframework.checker.nullness.qual.Nullable;
 
 /**
  * A multiset which maintains the ordering of its elements, according to either their natural order
- * or an explicit {@link Comparator}. In all cases, this implementation uses
- * {@link Comparable#compareTo} or {@link Comparator#compare} instead of {@link Object#equals} to
- * determine equivalence of instances.
+ * or an explicit {@link Comparator}. In all cases, this implementation uses {@link
+ * Comparable#compareTo} or {@link Comparator#compare} instead of {@link Object#equals} to determine
+ * equivalence of instances.
  *
  * <p><b>Warning:</b> The comparison must be <i>consistent with equals</i> as explained by the
- * {@link Comparable} class specification. Otherwise, the resulting multiset will violate the
- * {@link java.util.Collection} contract, which is specified in terms of {@link Object#equals}.
+ * {@link Comparable} class specification. Otherwise, the resulting multiset will violate the {@link
+ * java.util.Collection} contract, which is specified in terms of {@link Object#equals}.
  *
  * <p>See the Guava User Guide article on <a href=
- * "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multiset">
- * {@code Multiset}</a>.
+ * "https://github.com/google/guava/wiki/NewCollectionTypesExplained#multiset">{@code Multiset}</a>.
  *
  * @author Louis Wasserman
  * @author Jared Levy
  * @since 2.0
  */
 @GwtCompatible(emulated = true)
-public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements Serializable {
+@ElementTypesAreNonnullByDefault
+public final class TreeMultiset<E extends @Nullable Object> extends AbstractSortedMultiset<E>
+    implements Serializable {
 
   /**
    * Creates a new, empty multiset, sorted according to the elements' natural order. All elements
    * inserted into the multiset must implement the {@code Comparable} interface. Furthermore, all
    * such elements must be <i>mutually comparable</i>: {@code e1.compareTo(e2)} must not throw a
    * {@code ClassCastException} for any elements {@code e1} and {@code e2} in the multiset. If the
-   * user attempts to add an element to the multiset that violates this constraint (for example,
-   * the user attempts to add a string element to a set whose elements are integers), the
-   * {@code add(Object)} call will throw a {@code ClassCastException}.
+   * user attempts to add an element to the multiset that violates this constraint (for example, the
+   * user attempts to add a string element to a set whose elements are integers), the {@code
+   * add(Object)} call will throw a {@code ClassCastException}.
    *
    * <p>The type specification is {@code <E extends Comparable>}, instead of the more specific
    * {@code <E extends Comparable<? super E>>}, to support classes defined without generics.
@@ -77,17 +82,17 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
   /**
    * Creates a new, empty multiset, sorted according to the specified comparator. All elements
    * inserted into the multiset must be <i>mutually comparable</i> by the specified comparator:
-   * {@code comparator.compare(e1,
-   * e2)} must not throw a {@code ClassCastException} for any elements {@code e1} and {@code e2} in
-   * the multiset. If the user attempts to add an element to the multiset that violates this
-   * constraint, the {@code add(Object)} call will throw a {@code ClassCastException}.
+   * {@code comparator.compare(e1, e2)} must not throw a {@code ClassCastException} for any elements
+   * {@code e1} and {@code e2} in the multiset. If the user attempts to add an element to the
+   * multiset that violates this constraint, the {@code add(Object)} call will throw a {@code
+   * ClassCastException}.
    *
-   * @param comparator
-   *          the comparator that will be used to sort this multiset. A null value indicates that
-   *          the elements' <i>natural ordering</i> should be used.
+   * @param comparator the comparator that will be used to sort this multiset. A null value
+   *     indicates that the elements' <i>natural ordering</i> should be used.
    */
   @SuppressWarnings("unchecked")
-  public static <E> TreeMultiset<E> create(@Nullable Comparator<? super E> comparator) {
+  public static <E extends @Nullable Object> TreeMultiset<E> create(
+      @CheckForNull Comparator<? super E> comparator) {
     return (comparator == null)
         ? new TreeMultiset<E>((Comparator) Ordering.natural())
         : new TreeMultiset<E>(comparator);
@@ -122,14 +127,12 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
   TreeMultiset(Comparator<? super E> comparator) {
     super(comparator);
     this.range = GeneralRange.all(comparator);
-    this.header = new AvlNode<E>(null, 1);
+    this.header = new AvlNode<>();
     successor(header, header);
-    this.rootReference = new Reference<AvlNode<E>>();
+    this.rootReference = new Reference<>();
   }
 
-  /**
-   * A function which can be summed across a subtree.
-   */
+  /** A function which can be summed across a subtree. */
   private enum Aggregate {
     SIZE {
       @Override
@@ -138,7 +141,7 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       }
 
       @Override
-      long treeAggregate(@Nullable AvlNode<?> root) {
+      long treeAggregate(@CheckForNull AvlNode<?> root) {
         return (root == null) ? 0 : root.totalCount;
       }
     },
@@ -149,14 +152,14 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       }
 
       @Override
-      long treeAggregate(@Nullable AvlNode<?> root) {
+      long treeAggregate(@CheckForNull AvlNode<?> root) {
         return (root == null) ? 0 : root.distinctElements;
       }
     };
 
     abstract int nodeAggregate(AvlNode<?> node);
 
-    abstract long treeAggregate(@Nullable AvlNode<?> root);
+    abstract long treeAggregate(@CheckForNull AvlNode<?> root);
   }
 
   private long aggregateForEntries(Aggregate aggr) {
@@ -171,11 +174,14 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     return total;
   }
 
-  private long aggregateBelowRange(Aggregate aggr, @Nullable AvlNode<E> node) {
+  private long aggregateBelowRange(Aggregate aggr, @CheckForNull AvlNode<E> node) {
     if (node == null) {
       return 0;
     }
-    int cmp = comparator().compare(range.getLowerEndpoint(), node.elem);
+    // The cast is safe because we call this method only if hasLowerBound().
+    int cmp =
+        comparator()
+            .compare(uncheckedCastNullableTToT(range.getLowerEndpoint()), node.getElement());
     if (cmp < 0) {
       return aggregateBelowRange(aggr, node.left);
     } else if (cmp == 0) {
@@ -194,11 +200,14 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     }
   }
 
-  private long aggregateAboveRange(Aggregate aggr, @Nullable AvlNode<E> node) {
+  private long aggregateAboveRange(Aggregate aggr, @CheckForNull AvlNode<E> node) {
     if (node == null) {
       return 0;
     }
-    int cmp = comparator().compare(range.getUpperEndpoint(), node.elem);
+    // The cast is safe because we call this method only if hasUpperBound().
+    int cmp =
+        comparator()
+            .compare(uncheckedCastNullableTToT(range.getUpperEndpoint()), node.getElement());
     if (cmp > 0) {
       return aggregateAboveRange(aggr, node.right);
     } else if (cmp == 0) {
@@ -227,8 +236,12 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     return Ints.saturatedCast(aggregateForEntries(Aggregate.DISTINCT));
   }
 
+  static int distinctElements(@CheckForNull AvlNode<?> node) {
+    return (node == null) ? 0 : node.distinctElements;
+  }
+
   @Override
-  public int count(@Nullable Object element) {
+  public int count(@CheckForNull Object element) {
     try {
       @SuppressWarnings("unchecked")
       E e = (E) element;
@@ -237,15 +250,14 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
         return 0;
       }
       return root.count(comparator(), e);
-    } catch (ClassCastException e) {
-      return 0;
-    } catch (NullPointerException e) {
+    } catch (ClassCastException | NullPointerException e) {
       return 0;
     }
   }
 
+  @CanIgnoreReturnValue
   @Override
-  public int add(@Nullable E element, int occurrences) {
+  public int add(@ParametricNullness E element, int occurrences) {
     checkNonnegative(occurrences, "occurrences");
     if (occurrences == 0) {
       return count(element);
@@ -253,7 +265,7 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     checkArgument(range.contains(element));
     AvlNode<E> root = rootReference.get();
     if (root == null) {
-      comparator().compare(element, element);
+      int unused = comparator().compare(element, element);
       AvlNode<E> newRoot = new AvlNode<E>(element, occurrences);
       successor(header, newRoot, header);
       rootReference.checkAndSet(root, newRoot);
@@ -265,8 +277,9 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     return result[0];
   }
 
+  @CanIgnoreReturnValue
   @Override
-  public int remove(@Nullable Object element, int occurrences) {
+  public int remove(@CheckForNull Object element, int occurrences) {
     checkNonnegative(occurrences, "occurrences");
     if (occurrences == 0) {
       return count(element);
@@ -281,17 +294,16 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
         return 0;
       }
       newRoot = root.remove(comparator(), e, occurrences, result);
-    } catch (ClassCastException e) {
-      return 0;
-    } catch (NullPointerException e) {
+    } catch (ClassCastException | NullPointerException e) {
       return 0;
     }
     rootReference.checkAndSet(root, newRoot);
     return result[0];
   }
 
+  @CanIgnoreReturnValue
   @Override
-  public int setCount(@Nullable E element, int count) {
+  public int setCount(@ParametricNullness E element, int count) {
     checkNonnegative(count, "count");
     if (!range.contains(element)) {
       checkArgument(count == 0);
@@ -311,8 +323,9 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     return result[0];
   }
 
+  @CanIgnoreReturnValue
   @Override
-  public boolean setCount(@Nullable E element, int oldCount, int newCount) {
+  public boolean setCount(@ParametricNullness E element, int oldCount, int newCount) {
     checkNonnegative(newCount, "newCount");
     checkNonnegative(oldCount, "oldCount");
     checkArgument(range.contains(element));
@@ -334,9 +347,34 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     return result[0] == oldCount;
   }
 
+  @Override
+  public void clear() {
+    if (!range.hasLowerBound() && !range.hasUpperBound()) {
+      // We can do this in O(n) rather than removing one by one, which could force rebalancing.
+      for (AvlNode<E> current = header.succ(); current != header; ) {
+        AvlNode<E> next = current.succ();
+
+        current.elemCount = 0;
+        // Also clear these fields so that one deleted Entry doesn't retain all elements.
+        current.left = null;
+        current.right = null;
+        current.pred = null;
+        current.succ = null;
+
+        current = next;
+      }
+      successor(header, header);
+      rootReference.clear();
+    } else {
+      // TODO(cpovirk): Perhaps we can optimize in this case, too?
+      Iterators.clear(entryIterator());
+    }
+  }
+
   private Entry<E> wrapEntry(final AvlNode<E> baseEntry) {
     return new Multisets.AbstractEntry<E>() {
       @Override
+      @ParametricNullness
       public E getElement() {
         return baseEntry.getElement();
       }
@@ -353,10 +391,8 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     };
   }
 
-  /**
-   * Returns the first node in the tree that is in range.
-   */
-  @Nullable
+  /** Returns the first node in the tree that is in range. */
+  @CheckForNull
   private AvlNode<E> firstNode() {
     AvlNode<E> root = rootReference.get();
     if (root == null) {
@@ -364,22 +400,23 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     }
     AvlNode<E> node;
     if (range.hasLowerBound()) {
-      E endpoint = range.getLowerEndpoint();
-      node = rootReference.get().ceiling(comparator(), endpoint);
+      // The cast is safe because of the hasLowerBound check.
+      E endpoint = uncheckedCastNullableTToT(range.getLowerEndpoint());
+      node = root.ceiling(comparator(), endpoint);
       if (node == null) {
         return null;
       }
       if (range.getLowerBoundType() == BoundType.OPEN
           && comparator().compare(endpoint, node.getElement()) == 0) {
-        node = node.succ;
+        node = node.succ();
       }
     } else {
-      node = header.succ;
+      node = header.succ();
     }
     return (node == header || !range.contains(node.getElement())) ? null : node;
   }
 
-  @Nullable
+  @CheckForNull
   private AvlNode<E> lastNode() {
     AvlNode<E> root = rootReference.get();
     if (root == null) {
@@ -387,26 +424,32 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     }
     AvlNode<E> node;
     if (range.hasUpperBound()) {
-      E endpoint = range.getUpperEndpoint();
-      node = rootReference.get().floor(comparator(), endpoint);
+      // The cast is safe because of the hasUpperBound check.
+      E endpoint = uncheckedCastNullableTToT(range.getUpperEndpoint());
+      node = root.floor(comparator(), endpoint);
       if (node == null) {
         return null;
       }
       if (range.getUpperBoundType() == BoundType.OPEN
           && comparator().compare(endpoint, node.getElement()) == 0) {
-        node = node.pred;
+        node = node.pred();
       }
     } else {
-      node = header.pred;
+      node = header.pred();
     }
     return (node == header || !range.contains(node.getElement())) ? null : node;
   }
 
+  @Override
+  Iterator<E> elementIterator() {
+    return Multisets.elementIterator(entryIterator());
+  }
+
   @Override
   Iterator<Entry<E>> entryIterator() {
     return new Iterator<Entry<E>>() {
-      AvlNode<E> current = firstNode();
-      Entry<E> prevEntry;
+      @CheckForNull AvlNode<E> current = firstNode();
+      @CheckForNull Entry<E> prevEntry;
 
       @Override
       public boolean hasNext() {
@@ -425,19 +468,20 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
         if (!hasNext()) {
           throw new NoSuchElementException();
         }
-        Entry<E> result = wrapEntry(current);
+        // requireNonNull is safe because current is only nulled out after iteration is complete.
+        Entry<E> result = wrapEntry(requireNonNull(current));
         prevEntry = result;
-        if (current.succ == header) {
+        if (current.succ() == header) {
           current = null;
         } else {
-          current = current.succ;
+          current = current.succ();
         }
         return result;
       }
 
       @Override
       public void remove() {
-        checkRemove(prevEntry != null);
+        checkState(prevEntry != null, "no calls to next() since the last call to remove()");
         setCount(prevEntry.getElement(), 0);
         prevEntry = null;
       }
@@ -447,8 +491,8 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
   @Override
   Iterator<Entry<E>> descendingEntryIterator() {
     return new Iterator<Entry<E>>() {
-      AvlNode<E> current = lastNode();
-      Entry<E> prevEntry = null;
+      @CheckForNull AvlNode<E> current = lastNode();
+      @CheckForNull Entry<E> prevEntry = null;
 
       @Override
       public boolean hasNext() {
@@ -467,19 +511,21 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
         if (!hasNext()) {
           throw new NoSuchElementException();
         }
+        // requireNonNull is safe because current is only nulled out after iteration is complete.
+        requireNonNull(current);
         Entry<E> result = wrapEntry(current);
         prevEntry = result;
-        if (current.pred == header) {
+        if (current.pred() == header) {
           current = null;
         } else {
-          current = current.pred;
+          current = current.pred();
         }
         return result;
       }
 
       @Override
       public void remove() {
-        checkRemove(prevEntry != null);
+        checkState(prevEntry != null, "no calls to next() since the last call to remove()");
         setCount(prevEntry.getElement(), 0);
         prevEntry = null;
       }
@@ -487,7 +533,22 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
   }
 
   @Override
-  public SortedMultiset<E> headMultiset(@Nullable E upperBound, BoundType boundType) {
+  public void forEachEntry(ObjIntConsumer<? super E> action) {
+    checkNotNull(action);
+    for (AvlNode<E> node = firstNode();
+        node != header && node != null && !range.tooHigh(node.getElement());
+        node = node.succ()) {
+      action.accept(node.getElement(), node.getCount());
+    }
+  }
+
+  @Override
+  public Iterator<E> iterator() {
+    return Multisets.iteratorImpl(this);
+  }
+
+  @Override
+  public SortedMultiset<E> headMultiset(@ParametricNullness E upperBound, BoundType boundType) {
     return new TreeMultiset<E>(
         rootReference,
         range.intersect(GeneralRange.upTo(comparator(), upperBound, boundType)),
@@ -495,35 +556,45 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
   }
 
   @Override
-  public SortedMultiset<E> tailMultiset(@Nullable E lowerBound, BoundType boundType) {
+  public SortedMultiset<E> tailMultiset(@ParametricNullness E lowerBound, BoundType boundType) {
     return new TreeMultiset<E>(
         rootReference,
         range.intersect(GeneralRange.downTo(comparator(), lowerBound, boundType)),
         header);
   }
 
-  static int distinctElements(@Nullable AvlNode<?> node) {
-    return (node == null) ? 0 : node.distinctElements;
-  }
-
   private static final class Reference<T> {
-    @Nullable private T value;
+    @CheckForNull private T value;
 
-    @Nullable
+    @CheckForNull
     public T get() {
       return value;
     }
 
-    public void checkAndSet(@Nullable T expected, T newValue) {
+    public void checkAndSet(@CheckForNull T expected, @CheckForNull T newValue) {
       if (value != expected) {
         throw new ConcurrentModificationException();
       }
       value = newValue;
     }
+
+    void clear() {
+      value = null;
+    }
   }
 
-  private static final class AvlNode<E> extends Multisets.AbstractEntry<E> {
-    @Nullable private final E elem;
+  private static final class AvlNode<E extends @Nullable Object> {
+    /*
+     * For "normal" nodes, the type of this field is `E`, not `@Nullable E` (though note that E is a
+     * type that can include null, as in a TreeMultiset<@Nullable String>).
+     *
+     * For the header node, though, this field contains `null`, regardless of the type of the
+     * multiset.
+     *
+     * Most code that operates on an AvlNode never operates on the header node. Such code can access
+     * the elem field without a null check by calling getElement().
+     */
+    @CheckForNull private final E elem;
 
     // elemCount is 0 iff this node has been deleted.
     private int elemCount;
@@ -531,12 +602,23 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     private int distinctElements;
     private long totalCount;
     private int height;
-    private AvlNode<E> left;
-    private AvlNode<E> right;
-    private AvlNode<E> pred;
-    private AvlNode<E> succ;
+    @CheckForNull private AvlNode<E> left;
+    @CheckForNull private AvlNode<E> right;
+    /*
+     * pred and succ are nullable after construction, but we always call successor() to initialize
+     * them immediately thereafter.
+     *
+     * They may be subsequently nulled out by TreeMultiset.clear(). I think that the only place that
+     * we can reference a node whose fields have been cleared is inside the iterator (and presumably
+     * only under concurrent modification).
+     *
+     * To access these fields when you know that they are not null, call the pred() and succ()
+     * methods, which perform null checks before returning the fields.
+     */
+    @CheckForNull private AvlNode<E> pred;
+    @CheckForNull private AvlNode<E> succ;
 
-    AvlNode(@Nullable E elem, int elemCount) {
+    AvlNode(@ParametricNullness E elem, int elemCount) {
       checkArgument(elemCount > 0);
       this.elem = elem;
       this.elemCount = elemCount;
@@ -547,8 +629,24 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       this.right = null;
     }
 
-    public int count(Comparator<? super E> comparator, E e) {
-      int cmp = comparator.compare(e, elem);
+    /** Constructor for the header node. */
+    AvlNode() {
+      this.elem = null;
+      this.elemCount = 1;
+    }
+
+    // For discussion of pred() and succ(), see the comment on the pred and succ fields.
+
+    private AvlNode<E> pred() {
+      return requireNonNull(pred);
+    }
+
+    private AvlNode<E> succ() {
+      return requireNonNull(succ);
+    }
+
+    int count(Comparator<? super E> comparator, @ParametricNullness E e) {
+      int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
         return (left == null) ? 0 : left.count(comparator, e);
       } else if (cmp > 0) {
@@ -558,30 +656,31 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       }
     }
 
-    private AvlNode<E> addRightChild(E e, int count) {
+    private AvlNode<E> addRightChild(@ParametricNullness E e, int count) {
       right = new AvlNode<E>(e, count);
-      successor(this, right, succ);
+      successor(this, right, succ());
       height = Math.max(2, height);
       distinctElements++;
       totalCount += count;
       return this;
     }
 
-    private AvlNode<E> addLeftChild(E e, int count) {
+    private AvlNode<E> addLeftChild(@ParametricNullness E e, int count) {
       left = new AvlNode<E>(e, count);
-      successor(pred, left, this);
+      successor(pred(), left, this);
       height = Math.max(2, height);
       distinctElements++;
       totalCount += count;
       return this;
     }
 
-    AvlNode<E> add(Comparator<? super E> comparator, @Nullable E e, int count, int[] result) {
+    AvlNode<E> add(
+        Comparator<? super E> comparator, @ParametricNullness E e, int count, int[] result) {
       /*
        * It speeds things up considerably to unconditionally add count to totalCount here,
        * but that destroys failure atomicity in the case of count overflow. =(
        */
-      int cmp = comparator.compare(e, elem);
+      int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
         AvlNode<E> initLeft = left;
         if (initLeft == null) {
@@ -621,8 +720,10 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       return this;
     }
 
-    AvlNode<E> remove(Comparator<? super E> comparator, @Nullable E e, int count, int[] result) {
-      int cmp = comparator.compare(e, elem);
+    @CheckForNull
+    AvlNode<E> remove(
+        Comparator<? super E> comparator, @ParametricNullness E e, int count, int[] result) {
+      int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
         AvlNode<E> initLeft = left;
         if (initLeft == null) {
@@ -672,8 +773,10 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       }
     }
 
-    AvlNode<E> setCount(Comparator<? super E> comparator, @Nullable E e, int count, int[] result) {
-      int cmp = comparator.compare(e, elem);
+    @CheckForNull
+    AvlNode<E> setCount(
+        Comparator<? super E> comparator, @ParametricNullness E e, int count, int[] result) {
+      int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
         AvlNode<E> initLeft = left;
         if (initLeft == null) {
@@ -720,13 +823,14 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       return this;
     }
 
+    @CheckForNull
     AvlNode<E> setCount(
         Comparator<? super E> comparator,
-        @Nullable E e,
+        @ParametricNullness E e,
         int expectedCount,
         int newCount,
         int[] result) {
-      int cmp = comparator.compare(e, elem);
+      int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
         AvlNode<E> initLeft = left;
         if (initLeft == null) {
@@ -783,16 +887,17 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       return this;
     }
 
+    @CheckForNull
     private AvlNode<E> deleteMe() {
       int oldElemCount = this.elemCount;
       this.elemCount = 0;
-      successor(pred, succ);
+      successor(pred(), succ());
       if (left == null) {
         return right;
       } else if (right == null) {
         return left;
       } else if (left.height >= right.height) {
-        AvlNode<E> newTop = pred;
+        AvlNode<E> newTop = pred();
         // newTop is the maximum node in my left subtree
         newTop.left = left.removeMax(newTop);
         newTop.right = right;
@@ -800,7 +905,7 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
         newTop.totalCount = totalCount - oldElemCount;
         return newTop.rebalance();
       } else {
-        AvlNode<E> newTop = succ;
+        AvlNode<E> newTop = succ();
         newTop.right = right.removeMin(newTop);
         newTop.left = left;
         newTop.distinctElements = distinctElements - 1;
@@ -810,6 +915,7 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     }
 
     // Removes the minimum node from this subtree to be reused elsewhere
+    @CheckForNull
     private AvlNode<E> removeMin(AvlNode<E> node) {
       if (left == null) {
         return right;
@@ -822,6 +928,7 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     }
 
     // Removes the maximum node from this subtree to be reused elsewhere
+    @CheckForNull
     private AvlNode<E> removeMax(AvlNode<E> node) {
       if (right == null) {
         return left;
@@ -851,11 +958,15 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     private AvlNode<E> rebalance() {
       switch (balanceFactor()) {
         case -2:
+          // requireNonNull is safe because right must exist in order to get a negative factor.
+          requireNonNull(right);
           if (right.balanceFactor() > 0) {
             right = right.rotateRight();
           }
           return rotateLeft();
         case 2:
+          // requireNonNull is safe because left must exist in order to get a positive factor.
+          requireNonNull(left);
           if (left.balanceFactor() < 0) {
             left = left.rotateLeft();
           }
@@ -894,17 +1005,17 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       return newTop;
     }
 
-    private static long totalCount(@Nullable AvlNode<?> node) {
+    private static long totalCount(@CheckForNull AvlNode<?> node) {
       return (node == null) ? 0 : node.totalCount;
     }
 
-    private static int height(@Nullable AvlNode<?> node) {
+    private static int height(@CheckForNull AvlNode<?> node) {
       return (node == null) ? 0 : node.height;
     }
 
-    @Nullable
-    private AvlNode<E> ceiling(Comparator<? super E> comparator, E e) {
-      int cmp = comparator.compare(e, elem);
+    @CheckForNull
+    private AvlNode<E> ceiling(Comparator<? super E> comparator, @ParametricNullness E e) {
+      int cmp = comparator.compare(e, getElement());
       if (cmp < 0) {
         return (left == null) ? this : MoreObjects.firstNonNull(left.ceiling(comparator, e), this);
       } else if (cmp == 0) {
@@ -914,9 +1025,9 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       }
     }
 
-    @Nullable
-    private AvlNode<E> floor(Comparator<? super E> comparator, E e) {
-      int cmp = comparator.compare(e, elem);
+    @CheckForNull
+    private AvlNode<E> floor(Comparator<? super E> comparator, @ParametricNullness E e) {
+      int cmp = comparator.compare(e, getElement());
       if (cmp > 0) {
         return (right == null) ? this : MoreObjects.firstNonNull(right.floor(comparator, e), this);
       } else if (cmp == 0) {
@@ -926,13 +1037,13 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
       }
     }
 
-    @Override
-    public E getElement() {
-      return elem;
+    @ParametricNullness
+    E getElement() {
+      // For discussion of this cast, see the comment on the elem field.
+      return uncheckedCastNullableTToT(elem);
     }
 
-    @Override
-    public int getCount() {
+    int getCount() {
       return elemCount;
     }
 
@@ -942,12 +1053,13 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
     }
   }
 
-  private static <T> void successor(AvlNode<T> a, AvlNode<T> b) {
+  private static <T extends @Nullable Object> void successor(AvlNode<T> a, AvlNode<T> b) {
     a.succ = b;
     b.pred = a;
   }
 
-  private static <T> void successor(AvlNode<T> a, AvlNode<T> b, AvlNode<T> c) {
+  private static <T extends @Nullable Object> void successor(
+      AvlNode<T> a, AvlNode<T> b, AvlNode<T> c) {
     successor(a, b);
     successor(b, c);
   }
@@ -960,16 +1072,18 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
 
   /**
    * @serialData the comparator, the number of distinct elements, the first element, its count, the
-   *             second element, its count, and so on
+   *     second element, its count, and so on
    */
-  @GwtIncompatible("java.io.ObjectOutputStream")
+  @J2ktIncompatible
+  @GwtIncompatible // java.io.ObjectOutputStream
   private void writeObject(ObjectOutputStream stream) throws IOException {
     stream.defaultWriteObject();
     stream.writeObject(elementSet().comparator());
     Serialization.writeMultiset(this, stream);
   }
 
-  @GwtIncompatible("java.io.ObjectInputStream")
+  @J2ktIncompatible
+  @GwtIncompatible // java.io.ObjectInputStream
   private void readObject(ObjectInputStream stream) throws IOException, ClassNotFoundException {
     stream.defaultReadObject();
     @SuppressWarnings("unchecked")
@@ -980,12 +1094,13 @@ public final class TreeMultiset<E> extends AbstractSortedMultiset<E> implements
         .set(this, GeneralRange.all(comparator));
     Serialization.getFieldSetter(TreeMultiset.class, "rootReference")
         .set(this, new Reference<AvlNode<E>>());
-    AvlNode<E> header = new AvlNode<E>(null, 1);
+    AvlNode<E> header = new AvlNode<>();
     Serialization.getFieldSetter(TreeMultiset.class, "header").set(this, header);
     successor(header, header);
     Serialization.populateMultiset(this, stream);
   }
 
-  @GwtIncompatible("not needed in emulated source")
+  @GwtIncompatible // not needed in emulated source
+  @J2ktIncompatible
   private static final long serialVersionUID = 1;
 }
