@@ -1,17 +1,15 @@
 /*
  * Copyright (C) 2011 The Guava Authors
  *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the License at
  *
  * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
  */
 
 package com.google.common.math;
@@ -23,12 +21,14 @@ import static com.google.common.math.MathPreconditions.checkPositive;
 import static com.google.common.math.MathPreconditions.checkRoundingUnnecessary;
 import static java.math.RoundingMode.CEILING;
 import static java.math.RoundingMode.FLOOR;
+import static java.math.RoundingMode.HALF_DOWN;
 import static java.math.RoundingMode.HALF_EVEN;
+import static java.math.RoundingMode.UNNECESSARY;
 
 import com.google.common.annotations.GwtCompatible;
 import com.google.common.annotations.GwtIncompatible;
+import com.google.common.annotations.J2ktIncompatible;
 import com.google.common.annotations.VisibleForTesting;
-
 import java.math.BigDecimal;
 import java.math.BigInteger;
 import java.math.RoundingMode;
@@ -41,17 +41,38 @@ import java.util.List;
  * <p>The implementations of many methods in this class are based on material from Henry S. Warren,
  * Jr.'s <i>Hacker's Delight</i>, (Addison Wesley, 2002).
  *
- * <p>Similar functionality for {@code int} and for {@code long} can be found in
- * {@link IntMath} and {@link LongMath} respectively.
+ * <p>Similar functionality for {@code int} and for {@code long} can be found in {@link IntMath} and
+ * {@link LongMath} respectively.
  *
  * @author Louis Wasserman
  * @since 11.0
  */
 @GwtCompatible(emulated = true)
+@ElementTypesAreNonnullByDefault
 public final class BigIntegerMath {
   /**
-   * Returns {@code true} if {@code x} represents a power of two.
+   * Returns the smallest power of two greater than or equal to {@code x}. This is equivalent to
+   * {@code BigInteger.valueOf(2).pow(log2(x, CEILING))}.
+   *
+   * @throws IllegalArgumentException if {@code x <= 0}
+   * @since 20.0
    */
+  public static BigInteger ceilingPowerOfTwo(BigInteger x) {
+    return BigInteger.ZERO.setBit(log2(x, CEILING));
+  }
+
+  /**
+   * Returns the largest power of two less than or equal to {@code x}. This is equivalent to {@code
+   * BigInteger.valueOf(2).pow(log2(x, FLOOR))}.
+   *
+   * @throws IllegalArgumentException if {@code x <= 0}
+   * @since 20.0
+   */
+  public static BigInteger floorPowerOfTwo(BigInteger x) {
+    return BigInteger.ZERO.setBit(log2(x, FLOOR));
+  }
+
+  /** Returns {@code true} if {@code x} represents a power of two. */
   public static boolean isPowerOfTwo(BigInteger x) {
     checkNotNull(x);
     return x.signum() > 0 && x.getLowestSetBit() == x.bitLength() - 1;
@@ -62,7 +83,7 @@ public final class BigIntegerMath {
    *
    * @throws IllegalArgumentException if {@code x <= 0}
    * @throws ArithmeticException if {@code mode} is {@link RoundingMode#UNNECESSARY} and {@code x}
-   *         is not a power of two
+   *     is not a power of two
    */
   @SuppressWarnings("fallthrough")
   // TODO(kevinb): remove after this warning is disabled globally
@@ -84,20 +105,18 @@ public final class BigIntegerMath {
       case HALF_UP:
       case HALF_EVEN:
         if (logFloor < SQRT2_PRECOMPUTE_THRESHOLD) {
-          BigInteger halfPower = SQRT2_PRECOMPUTED_BITS.shiftRight(
-              SQRT2_PRECOMPUTE_THRESHOLD - logFloor);
+          BigInteger halfPower =
+              SQRT2_PRECOMPUTED_BITS.shiftRight(SQRT2_PRECOMPUTE_THRESHOLD - logFloor);
           if (x.compareTo(halfPower) <= 0) {
             return logFloor;
           } else {
             return logFloor + 1;
           }
         }
-        /*
-         * Since sqrt(2) is irrational, log2(x) - logFloor cannot be exactly 0.5
-         *
-         * To determine which side of logFloor.5 the logarithm is, we compare x^2 to 2^(2 *
-         * logFloor + 1).
-         */
+        // Since sqrt(2) is irrational, log2(x) - logFloor cannot be exactly 0.5
+        //
+        // To determine which side of logFloor.5 the logarithm is,
+        // we compare x^2 to 2^(2 * logFloor + 1).
         BigInteger x2 = x.pow(2);
         int logX2Floor = x2.bitLength() - 1;
         return (logX2Floor < 2 * logFloor + 1) ? logFloor : logFloor + 1;
@@ -114,7 +133,8 @@ public final class BigIntegerMath {
    */
   @VisibleForTesting static final int SQRT2_PRECOMPUTE_THRESHOLD = 256;
 
-  @VisibleForTesting static final BigInteger SQRT2_PRECOMPUTED_BITS =
+  @VisibleForTesting
+  static final BigInteger SQRT2_PRECOMPUTED_BITS =
       new BigInteger("16a09e667f3bcc908b2fb1366ea957d3e3adec17512775099da2f590b0667322a", 16);
 
   /**
@@ -122,9 +142,10 @@ public final class BigIntegerMath {
    *
    * @throws IllegalArgumentException if {@code x <= 0}
    * @throws ArithmeticException if {@code mode} is {@link RoundingMode#UNNECESSARY} and {@code x}
-   *         is not a power of ten
+   *     is not a power of ten
    */
-  @GwtIncompatible("TODO")
+  @J2ktIncompatible
+  @GwtIncompatible // TODO
   @SuppressWarnings("fallthrough")
   public static int log10(BigInteger x, RoundingMode mode) {
     checkPositive("x", x);
@@ -144,8 +165,8 @@ public final class BigIntegerMath {
     if (approxCmp > 0) {
       /*
        * The code is written so that even completely incorrect approximations will still yield the
-       * correct answer eventually, but in practice this branch should almost never be entered,
-       * and even then the loop should not run more than once.
+       * correct answer eventually, but in practice this branch should almost never be entered, and
+       * even then the loop should not run more than once.
        */
       do {
         approxLog10--;
@@ -199,10 +220,11 @@ public final class BigIntegerMath {
    * Returns the square root of {@code x}, rounded with the specified rounding mode.
    *
    * @throws IllegalArgumentException if {@code x < 0}
-   * @throws ArithmeticException if {@code mode} is {@link RoundingMode#UNNECESSARY} and
-   *         {@code sqrt(x)} is not an integer
+   * @throws ArithmeticException if {@code mode} is {@link RoundingMode#UNNECESSARY} and {@code
+   *     sqrt(x)} is not an integer
    */
-  @GwtIncompatible("TODO")
+  @J2ktIncompatible
+  @GwtIncompatible // TODO
   @SuppressWarnings("fallthrough")
   public static BigInteger sqrt(BigInteger x, RoundingMode mode) {
     checkNonNegative("x", x);
@@ -221,15 +243,15 @@ public final class BigIntegerMath {
         int sqrtFloorInt = sqrtFloor.intValue();
         boolean sqrtFloorIsExact =
             (sqrtFloorInt * sqrtFloorInt == x.intValue()) // fast check mod 2^32
-            && sqrtFloor.pow(2).equals(x); // slow exact check
+                && sqrtFloor.pow(2).equals(x); // slow exact check
         return sqrtFloorIsExact ? sqrtFloor : sqrtFloor.add(BigInteger.ONE);
       case HALF_DOWN:
       case HALF_UP:
       case HALF_EVEN:
         BigInteger halfSquare = sqrtFloor.pow(2).add(sqrtFloor);
         /*
-         * We wish to test whether or not x <= (sqrtFloor + 0.5)^2 = halfSquare + 0.25. Since both
-         * x and halfSquare are integers, this is equivalent to testing whether or not x <=
+         * We wish to test whether or not x <= (sqrtFloor + 0.5)^2 = halfSquare + 0.25. Since both x
+         * and halfSquare are integers, this is equivalent to testing whether or not x <=
          * halfSquare.
          */
         return (halfSquare.compareTo(x) >= 0) ? sqrtFloor : sqrtFloor.add(BigInteger.ONE);
@@ -238,7 +260,8 @@ public final class BigIntegerMath {
     }
   }
 
-  @GwtIncompatible("TODO")
+  @J2ktIncompatible
+  @GwtIncompatible // TODO
   private static BigInteger sqrtFloor(BigInteger x) {
     /*
      * Adapted from Hacker's Delight, Figure 11-1.
@@ -282,19 +305,76 @@ public final class BigIntegerMath {
     return sqrt0;
   }
 
-  @GwtIncompatible("TODO")
+  @J2ktIncompatible
+  @GwtIncompatible // TODO
   private static BigInteger sqrtApproxWithDoubles(BigInteger x) {
     return DoubleMath.roundToBigInteger(Math.sqrt(DoubleUtils.bigToDouble(x)), HALF_EVEN);
   }
 
   /**
-   * Returns the result of dividing {@code p} by {@code q}, rounding using the specified
-   * {@code RoundingMode}.
+   * Returns {@code x}, rounded to a {@code double} with the specified rounding mode. If {@code x}
+   * is precisely representable as a {@code double}, its {@code double} value will be returned;
+   * otherwise, the rounding will choose between the two nearest representable values with {@code
+   * mode}.
+   *
+   * <p>For the case of {@link RoundingMode#HALF_DOWN}, {@code HALF_UP}, and {@code HALF_EVEN},
+   * infinite {@code double} values are considered infinitely far away. For example, 2^2000 is not
+   * representable as a double, but {@code roundToDouble(BigInteger.valueOf(2).pow(2000), HALF_UP)}
+   * will return {@code Double.MAX_VALUE}, not {@code Double.POSITIVE_INFINITY}.
+   *
+   * <p>For the case of {@link RoundingMode#HALF_EVEN}, this implementation uses the IEEE 754
+   * default rounding mode: if the two nearest representable values are equally near, the one with
+   * the least significant bit zero is chosen. (In such cases, both of the nearest representable
+   * values are even integers; this method returns the one that is a multiple of a greater power of
+   * two.)
+   *
+   * @throws ArithmeticException if {@code mode} is {@link RoundingMode#UNNECESSARY} and {@code x}
+   *     is not precisely representable as a {@code double}
+   * @since 30.0
+   */
+  @J2ktIncompatible
+  @GwtIncompatible
+  public static double roundToDouble(BigInteger x, RoundingMode mode) {
+    return BigIntegerToDoubleRounder.INSTANCE.roundToDouble(x, mode);
+  }
+
+  @J2ktIncompatible
+  @GwtIncompatible
+  private static class BigIntegerToDoubleRounder extends ToDoubleRounder<BigInteger> {
+    static final BigIntegerToDoubleRounder INSTANCE = new BigIntegerToDoubleRounder();
+
+    private BigIntegerToDoubleRounder() {}
+
+    @Override
+    double roundToDoubleArbitrarily(BigInteger bigInteger) {
+      return DoubleUtils.bigToDouble(bigInteger);
+    }
+
+    @Override
+    int sign(BigInteger bigInteger) {
+      return bigInteger.signum();
+    }
+
+    @Override
+    BigInteger toX(double d, RoundingMode mode) {
+      return DoubleMath.roundToBigInteger(d, mode);
+    }
+
+    @Override
+    BigInteger minus(BigInteger a, BigInteger b) {
+      return a.subtract(b);
+    }
+  }
+
+  /**
+   * Returns the result of dividing {@code p} by {@code q}, rounding using the specified {@code
+   * RoundingMode}.
    *
    * @throws ArithmeticException if {@code q == 0}, or if {@code mode == UNNECESSARY} and {@code a}
-   *         is not an integer multiple of {@code b}
+   *     is not an integer multiple of {@code b}
    */
-  @GwtIncompatible("TODO")
+  @J2ktIncompatible
+  @GwtIncompatible // TODO
   public static BigInteger divide(BigInteger p, BigInteger q, RoundingMode mode) {
     BigDecimal pDec = new BigDecimal(p);
     BigDecimal qDec = new BigDecimal(q);
@@ -302,14 +382,14 @@ public final class BigIntegerMath {
   }
 
   /**
-   * Returns {@code n!}, that is, the product of the first {@code n} positive
-   * integers, or {@code 1} if {@code n == 0}.
+   * Returns {@code n!}, that is, the product of the first {@code n} positive integers, or {@code 1}
+   * if {@code n == 0}.
    *
    * <p><b>Warning:</b> the result takes <i>O(n log n)</i> space, so use cautiously.
    *
-   * <p>This uses an efficient binary recursive algorithm to compute the factorial
-   * with balanced multiplies.  It also removes all the 2s from the intermediate
-   * products (shifting them back in at the end).
+   * <p>This uses an efficient binary recursive algorithm to compute the factorial with balanced
+   * multiplies. It also removes all the 2s from the intermediate products (shifting them back in at
+   * the end).
    *
    * @throws IllegalArgumentException if {@code n < 0}
    */
@@ -323,7 +403,7 @@ public final class BigIntegerMath {
 
     // Pre-allocate space for our list of intermediate BigIntegers.
     int approxSize = IntMath.divide(n * IntMath.log2(n, CEILING), Long.SIZE, CEILING);
-    ArrayList<BigInteger> bignums = new ArrayList<BigInteger>(approxSize);
+    ArrayList<BigInteger> bignums = new ArrayList<>(approxSize);
 
     // Start from the pre-computed maximum long factorial.
     int startingNumber = LongMath.factorials.length;
@@ -389,7 +469,7 @@ public final class BigIntegerMath {
     }
   }
 
- /**
+  /**
    * Returns {@code n} choose {@code k}, also known as the binomial coefficient of {@code n} and
    * {@code k}, that is, {@code n! / (k! (n - k)!)}.
    *
@@ -413,7 +493,7 @@ public final class BigIntegerMath {
     long numeratorAccum = n;
     long denominatorAccum = 1;
 
-    int bits = LongMath.log2(n, RoundingMode.CEILING);
+    int bits = LongMath.log2(n, CEILING);
 
     int numeratorBits = bits;
 
@@ -426,9 +506,10 @@ public final class BigIntegerMath {
       if (numeratorBits + bits >= Long.SIZE - 1) {
         // The numerator is as big as it can get without risking overflow.
         // Multiply numeratorAccum / denominatorAccum into accum.
-        accum = accum
-            .multiply(BigInteger.valueOf(numeratorAccum))
-            .divide(BigInteger.valueOf(denominatorAccum));
+        accum =
+            accum
+                .multiply(BigInteger.valueOf(numeratorAccum))
+                .divide(BigInteger.valueOf(denominatorAccum));
         numeratorAccum = p;
         denominatorAccum = q;
         numeratorBits = bits;
@@ -445,7 +526,8 @@ public final class BigIntegerMath {
   }
 
   // Returns true if BigInteger.valueOf(x.longValue()).equals(x).
-  @GwtIncompatible("TODO")
+  @J2ktIncompatible
+  @GwtIncompatible // TODO
   static boolean fitsInLong(BigInteger x) {
     return x.bitLength() <= Long.SIZE - 1;
   }
